/* GXmlDocument.c generated by valac 0.44.3, the Vala compiler
 * generated from GXmlDocument.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */
/* GDocument.vala
 *
 * Copyright (C) 2016-2019  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gee.h>
#include <gio/gio.h>
#include <libxml/tree.h>
#include <float.h>
#include <math.h>
#include <libxml/parser.h>
#include <glib/gi18n-lib.h>
#include <libxml/xmlerror.h>
#include <libxml/xmlwriter.h>

#define GXML_TYPE_DOM_EVENT_TARGET (gxml_dom_event_target_get_type ())
#define GXML_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTarget))
#define GXML_IS_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_TARGET))
#define GXML_DOM_EVENT_TARGET_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTargetIface))

typedef struct _GXmlDomEventTarget GXmlDomEventTarget;
typedef struct _GXmlDomEventTargetIface GXmlDomEventTargetIface;

#define GXML_TYPE_DOM_EVENT_LISTENER (gxml_dom_event_listener_get_type ())
#define GXML_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListener))
#define GXML_IS_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_LISTENER))
#define GXML_DOM_EVENT_LISTENER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListenerIface))

typedef struct _GXmlDomEventListener GXmlDomEventListener;
typedef struct _GXmlDomEventListenerIface GXmlDomEventListenerIface;

#define GXML_TYPE_DOM_EVENT (gxml_dom_event_get_type ())
#define GXML_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEvent))
#define GXML_IS_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT))
#define GXML_DOM_EVENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEventIface))

typedef struct _GXmlDomEvent GXmlDomEvent;
typedef struct _GXmlDomEventIface GXmlDomEventIface;

#define GXML_TYPE_DOM_TIME_STAMP (gxml_dom_time_stamp_get_type ())
#define GXML_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStamp))
#define GXML_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))
#define GXML_IS_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_IS_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_DOM_TIME_STAMP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))

typedef struct _GXmlDomTimeStamp GXmlDomTimeStamp;
typedef struct _GXmlDomTimeStampClass GXmlDomTimeStampClass;
typedef enum  {
	GXML_DOM_EVENT_PHASE_NONE = 0,
	GXML_DOM_EVENT_PHASE_CAPTURING_PHASE,
	GXML_DOM_EVENT_PHASE_AT_TARGET,
	GXML_DOM_EVENT_PHASE_BUBBLING_PHASE
} GXmlDomEventPhase;

#define GXML_DOM_EVENT_TYPE_PHASE (gxml_dom_event_phase_get_type ())

#define GXML_TYPE_DOM_NODE (gxml_dom_node_get_type ())
#define GXML_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE, GXmlDomNode))
#define GXML_IS_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE))
#define GXML_DOM_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE, GXmlDomNodeIface))

typedef struct _GXmlDomNode GXmlDomNode;
typedef struct _GXmlDomNodeIface GXmlDomNodeIface;
typedef enum  {
	GXML_DOM_NODE_DOCUMENT_POSITION_NONE = 1 << 0,
	GXML_DOM_NODE_DOCUMENT_POSITION_DISCONNECTED = 1 << 1,
	GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING = 1 << 2,
	GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING = 1 << 3,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS = 1 << 4,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY = 1 << 5,
	GXML_DOM_NODE_DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC = 1 << 6
} GXmlDomNodeDocumentPosition;

#define GXML_DOM_NODE_TYPE_DOCUMENT_POSITION (gxml_dom_node_document_position_get_type ())
typedef enum  {
	GXML_DOM_NODE_NODE_TYPE_INVALID = 0,
	GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE = 1,
	GXML_DOM_NODE_NODE_TYPE_ATTRIBUTE_NODE,
	GXML_DOM_NODE_NODE_TYPE_TEXT_NODE,
	GXML_DOM_NODE_NODE_TYPE_CDATA_SECTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_REFERENCE_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_NODE,
	GXML_DOM_NODE_NODE_TYPE_PROCESSING_INSTRUCTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_COMMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_FRAGMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_NOTATION_NODE
} GXmlDomNodeNodeType;

#define GXML_DOM_NODE_TYPE_NODE_TYPE (gxml_dom_node_node_type_get_type ())

#define GXML_TYPE_DOM_DOCUMENT (gxml_dom_document_get_type ())
#define GXML_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocument))
#define GXML_IS_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT))
#define GXML_DOM_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocumentIface))

typedef struct _GXmlDomDocument GXmlDomDocument;
typedef struct _GXmlDomDocumentIface GXmlDomDocumentIface;

#define GXML_TYPE_DOM_PARENT_NODE (gxml_dom_parent_node_get_type ())
#define GXML_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNode))
#define GXML_IS_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PARENT_NODE))
#define GXML_DOM_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNodeIface))

typedef struct _GXmlDomParentNode GXmlDomParentNode;
typedef struct _GXmlDomParentNodeIface GXmlDomParentNodeIface;

#define GXML_TYPE_DOM_ELEMENT (gxml_dom_element_get_type ())
#define GXML_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElement))
#define GXML_IS_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT))
#define GXML_DOM_ELEMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElementIface))

typedef struct _GXmlDomElement GXmlDomElement;
typedef struct _GXmlDomElementIface GXmlDomElementIface;

#define GXML_TYPE_DOM_CHILD_NODE (gxml_dom_child_node_get_type ())
#define GXML_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNode))
#define GXML_IS_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHILD_NODE))
#define GXML_DOM_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNodeIface))

typedef struct _GXmlDomChildNode GXmlDomChildNode;
typedef struct _GXmlDomChildNodeIface GXmlDomChildNodeIface;

#define GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE (gxml_dom_non_document_type_child_node_get_type ())
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNode))
#define GXML_IS_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE))
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNodeIface))

typedef struct _GXmlDomNonDocumentTypeChildNode GXmlDomNonDocumentTypeChildNode;
typedef struct _GXmlDomNonDocumentTypeChildNodeIface GXmlDomNonDocumentTypeChildNodeIface;

#define GXML_TYPE_DOM_HTML_COLLECTION (gxml_dom_html_collection_get_type ())
#define GXML_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollection))
#define GXML_IS_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_HTML_COLLECTION))
#define GXML_DOM_HTML_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollectionIface))

typedef struct _GXmlDomHTMLCollection GXmlDomHTMLCollection;
typedef struct _GXmlDomHTMLCollectionIface GXmlDomHTMLCollectionIface;

#define GXML_TYPE_DOM_TOKEN_LIST (gxml_dom_token_list_get_type ())
#define GXML_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenList))
#define GXML_IS_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TOKEN_LIST))
#define GXML_DOM_TOKEN_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenListIface))

typedef struct _GXmlDomTokenList GXmlDomTokenList;
typedef struct _GXmlDomTokenListIface GXmlDomTokenListIface;

#define GXML_TYPE_DOM_NAMED_NODE_MAP (gxml_dom_named_node_map_get_type ())
#define GXML_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMap))
#define GXML_IS_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP))
#define GXML_DOM_NAMED_NODE_MAP_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMapIface))

typedef struct _GXmlDomNamedNodeMap GXmlDomNamedNodeMap;
typedef struct _GXmlDomNamedNodeMapIface GXmlDomNamedNodeMapIface;

#define GXML_TYPE_DOM_NODE_LIST (gxml_dom_node_list_get_type ())
#define GXML_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeList))
#define GXML_IS_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_LIST))
#define GXML_DOM_NODE_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeListIface))

typedef struct _GXmlDomNodeList GXmlDomNodeList;
typedef struct _GXmlDomNodeListIface GXmlDomNodeListIface;

#define GXML_TYPE_DOM_ELEMENT_LIST (gxml_dom_element_list_get_type ())
#define GXML_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementList))
#define GXML_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))
#define GXML_IS_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_IS_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_DOM_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))

typedef struct _GXmlDomElementList GXmlDomElementList;
typedef struct _GXmlDomElementListClass GXmlDomElementListClass;

#define GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE (gxml_dom_non_element_parent_node_get_type ())
#define GXML_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNode))
#define GXML_IS_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE))
#define GXML_DOM_NON_ELEMENT_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNodeIface))

typedef struct _GXmlDomNonElementParentNode GXmlDomNonElementParentNode;
typedef struct _GXmlDomNonElementParentNodeIface GXmlDomNonElementParentNodeIface;

#define GXML_TYPE_DOM_DOCUMENT_FRAGMENT (gxml_dom_document_fragment_get_type ())
#define GXML_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragment))
#define GXML_IS_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT))
#define GXML_DOM_DOCUMENT_FRAGMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragmentIface))

typedef struct _GXmlDomDocumentFragment GXmlDomDocumentFragment;
typedef struct _GXmlDomDocumentFragmentIface GXmlDomDocumentFragmentIface;

#define GXML_TYPE_DOM_TEXT (gxml_dom_text_get_type ())
#define GXML_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TEXT, GXmlDomText))
#define GXML_IS_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TEXT))
#define GXML_DOM_TEXT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TEXT, GXmlDomTextIface))

typedef struct _GXmlDomText GXmlDomText;
typedef struct _GXmlDomTextIface GXmlDomTextIface;

#define GXML_TYPE_DOM_CHARACTER_DATA (gxml_dom_character_data_get_type ())
#define GXML_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterData))
#define GXML_IS_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHARACTER_DATA))
#define GXML_DOM_CHARACTER_DATA_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterDataIface))

typedef struct _GXmlDomCharacterData GXmlDomCharacterData;
typedef struct _GXmlDomCharacterDataIface GXmlDomCharacterDataIface;

#define GXML_TYPE_DOM_COMMENT (gxml_dom_comment_get_type ())
#define GXML_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomComment))
#define GXML_IS_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_COMMENT))
#define GXML_DOM_COMMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomCommentIface))

typedef struct _GXmlDomComment GXmlDomComment;
typedef struct _GXmlDomCommentIface GXmlDomCommentIface;

#define GXML_TYPE_DOM_PROCESSING_INSTRUCTION (gxml_dom_processing_instruction_get_type ())
#define GXML_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstruction))
#define GXML_IS_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION))
#define GXML_DOM_PROCESSING_INSTRUCTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstructionIface))

typedef struct _GXmlDomProcessingInstruction GXmlDomProcessingInstruction;
typedef struct _GXmlDomProcessingInstructionIface GXmlDomProcessingInstructionIface;

#define GXML_TYPE_DOM_RANGE (gxml_dom_range_get_type ())
#define GXML_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRange))
#define GXML_IS_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_RANGE))
#define GXML_DOM_RANGE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRangeIface))

typedef struct _GXmlDomRange GXmlDomRange;
typedef struct _GXmlDomRangeIface GXmlDomRangeIface;
typedef enum  {
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_START = 0,
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_START
} GXmlDomRangeBoundaryPoints;

#define GXML_DOM_RANGE_TYPE_BOUNDARY_POINTS (gxml_dom_range_boundary_points_get_type ())

#define GXML_TYPE_DOM_NODE_FILTER (gxml_dom_node_filter_get_type ())
#define GXML_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilter))
#define GXML_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))
#define GXML_IS_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_IS_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_DOM_NODE_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))

typedef struct _GXmlDomNodeFilter GXmlDomNodeFilter;
typedef struct _GXmlDomNodeFilterClass GXmlDomNodeFilterClass;

#define GXML_TYPE_DOM_NODE_ITERATOR (gxml_dom_node_iterator_get_type ())
#define GXML_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIterator))
#define GXML_IS_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_ITERATOR))
#define GXML_DOM_NODE_ITERATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIteratorIface))

typedef struct _GXmlDomNodeIterator GXmlDomNodeIterator;
typedef struct _GXmlDomNodeIteratorIface GXmlDomNodeIteratorIface;

#define GXML_TYPE_DOM_TREE_WALKER (gxml_dom_tree_walker_get_type ())
#define GXML_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalker))
#define GXML_IS_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TREE_WALKER))
#define GXML_DOM_TREE_WALKER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalkerIface))

typedef struct _GXmlDomTreeWalker GXmlDomTreeWalker;
typedef struct _GXmlDomTreeWalkerIface GXmlDomTreeWalkerIface;

#define GXML_TYPE_PARSER (gxml_parser_get_type ())
#define GXML_PARSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_PARSER, GXmlParser))
#define GXML_IS_PARSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_PARSER))
#define GXML_PARSER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_PARSER, GXmlParserIface))

typedef struct _GXmlParser GXmlParser;
typedef struct _GXmlParserIface GXmlParserIface;

#define GXML_TYPE_DOM_IMPLEMENTATION (gxml_dom_implementation_get_type ())
#define GXML_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementation))
#define GXML_IS_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_IMPLEMENTATION))
#define GXML_DOM_IMPLEMENTATION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementationIface))

typedef struct _GXmlDomImplementation GXmlDomImplementation;
typedef struct _GXmlDomImplementationIface GXmlDomImplementationIface;

#define GXML_TYPE_DOM_DOCUMENT_TYPE (gxml_dom_document_type_get_type ())
#define GXML_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentType))
#define GXML_IS_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE))
#define GXML_DOM_DOCUMENT_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentTypeIface))

typedef struct _GXmlDomDocumentType GXmlDomDocumentType;
typedef struct _GXmlDomDocumentTypeIface GXmlDomDocumentTypeIface;

#define GXML_TYPE_DOM_XML_DOCUMENT (gxml_dom_xml_document_get_type ())
#define GXML_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocument))
#define GXML_IS_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_XML_DOCUMENT))
#define GXML_DOM_XML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocumentIface))

typedef struct _GXmlDomXMLDocument GXmlDomXMLDocument;
typedef struct _GXmlDomXMLDocumentIface GXmlDomXMLDocumentIface;

#define GXML_TYPE_DOCUMENT (gxml_document_get_type ())
#define GXML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOCUMENT, GXmlDocument))
#define GXML_IS_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOCUMENT))
#define GXML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOCUMENT, GXmlDocumentIface))

typedef struct _GXmlDocument GXmlDocument;
typedef struct _GXmlDocumentIface GXmlDocumentIface;

#define GXML_TYPE_NODE (gxml_node_get_type ())
#define GXML_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NODE, GXmlNode))
#define GXML_IS_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NODE))
#define GXML_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NODE, GXmlNodeIface))

typedef struct _GXmlNode GXmlNode;
typedef struct _GXmlNodeIface GXmlNodeIface;

#define GXML_TYPE_ELEMENT_LIST (gxml_element_list_get_type ())
#define GXML_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementList))
#define GXML_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))
#define GXML_IS_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ELEMENT_LIST))
#define GXML_IS_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_ELEMENT_LIST))
#define GXML_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))

typedef struct _GXmlElementList GXmlElementList;
typedef struct _GXmlElementListClass GXmlElementListClass;

#define GXML_TYPE_NAMESPACE (gxml_namespace_get_type ())
#define GXML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NAMESPACE, GXmlNamespace))
#define GXML_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NAMESPACE))
#define GXML_NAMESPACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NAMESPACE, GXmlNamespaceIface))

typedef struct _GXmlNamespace GXmlNamespace;
typedef struct _GXmlNamespaceIface GXmlNamespaceIface;
typedef enum  {
	GXML_NODE_TYPE_INVALID = 0,
	GXML_NODE_TYPE_ELEMENT = 1,
	GXML_NODE_TYPE_ATTRIBUTE,
	GXML_NODE_TYPE_TEXT,
	GXML_NODE_TYPE_CDATA_SECTION,
	GXML_NODE_TYPE_ENTITY_REFERENCE,
	GXML_NODE_TYPE_ENTITY,
	GXML_NODE_TYPE_PROCESSING_INSTRUCTION,
	GXML_NODE_TYPE_COMMENT,
	GXML_NODE_TYPE_DOCUMENT,
	GXML_NODE_TYPE_DOCUMENT_TYPE,
	GXML_NODE_TYPE_DOCUMENT_FRAGMENT,
	GXML_NODE_TYPE_NOTATION
} GXmlNodeType;

#define GXML_TYPE_NODE_TYPE (gxml_node_type_get_type ())

#define GXML_TYPE_GNODE (gxml_gnode_get_type ())
#define GXML_GNODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GNODE, GXmlGNode))
#define GXML_GNODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GNODE, GXmlGNodeClass))
#define GXML_IS_GNODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GNODE))
#define GXML_IS_GNODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GNODE))
#define GXML_GNODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GNODE, GXmlGNodeClass))

typedef struct _GXmlGNode GXmlGNode;
typedef struct _GXmlGNodeClass GXmlGNodeClass;
typedef struct _GXmlGNodePrivate GXmlGNodePrivate;

#define GXML_TYPE_GDOCUMENT (gxml_gdocument_get_type ())
#define GXML_GDOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOCUMENT, GXmlGDocument))
#define GXML_GDOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOCUMENT, GXmlGDocumentClass))
#define GXML_IS_GDOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOCUMENT))
#define GXML_IS_GDOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOCUMENT))
#define GXML_GDOCUMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOCUMENT, GXmlGDocumentClass))

typedef struct _GXmlGDocument GXmlGDocument;
typedef struct _GXmlGDocumentClass GXmlGDocumentClass;

#define GXML_TYPE_XPATH_CONTEXT (gxml_xpath_context_get_type ())
#define GXML_XPATH_CONTEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_XPATH_CONTEXT, GXmlXPathContext))
#define GXML_IS_XPATH_CONTEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_XPATH_CONTEXT))
#define GXML_XPATH_CONTEXT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_XPATH_CONTEXT, GXmlXPathContextIface))

typedef struct _GXmlXPathContext GXmlXPathContext;
typedef struct _GXmlXPathContextIface GXmlXPathContextIface;

#define GXML_TYPE_XPATH_OBJECT (gxml_xpath_object_get_type ())
#define GXML_XPATH_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_XPATH_OBJECT, GXmlXPathObject))
#define GXML_IS_XPATH_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_XPATH_OBJECT))
#define GXML_XPATH_OBJECT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_XPATH_OBJECT, GXmlXPathObjectIface))

typedef struct _GXmlXPathObject GXmlXPathObject;
typedef struct _GXmlXPathObjectIface GXmlXPathObjectIface;
typedef enum  {
	GXML_XPATH_OBJECT_TYPE_UNDEFINED,
	GXML_XPATH_OBJECT_TYPE_NODESET,
	GXML_XPATH_OBJECT_TYPE_BOOLEAN,
	GXML_XPATH_OBJECT_TYPE_NUMBER,
	GXML_XPATH_OBJECT_TYPE_STRING,
	GXML_XPATH_OBJECT_TYPE_POINT,
	GXML_XPATH_OBJECT_TYPE_RANGE,
	GXML_XPATH_OBJECT_TYPE_LOCATIONSET,
	GXML_XPATH_OBJECT_TYPE_USERS,
	GXML_XPATH_OBJECT_TYPE_XSLT_TREE
} GXmlXPathObjectType;

#define GXML_TYPE_XPATH_OBJECT_TYPE (gxml_xpath_object_type_get_type ())
typedef struct _GXmlGDocumentPrivate GXmlGDocumentPrivate;

#define GXML_TYPE_GIMPLEMENTATION (gxml_gimplementation_get_type ())
#define GXML_GIMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GIMPLEMENTATION, GXmlGImplementation))
#define GXML_GIMPLEMENTATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GIMPLEMENTATION, GXmlGImplementationClass))
#define GXML_IS_GIMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GIMPLEMENTATION))
#define GXML_IS_GIMPLEMENTATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GIMPLEMENTATION))
#define GXML_GIMPLEMENTATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GIMPLEMENTATION, GXmlGImplementationClass))

typedef struct _GXmlGImplementation GXmlGImplementation;
typedef struct _GXmlGImplementationClass GXmlGImplementationClass;
enum  {
	GXML_GDOCUMENT_0_PROPERTY,
	GXML_GDOCUMENT_ATTRS_PROPERTY,
	GXML_GDOCUMENT_CHILDREN_NODES_PROPERTY,
	GXML_GDOCUMENT_NAMESPACES_PROPERTY,
	GXML_GDOCUMENT_DOCUMENT_PROPERTY,
	GXML_GDOCUMENT_INDENT_PROPERTY,
	GXML_GDOCUMENT_NS_TOP_PROPERTY,
	GXML_GDOCUMENT_PREFIX_DEFAULT_NS_PROPERTY,
	GXML_GDOCUMENT_BACKUP_PROPERTY,
	GXML_GDOCUMENT_FILE_PROPERTY,
	GXML_GDOCUMENT_ROOT_PROPERTY,
	GXML_GDOCUMENT_IMPLEMENTATION_PROPERTY,
	GXML_GDOCUMENT_URL_PROPERTY,
	GXML_GDOCUMENT_DOCUMENT_URI_PROPERTY,
	GXML_GDOCUMENT_ORIGIN_PROPERTY,
	GXML_GDOCUMENT_COMPAT_MODE_PROPERTY,
	GXML_GDOCUMENT_CHARACTER_SET_PROPERTY,
	GXML_GDOCUMENT_CONTENT_TYPE_PROPERTY,
	GXML_GDOCUMENT_DOCTYPE_PROPERTY,
	GXML_GDOCUMENT_DOCUMENT_ELEMENT_PROPERTY,
	GXML_GDOCUMENT_CHILDREN_PROPERTY,
	GXML_GDOCUMENT_FIRST_ELEMENT_CHILD_PROPERTY,
	GXML_GDOCUMENT_LAST_ELEMENT_CHILD_PROPERTY,
	GXML_GDOCUMENT_CHILD_ELEMENT_COUNT_PROPERTY,
	GXML_GDOCUMENT_NUM_PROPERTIES
};
static GParamSpec* gxml_gdocument_properties[GXML_GDOCUMENT_NUM_PROPERTIES];
#define _xmlBufferFree0(var) ((var == NULL) ? NULL : (var = (xmlBufferFree (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define GXML_TYPE_GPARSER (gxml_gparser_get_type ())
#define GXML_GPARSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GPARSER, GXmlGParser))
#define GXML_GPARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GPARSER, GXmlGParserClass))
#define GXML_IS_GPARSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GPARSER))
#define GXML_IS_GPARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GPARSER))
#define GXML_GPARSER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GPARSER, GXmlGParserClass))

typedef struct _GXmlGParser GXmlGParser;
typedef struct _GXmlGParserClass GXmlGParserClass;

#define GXML_TYPE_GCHILD_NODE (gxml_gchild_node_get_type ())
#define GXML_GCHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GCHILD_NODE, GXmlGChildNode))
#define GXML_GCHILD_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GCHILD_NODE, GXmlGChildNodeClass))
#define GXML_IS_GCHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GCHILD_NODE))
#define GXML_IS_GCHILD_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GCHILD_NODE))
#define GXML_GCHILD_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GCHILD_NODE, GXmlGChildNodeClass))

typedef struct _GXmlGChildNode GXmlGChildNode;
typedef struct _GXmlGChildNodeClass GXmlGChildNodeClass;

#define GXML_TYPE_GNON_DOCUMENT_CHILD_NODE (gxml_gnon_document_child_node_get_type ())
#define GXML_GNON_DOCUMENT_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GNON_DOCUMENT_CHILD_NODE, GXmlGNonDocumentChildNode))
#define GXML_GNON_DOCUMENT_CHILD_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GNON_DOCUMENT_CHILD_NODE, GXmlGNonDocumentChildNodeClass))
#define GXML_IS_GNON_DOCUMENT_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GNON_DOCUMENT_CHILD_NODE))
#define GXML_IS_GNON_DOCUMENT_CHILD_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GNON_DOCUMENT_CHILD_NODE))
#define GXML_GNON_DOCUMENT_CHILD_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GNON_DOCUMENT_CHILD_NODE, GXmlGNonDocumentChildNodeClass))

typedef struct _GXmlGNonDocumentChildNode GXmlGNonDocumentChildNode;
typedef struct _GXmlGNonDocumentChildNodeClass GXmlGNonDocumentChildNodeClass;

#define GXML_TYPE_GCHARACTER_DATA (gxml_gcharacter_data_get_type ())
#define GXML_GCHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GCHARACTER_DATA, GXmlGCharacterData))
#define GXML_GCHARACTER_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GCHARACTER_DATA, GXmlGCharacterDataClass))
#define GXML_IS_GCHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GCHARACTER_DATA))
#define GXML_IS_GCHARACTER_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GCHARACTER_DATA))
#define GXML_GCHARACTER_DATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GCHARACTER_DATA, GXmlGCharacterDataClass))

typedef struct _GXmlGCharacterData GXmlGCharacterData;
typedef struct _GXmlGCharacterDataClass GXmlGCharacterDataClass;

#define GXML_TYPE_GCOMMENT (gxml_gcomment_get_type ())
#define GXML_GCOMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GCOMMENT, GXmlGComment))
#define GXML_GCOMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GCOMMENT, GXmlGCommentClass))
#define GXML_IS_GCOMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GCOMMENT))
#define GXML_IS_GCOMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GCOMMENT))
#define GXML_GCOMMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GCOMMENT, GXmlGCommentClass))

typedef struct _GXmlGComment GXmlGComment;
typedef struct _GXmlGCommentClass GXmlGCommentClass;

#define GXML_TYPE_GPROCESSING_INSTRUCTION (gxml_gprocessing_instruction_get_type ())
#define GXML_GPROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GPROCESSING_INSTRUCTION, GXmlGProcessingInstruction))
#define GXML_GPROCESSING_INSTRUCTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GPROCESSING_INSTRUCTION, GXmlGProcessingInstructionClass))
#define GXML_IS_GPROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GPROCESSING_INSTRUCTION))
#define GXML_IS_GPROCESSING_INSTRUCTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GPROCESSING_INSTRUCTION))
#define GXML_GPROCESSING_INSTRUCTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GPROCESSING_INSTRUCTION, GXmlGProcessingInstructionClass))

typedef struct _GXmlGProcessingInstruction GXmlGProcessingInstruction;
typedef struct _GXmlGProcessingInstructionClass GXmlGProcessingInstructionClass;

#define GXML_TYPE_GELEMENT (gxml_gelement_get_type ())
#define GXML_GELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GELEMENT, GXmlGElement))
#define GXML_GELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GELEMENT, GXmlGElementClass))
#define GXML_IS_GELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GELEMENT))
#define GXML_IS_GELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GELEMENT))
#define GXML_GELEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GELEMENT, GXmlGElementClass))

typedef struct _GXmlGElement GXmlGElement;
typedef struct _GXmlGElementClass GXmlGElementClass;

#define GXML_TYPE_GTEXT (gxml_gtext_get_type ())
#define GXML_GTEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GTEXT, GXmlGText))
#define GXML_GTEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GTEXT, GXmlGTextClass))
#define GXML_IS_GTEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GTEXT))
#define GXML_IS_GTEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GTEXT))
#define GXML_GTEXT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GTEXT, GXmlGTextClass))

typedef struct _GXmlGText GXmlGText;
typedef struct _GXmlGTextClass GXmlGTextClass;

#define GXML_TYPE_GCDATA (gxml_gcdata_get_type ())
#define GXML_GCDATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GCDATA, GXmlGCDATA))
#define GXML_GCDATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GCDATA, GXmlGCDATAClass))
#define GXML_IS_GCDATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GCDATA))
#define GXML_IS_GCDATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GCDATA))
#define GXML_GCDATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GCDATA, GXmlGCDATAClass))

typedef struct _GXmlGCDATA GXmlGCDATA;
typedef struct _GXmlGCDATAClass GXmlGCDATAClass;
#define _xmlFreeTextWriter0(var) ((var == NULL) ? NULL : (var = (xmlFreeTextWriter (var), NULL)))
#define _xmlFreeDoc0(var) ((var == NULL) ? NULL : (var = (xmlFreeDoc (var), NULL)))

#define GXML_TYPE_GDOM_HTML_COLLECTION (gxml_gdom_html_collection_get_type ())
#define GXML_GDOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOM_HTML_COLLECTION, GXmlGDomHTMLCollection))
#define GXML_GDOM_HTML_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOM_HTML_COLLECTION, GXmlGDomHTMLCollectionClass))
#define GXML_IS_GDOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOM_HTML_COLLECTION))
#define GXML_IS_GDOM_HTML_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOM_HTML_COLLECTION))
#define GXML_GDOM_HTML_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOM_HTML_COLLECTION, GXmlGDomHTMLCollectionClass))

typedef struct _GXmlGDomHTMLCollection GXmlGDomHTMLCollection;
typedef struct _GXmlGDomHTMLCollectionClass GXmlGDomHTMLCollectionClass;

#define GXML_TYPE_GDOCUMENT_FRAGMENT (gxml_gdocument_fragment_get_type ())
#define GXML_GDOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOCUMENT_FRAGMENT, GXmlGDocumentFragment))
#define GXML_GDOCUMENT_FRAGMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOCUMENT_FRAGMENT, GXmlGDocumentFragmentClass))
#define GXML_IS_GDOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOCUMENT_FRAGMENT))
#define GXML_IS_GDOCUMENT_FRAGMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOCUMENT_FRAGMENT))
#define GXML_GDOCUMENT_FRAGMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOCUMENT_FRAGMENT, GXmlGDocumentFragmentClass))

typedef struct _GXmlGDocumentFragment GXmlGDocumentFragment;
typedef struct _GXmlGDocumentFragmentClass GXmlGDocumentFragmentClass;

#define GXML_TYPE_GDOM_EVENT (gxml_gdom_event_get_type ())
#define GXML_GDOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOM_EVENT, GXmlGDomEvent))
#define GXML_GDOM_EVENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOM_EVENT, GXmlGDomEventClass))
#define GXML_IS_GDOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOM_EVENT))
#define GXML_IS_GDOM_EVENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOM_EVENT))
#define GXML_GDOM_EVENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOM_EVENT, GXmlGDomEventClass))

typedef struct _GXmlGDomEvent GXmlGDomEvent;
typedef struct _GXmlGDomEventClass GXmlGDomEventClass;

#define GXML_TYPE_GDOM_CUSTOM_EVENT (gxml_gdom_custom_event_get_type ())
#define GXML_GDOM_CUSTOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOM_CUSTOM_EVENT, GXmlGDomCustomEvent))
#define GXML_GDOM_CUSTOM_EVENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOM_CUSTOM_EVENT, GXmlGDomCustomEventClass))
#define GXML_IS_GDOM_CUSTOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOM_CUSTOM_EVENT))
#define GXML_IS_GDOM_CUSTOM_EVENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOM_CUSTOM_EVENT))
#define GXML_GDOM_CUSTOM_EVENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOM_CUSTOM_EVENT, GXmlGDomCustomEventClass))

typedef struct _GXmlGDomCustomEvent GXmlGDomCustomEvent;
typedef struct _GXmlGDomCustomEventClass GXmlGDomCustomEventClass;

#define GXML_TYPE_GDOM_RANGE (gxml_gdom_range_get_type ())
#define GXML_GDOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOM_RANGE, GXmlGDomRange))
#define GXML_GDOM_RANGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOM_RANGE, GXmlGDomRangeClass))
#define GXML_IS_GDOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOM_RANGE))
#define GXML_IS_GDOM_RANGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOM_RANGE))
#define GXML_GDOM_RANGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOM_RANGE, GXmlGDomRangeClass))

typedef struct _GXmlGDomRange GXmlGDomRange;
typedef struct _GXmlGDomRangeClass GXmlGDomRangeClass;

#define GXML_TYPE_GDOM_NODE_ITERATOR (gxml_gdom_node_iterator_get_type ())
#define GXML_GDOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOM_NODE_ITERATOR, GXmlGDomNodeIterator))
#define GXML_GDOM_NODE_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOM_NODE_ITERATOR, GXmlGDomNodeIteratorClass))
#define GXML_IS_GDOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOM_NODE_ITERATOR))
#define GXML_IS_GDOM_NODE_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOM_NODE_ITERATOR))
#define GXML_GDOM_NODE_ITERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOM_NODE_ITERATOR, GXmlGDomNodeIteratorClass))

typedef struct _GXmlGDomNodeIterator GXmlGDomNodeIterator;
typedef struct _GXmlGDomNodeIteratorClass GXmlGDomNodeIteratorClass;

#define GXML_TYPE_GDOM_TREE_WALKER (gxml_gdom_tree_walker_get_type ())
#define GXML_GDOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOM_TREE_WALKER, GXmlGDomTreeWalker))
#define GXML_GDOM_TREE_WALKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOM_TREE_WALKER, GXmlGDomTreeWalkerClass))
#define GXML_IS_GDOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOM_TREE_WALKER))
#define GXML_IS_GDOM_TREE_WALKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOM_TREE_WALKER))
#define GXML_GDOM_TREE_WALKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOM_TREE_WALKER, GXmlGDomTreeWalkerClass))

typedef struct _GXmlGDomTreeWalker GXmlGDomTreeWalker;
typedef struct _GXmlGDomTreeWalkerClass GXmlGDomTreeWalkerClass;

#define GXML_TYPE_CSS_SELECTOR_PARSER (gxml_css_selector_parser_get_type ())
#define GXML_CSS_SELECTOR_PARSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_CSS_SELECTOR_PARSER, GXmlCssSelectorParser))
#define GXML_CSS_SELECTOR_PARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_CSS_SELECTOR_PARSER, GXmlCssSelectorParserClass))
#define GXML_IS_CSS_SELECTOR_PARSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_CSS_SELECTOR_PARSER))
#define GXML_IS_CSS_SELECTOR_PARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_CSS_SELECTOR_PARSER))
#define GXML_CSS_SELECTOR_PARSER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_CSS_SELECTOR_PARSER, GXmlCssSelectorParserClass))

typedef struct _GXmlCssSelectorParser GXmlCssSelectorParser;
typedef struct _GXmlCssSelectorParserClass GXmlCssSelectorParserClass;

#define GXML_TYPE_GOM_NODE_LIST (gxml_gom_node_list_get_type ())
#define GXML_GOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_NODE_LIST, GXmlGomNodeList))
#define GXML_GOM_NODE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_NODE_LIST, GXmlGomNodeListClass))
#define GXML_IS_GOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_NODE_LIST))
#define GXML_IS_GOM_NODE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_NODE_LIST))
#define GXML_GOM_NODE_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_NODE_LIST, GXmlGomNodeListClass))

typedef struct _GXmlGomNodeList GXmlGomNodeList;
typedef struct _GXmlGomNodeListClass GXmlGomNodeListClass;

#define GXML_TYPE_GHASH_MAP_ATTR (gxml_ghash_map_attr_get_type ())
#define GXML_GHASH_MAP_ATTR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GHASH_MAP_ATTR, GXmlGHashMapAttr))
#define GXML_GHASH_MAP_ATTR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GHASH_MAP_ATTR, GXmlGHashMapAttrClass))
#define GXML_IS_GHASH_MAP_ATTR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GHASH_MAP_ATTR))
#define GXML_IS_GHASH_MAP_ATTR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GHASH_MAP_ATTR))
#define GXML_GHASH_MAP_ATTR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GHASH_MAP_ATTR, GXmlGHashMapAttrClass))

typedef struct _GXmlGHashMapAttr GXmlGHashMapAttr;
typedef struct _GXmlGHashMapAttrClass GXmlGHashMapAttrClass;

#define GXML_TYPE_GLIST_CHILDREN (gxml_glist_children_get_type ())
#define GXML_GLIST_CHILDREN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GLIST_CHILDREN, GXmlGListChildren))
#define GXML_GLIST_CHILDREN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GLIST_CHILDREN, GXmlGListChildrenClass))
#define GXML_IS_GLIST_CHILDREN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GLIST_CHILDREN))
#define GXML_IS_GLIST_CHILDREN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GLIST_CHILDREN))
#define GXML_GLIST_CHILDREN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GLIST_CHILDREN, GXmlGListChildrenClass))

typedef struct _GXmlGListChildren GXmlGListChildren;
typedef struct _GXmlGListChildrenClass GXmlGListChildrenClass;

#define GXML_TYPE_GLIST_NAMESPACES (gxml_glist_namespaces_get_type ())
#define GXML_GLIST_NAMESPACES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GLIST_NAMESPACES, GXmlGListNamespaces))
#define GXML_GLIST_NAMESPACES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GLIST_NAMESPACES, GXmlGListNamespacesClass))
#define GXML_IS_GLIST_NAMESPACES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GLIST_NAMESPACES))
#define GXML_IS_GLIST_NAMESPACES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GLIST_NAMESPACES))
#define GXML_GLIST_NAMESPACES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GLIST_NAMESPACES, GXmlGListNamespacesClass))

typedef struct _GXmlGListNamespaces GXmlGListNamespaces;
typedef struct _GXmlGListNamespacesClass GXmlGListNamespacesClass;

#define GXML_TYPE_ELEMENT (gxml_element_get_type ())
#define GXML_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ELEMENT, GXmlElement))
#define GXML_IS_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ELEMENT))
#define GXML_ELEMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_ELEMENT, GXmlElementIface))

typedef struct _GXmlElement GXmlElement;
typedef struct _GXmlElementIface GXmlElementIface;
typedef struct _GXmlGImplementationPrivate GXmlGImplementationPrivate;
enum  {
	GXML_GIMPLEMENTATION_0_PROPERTY,
	GXML_GIMPLEMENTATION_NUM_PROPERTIES
};
static GParamSpec* gxml_gimplementation_properties[GXML_GIMPLEMENTATION_NUM_PROPERTIES];

#define GXML_TYPE_GDOCUMENT_TYPE (gxml_gdocument_type_get_type ())
#define GXML_GDOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOCUMENT_TYPE, GXmlGDocumentType))
#define GXML_GDOCUMENT_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOCUMENT_TYPE, GXmlGDocumentTypeClass))
#define GXML_IS_GDOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOCUMENT_TYPE))
#define GXML_IS_GDOCUMENT_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOCUMENT_TYPE))
#define GXML_GDOCUMENT_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOCUMENT_TYPE, GXmlGDocumentTypeClass))

typedef struct _GXmlGDocumentType GXmlGDocumentType;
typedef struct _GXmlGDocumentTypeClass GXmlGDocumentTypeClass;

#define GXML_TYPE_GHTML_DOCUMENT (gxml_ghtml_document_get_type ())
#define GXML_GHTML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GHTML_DOCUMENT, GXmlGHtmlDocument))
#define GXML_GHTML_DOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GHTML_DOCUMENT, GXmlGHtmlDocumentClass))
#define GXML_IS_GHTML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GHTML_DOCUMENT))
#define GXML_IS_GHTML_DOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GHTML_DOCUMENT))
#define GXML_GHTML_DOCUMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GHTML_DOCUMENT, GXmlGHtmlDocumentClass))

typedef struct _GXmlGHtmlDocument GXmlGHtmlDocument;
typedef struct _GXmlGHtmlDocumentClass GXmlGHtmlDocumentClass;
typedef struct _GXmlGChildNodePrivate GXmlGChildNodePrivate;
typedef struct _GXmlGDocumentTypePrivate GXmlGDocumentTypePrivate;
enum  {
	GXML_GDOCUMENT_TYPE_0_PROPERTY,
	GXML_GDOCUMENT_TYPE_NAME_PROPERTY,
	GXML_GDOCUMENT_TYPE_PUBLIC_ID_PROPERTY,
	GXML_GDOCUMENT_TYPE_SYSTEM_ID_PROPERTY,
	GXML_GDOCUMENT_TYPE_NUM_PROPERTIES
};
static GParamSpec* gxml_gdocument_type_properties[GXML_GDOCUMENT_TYPE_NUM_PROPERTIES];
typedef struct _GXmlGDocumentFragmentPrivate GXmlGDocumentFragmentPrivate;
enum  {
	GXML_GDOCUMENT_FRAGMENT_0_PROPERTY,
	GXML_GDOCUMENT_FRAGMENT_NUM_PROPERTIES
};
static GParamSpec* gxml_gdocument_fragment_properties[GXML_GDOCUMENT_FRAGMENT_NUM_PROPERTIES];
typedef struct _GXmlGDomNodeIteratorPrivate GXmlGDomNodeIteratorPrivate;
enum  {
	GXML_GDOM_NODE_ITERATOR_0_PROPERTY,
	GXML_GDOM_NODE_ITERATOR_NUM_PROPERTIES
};
static GParamSpec* gxml_gdom_node_iterator_properties[GXML_GDOM_NODE_ITERATOR_NUM_PROPERTIES];
typedef struct _GXmlGDomTreeWalkerPrivate GXmlGDomTreeWalkerPrivate;
enum  {
	GXML_GDOM_TREE_WALKER_0_PROPERTY,
	GXML_GDOM_TREE_WALKER_ROOT_PROPERTY,
	GXML_GDOM_TREE_WALKER_WHAT_TO_SHOW_PROPERTY,
	GXML_GDOM_TREE_WALKER_FILTER_PROPERTY,
	GXML_GDOM_TREE_WALKER_CURRENT_NODE_PROPERTY,
	GXML_GDOM_TREE_WALKER_NUM_PROPERTIES
};
static GParamSpec* gxml_gdom_tree_walker_properties[GXML_GDOM_TREE_WALKER_NUM_PROPERTIES];

struct _GXmlDomEventIface {
	GTypeInterface parent_iface;
	void (*stop_propagation) (GXmlDomEvent* self);
	void (*stop_immediate_propagation) (GXmlDomEvent* self);
	void (*prevent_default) (GXmlDomEvent* self);
	void (*init_event) (GXmlDomEvent* self, const gchar* type, gboolean bubbles, gboolean cancelable);
	const gchar* (*get_etype) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_event_target) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_current_target) (GXmlDomEvent* self);
	gboolean (*get_bubbles) (GXmlDomEvent* self);
	gboolean (*get_cancelable) (GXmlDomEvent* self);
	gboolean (*get_is_trusted) (GXmlDomEvent* self);
	GXmlDomTimeStamp* (*get_time_stamp) (GXmlDomEvent* self);
	gboolean (*get_default_prevented) (GXmlDomEvent* self);
	GXmlDomEventPhase (*get_event_phase) (GXmlDomEvent* self);
};

struct _GXmlDomEventListenerIface {
	GTypeInterface parent_iface;
	void (*handle_event) (GXmlDomEventListener* self, GXmlDomEvent* event);
};

struct _GXmlDomEventTargetIface {
	GTypeInterface parent_iface;
	void (*add_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	void (*remove_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	gboolean (*dispatch_event) (GXmlDomEventTarget* self, GXmlDomEvent* event, GError** error);
};

struct _GXmlDomChildNodeIface {
	GTypeInterface parent_iface;
	void (*remove) (GXmlDomChildNode* self);
};

struct _GXmlDomNonDocumentTypeChildNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_previous_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
	GXmlDomElement* (*get_next_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
};

struct _GXmlDomHTMLCollectionIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement** (*to_array) (GXmlDomHTMLCollection* self, gint* result_length1);
	GXmlDomElement* (*item) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement* (*named_item) (GXmlDomHTMLCollection* self, const gchar* name);
	gint (*get_length) (GXmlDomHTMLCollection* self);
};

struct _GXmlDomTokenListIface {
	GTypeInterface parent_iface;
	gchar* (*item) (GXmlDomTokenList* self, gint index);
	gboolean (*contains) (GXmlDomTokenList* self, const gchar* token, GError** error);
	void (*add) (GXmlDomTokenList* self, gchar** tokens, gint tokens_length1, GError** error);
	void (*remove) (GXmlDomTokenList* self, gchar** tokens, gint tokens_length1);
	gboolean (*toggle) (GXmlDomTokenList* self, const gchar* token, gboolean force, gboolean _auto_, GError** error);
	gchar* (*to_string) (GXmlDomTokenList* self);
	gint (*get_length) (GXmlDomTokenList* self);
};

struct _GXmlDomNamedNodeMapIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNamedNodeMap* self, gint index);
	GXmlDomNode* (*get_named_item) (GXmlDomNamedNodeMap* self, const gchar* name);
	GXmlDomNode* (*set_named_item) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*remove_named_item) (GXmlDomNamedNodeMap* self, const gchar* name, GError** error);
	GXmlDomNode* (*remove_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* localName, GError** error);
	GXmlDomNode* (*get_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* local_name, GError** error);
	GXmlDomNode* (*set_named_item_ns) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	gint (*get_length) (GXmlDomNamedNodeMap* self);
};

struct _GXmlDomElementIface {
	GTypeInterface parent_iface;
	gchar* (*get_attribute) (GXmlDomElement* self, const gchar* name);
	gchar* (*get_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	void (*set_attribute) (GXmlDomElement* self, const gchar* name, const gchar* value, GError** error);
	void (*set_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* name, const gchar* value, GError** error);
	void (*remove_attribute) (GXmlDomElement* self, const gchar* name);
	void (*remove_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	gboolean (*has_attribute) (GXmlDomElement* self, const gchar* name);
	gboolean (*has_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomElement* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomElement* self, const gchar* class_names);
	gboolean (*matches) (GXmlDomElement* self, const gchar* selectors, GError** error);
	void (*read_from_uri) (GXmlDomElement* self, const gchar* uri, GError** error);
	void (*read_from_uri_async) (GXmlDomElement* self, const gchar* uri, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_uri_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*read_from_file) (GXmlDomElement* self, GFile* f, GCancellable* cancellable, GError** error);
	void (*read_from_file_async) (GXmlDomElement* self, GFile* f, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_file_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*read_from_stream) (GXmlDomElement* self, GInputStream* istream, GCancellable* cancellable, GError** error);
	void (*read_from_stream_async) (GXmlDomElement* self, GInputStream* istream, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_stream_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*read_from_string) (GXmlDomElement* self, const gchar* str, GCancellable* cancellable, GError** error);
	void (*read_from_string_async) (GXmlDomElement* self, const gchar* str, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_string_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	gchar* (*write_string) (GXmlDomElement* self, GCancellable* cancellable, GError** error);
	void (*write_string_async) (GXmlDomElement* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gchar* (*write_string_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*write_file) (GXmlDomElement* self, GFile* f, GCancellable* cancellable, GError** error);
	void (*write_file_async) (GXmlDomElement* self, GFile* f, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_file_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*write_stream) (GXmlDomElement* self, GOutputStream* stream, GError** error);
	void (*write_stream_async) (GXmlDomElement* self, GOutputStream* stream, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_stream_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	GInputStream* (*create_stream) (GXmlDomElement* self, GError** error);
	void (*create_stream_async) (GXmlDomElement* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GInputStream* (*create_stream_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	gchar* (*get_namespace_uri) (GXmlDomElement* self);
	gchar* (*get_prefix) (GXmlDomElement* self);
	gchar* (*get_local_name) (GXmlDomElement* self);
	gchar* (*get_tag_name) (GXmlDomElement* self);
	gchar* (*get_id) (GXmlDomElement* self);
	void (*set_id) (GXmlDomElement* self, const gchar* value);
	gchar* (*get_class_name) (GXmlDomElement* self);
	void (*set_class_name) (GXmlDomElement* self, const gchar* value);
	GXmlDomTokenList* (*get_class_list) (GXmlDomElement* self);
	GXmlDomNamedNodeMap* (*get_attributes) (GXmlDomElement* self);
};

struct _GXmlDomNodeListIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNodeList* self, gint index);
	gint (*get_length) (GXmlDomNodeList* self);
};

struct _GXmlDomParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*query_selector) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomNodeList* (*query_selector_all) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomElementList* (*get_elements_by_property_value) (GXmlDomParentNode* self, const gchar* property, const gchar* value);
	GXmlDomHTMLCollection* (*get_children) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_first_element_child) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_last_element_child) (GXmlDomParentNode* self);
	gint (*get_child_element_count) (GXmlDomParentNode* self);
};

struct _GXmlDomNonElementParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element_by_id) (GXmlDomNonElementParentNode* self, const gchar* element_id, GError** error);
};

struct _GXmlDomDocumentFragmentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomCharacterDataIface {
	GTypeInterface parent_iface;
	gchar* (*substring_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*append_data) (GXmlDomCharacterData* self, const gchar* data);
	void (*insert_data) (GXmlDomCharacterData* self, gint offset, const gchar* data, GError** error);
	void (*delete_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*replace_data) (GXmlDomCharacterData* self, gint offset, gint count, const gchar* data, GError** error);
	gchar* (*get_data) (GXmlDomCharacterData* self);
	void (*set_data) (GXmlDomCharacterData* self, const gchar* value);
	gint (*get_length) (GXmlDomCharacterData* self);
};

struct _GXmlDomTextIface {
	GTypeInterface parent_iface;
	GXmlDomText* (*split_text) (GXmlDomText* self, gint offset, GError** error);
	gchar* (*get_whole_text) (GXmlDomText* self);
};

struct _GXmlDomCommentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomProcessingInstructionIface {
	GTypeInterface parent_iface;
	gchar* (*get_target) (GXmlDomProcessingInstruction* self);
};

struct _GXmlDomRangeIface {
	GTypeInterface parent_iface;
	void (*set_start) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_end) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_start_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_start_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*collapse) (GXmlDomRange* self, gboolean to_start, GError** error);
	void (*select_node) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*select_node_contents) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	gint (*compare_boundary_points) (GXmlDomRange* self, GXmlDomRangeBoundaryPoints how, GXmlDomRange* sourceRange, GError** error);
	void (*delete_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*extract_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*clone_contents) (GXmlDomRange* self, GError** error);
	void (*insert_node) (GXmlDomRange* self, GXmlDomNode* node);
	void (*surround_contents) (GXmlDomRange* self, GXmlDomNode* newParent);
	GXmlDomRange* (*clone_range) (GXmlDomRange* self);
	void (*detach) (GXmlDomRange* self);
	gboolean (*is_point_in_range) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gshort (*compare_point) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gboolean (*intersects_node) (GXmlDomRange* self, GXmlDomNode* node);
	gchar* (*to_string) (GXmlDomRange* self);
	GXmlDomNode* (*get_start_container) (GXmlDomRange* self);
	gint (*get_start_offset) (GXmlDomRange* self);
	GXmlDomNode* (*get_end_container) (GXmlDomRange* self);
	gint (*get_end_offset) (GXmlDomRange* self);
	gboolean (*get_collapsed) (GXmlDomRange* self);
	GXmlDomNode* (*get_common_ancestor_container) (GXmlDomRange* self);
};

struct _GXmlDomNodeIteratorIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*next_node) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*previous_node) (GXmlDomNodeIterator* self);
	void (*detach) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_root) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_reference_node) (GXmlDomNodeIterator* self);
	gboolean (*get_pointer_before_reference_node) (GXmlDomNodeIterator* self);
	gint (*get_what_to_show) (GXmlDomNodeIterator* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomNodeIterator* self);
};

struct _GXmlDomTreeWalkerIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*parent_node) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*first_child) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*last_child) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previous_sibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*next_sibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previous_node) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*next_node) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_root) (GXmlDomTreeWalker* self);
	gint (*get_what_to_show) (GXmlDomTreeWalker* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_current_node) (GXmlDomTreeWalker* self);
};

struct _GXmlParserIface {
	GTypeInterface parent_iface;
	void (*write_file) (GXmlParser* self, GFile* file, GError** error);
	void (*write_file_async) (GXmlParser* self, GFile* file, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_file_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	gchar* (*write_string) (GXmlParser* self, GError** error);
	void (*write_string_async) (GXmlParser* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gchar* (*write_string_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*write_stream) (GXmlParser* self, GOutputStream* stream, GError** error);
	void (*write_stream_async) (GXmlParser* self, GOutputStream* stream, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_stream_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*read_file) (GXmlParser* self, GFile* file, GError** error);
	void (*read_file_async) (GXmlParser* self, GFile* file, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_file_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*read_stream) (GXmlParser* self, GInputStream* stream, GError** error);
	void (*read_stream_async) (GXmlParser* self, GInputStream* stream, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_stream_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*read_string) (GXmlParser* self, const gchar* str, GError** error);
	void (*read_string_async) (GXmlParser* self, const gchar* str, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_string_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	GInputStream* (*create_stream) (GXmlParser* self, GError** error);
	void (*create_stream_async) (GXmlParser* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GInputStream* (*create_stream_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*read_child_nodes) (GXmlParser* self, GXmlDomNode* parent, GError** error);
	void (*read_child_nodes_async) (GXmlParser* self, GXmlDomNode* parent, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_child_nodes_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	gboolean (*read_child_node) (GXmlParser* self, GXmlDomNode* parent, GError** error);
	gboolean (*read_child_element) (GXmlParser* self, GXmlDomNode* parent, GError** error);
	gboolean (*read_element_property) (GXmlParser* self, GXmlDomNode* parent, GXmlDomNode* * element, GError** error);
	gboolean (*add_element_collection) (GXmlParser* self, GXmlDomNode* parent, GXmlDomNode* * element, GError** error);
	void (*read_child_nodes_stream) (GXmlParser* self, GInputStream* istream, GError** error);
	void (*read_child_nodes_string) (GXmlParser* self, const gchar* str, GError** error);
	gchar* (*read_unparsed) (GXmlParser* self, GError** error);
	gboolean (*move_next_node) (GXmlParser* self, GError** error);
	gboolean (*current_is_empty_element) (GXmlParser* self);
	gboolean (*current_is_element) (GXmlParser* self);
	gboolean (*current_is_document) (GXmlParser* self);
	gchar* (*current_node_name) (GXmlParser* self);
	GXmlDomElement* (*create_element) (GXmlParser* self, GXmlDomNode* parent, GError** error);
	void (*read_element) (GXmlParser* self, GXmlDomElement* element, GError** error);
	gboolean (*get_backup) (GXmlParser* self);
	void (*set_backup) (GXmlParser* self, gboolean value);
	gboolean (*get_indent) (GXmlParser* self);
	void (*set_indent) (GXmlParser* self, gboolean value);
	GCancellable* (*get_cancellable) (GXmlParser* self);
	void (*set_cancellable) (GXmlParser* self, GCancellable* value);
	GXmlDomNode* (*get_node) (GXmlParser* self);
};

struct _GXmlDomDocumentTypeIface {
	GTypeInterface parent_iface;
	const gchar* (*get_name) (GXmlDomDocumentType* self);
	const gchar* (*get_public_id) (GXmlDomDocumentType* self);
	const gchar* (*get_system_id) (GXmlDomDocumentType* self);
};

struct _GXmlDomXMLDocumentIface {
	GTypeInterface parent_iface;
};

struct _GXmlNamespaceIface {
	GTypeInterface parent_iface;
	gchar* (*get_uri) (GXmlNamespace* self);
	gchar* (*get_prefix) (GXmlNamespace* self);
};

struct _GXmlNodeIface {
	GTypeInterface parent_iface;
	GXmlNode* (*get) (GXmlNode* self, const gchar* key);
	GXmlElementList* (*get_elements_by_property_value) (GXmlNode* self, const gchar* property, const gchar* value);
	GXmlElementList* (*get_elements_by_name) (GXmlNode* self, const gchar* name);
	GXmlElementList* (*get_elements_by_name_ns) (GXmlNode* self, const gchar* name, const gchar* ns);
	gchar* (*to_string) (GXmlNode* self);
	gboolean (*set_namespace) (GXmlNode* self, const gchar* uri, const gchar* prefix);
	gchar* (*ns_prefix) (GXmlNode* self);
	gchar* (*ns_uri) (GXmlNode* self);
	GeeList* (*get_namespaces) (GXmlNode* self);
	GeeBidirList* (*get_children_nodes) (GXmlNode* self);
	GeeMap* (*get_attrs) (GXmlNode* self);
	gchar* (*get_name) (GXmlNode* self);
	gchar* (*get_value) (GXmlNode* self);
	void (*set_value) (GXmlNode* self, const gchar* value);
	GXmlNodeType (*get_type_node) (GXmlNode* self);
	GXmlDocument* (*get_document) (GXmlNode* self);
	GXmlNode* (*get_parent) (GXmlNode* self);
};

struct _GXmlDocumentIface {
	GTypeInterface parent_iface;
	GXmlNode* (*create_element) (GXmlDocument* self, const gchar* name, GError** error);
	GXmlNode* (*create_text) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_comment) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_cdata) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_pi) (GXmlDocument* self, const gchar* target, const gchar* data);
	gboolean (*save) (GXmlDocument* self, GCancellable* cancellable, GError** error);
	gboolean (*save_as) (GXmlDocument* self, GFile* f, GCancellable* cancellable, GError** error);
	gboolean (*get_indent) (GXmlDocument* self);
	void (*set_indent) (GXmlDocument* self, gboolean value);
	gboolean (*get_ns_top) (GXmlDocument* self);
	void (*set_ns_top) (GXmlDocument* self, gboolean value);
	gboolean (*get_prefix_default_ns) (GXmlDocument* self);
	void (*set_prefix_default_ns) (GXmlDocument* self, gboolean value);
	gboolean (*get_backup) (GXmlDocument* self);
	void (*set_backup) (GXmlDocument* self, gboolean value);
	GXmlNode* (*get_root) (GXmlDocument* self);
	GFile* (*get_file) (GXmlDocument* self);
	void (*set_file) (GXmlDocument* self, GFile* value);
};

struct _GXmlDomImplementationIface {
	GTypeInterface parent_iface;
	GXmlDomDocumentType* (*create_document_type) (GXmlDomImplementation* self, const gchar* qualified_name, const gchar* public_id, const gchar* system_id, GError** error);
	GXmlDomXMLDocument* (*create_document) (GXmlDomImplementation* self, const gchar* nspace, const gchar* qualified_name, GXmlDomDocumentType* doctype, GError** error);
	GXmlDocument* (*create_html_document) (GXmlDomImplementation* self, const gchar* title);
	gboolean (*has_feature) (GXmlDomImplementation* self);
};

struct _GXmlDomDocumentIface {
	GTypeInterface parent_iface;
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomDocument* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomDocument* self, const gchar* classNames);
	GXmlDomElement* (*create_element) (GXmlDomDocument* self, const gchar* local_name, GError** error);
	GXmlDomElement* (*create_element_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* qualified_name, GError** error);
	GXmlDomDocumentFragment* (*create_document_fragment) (GXmlDomDocument* self);
	GXmlDomText* (*create_text_node) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomComment* (*create_comment) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomProcessingInstruction* (*create_processing_instruction) (GXmlDomDocument* self, const gchar* target, const gchar* data, GError** error);
	GXmlDomNode* (*import_node) (GXmlDomDocument* self, GXmlDomNode* node, gboolean deep, GError** error);
	GXmlDomNode* (*adopt_node) (GXmlDomDocument* self, GXmlDomNode* node, GError** error);
	GXmlDomEvent* (*create_event) (GXmlDomDocument* self, const gchar* interface, GError** error);
	GXmlDomRange* (*create_range) (GXmlDomDocument* self);
	GXmlDomNodeIterator* (*create_node_iterator) (GXmlDomDocument* self, GXmlDomNode* root, gint whatToShow, GXmlDomNodeFilter* filter);
	GXmlDomTreeWalker* (*create_tree_walker) (GXmlDomDocument* self, GXmlDomNode* root, gint what_to_show, GXmlDomNodeFilter* filter);
	void (*write_file) (GXmlDomDocument* self, GFile* file, GCancellable* cancellable, GError** error);
	void (*write_file_async) (GXmlDomDocument* self, GFile* file, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_file_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	void (*write_stream) (GXmlDomDocument* self, GOutputStream* stream, GCancellable* cancellable, GError** error);
	void (*write_stream_async) (GXmlDomDocument* self, GOutputStream* stream, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_stream_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	GInputStream* (*create_stream) (GXmlDomDocument* self, GError** error);
	void (*create_stream_async) (GXmlDomDocument* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GInputStream* (*create_stream_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	gchar* (*write_string) (GXmlDomDocument* self, GCancellable* cancellable, GError** error);
	void (*write_string_async) (GXmlDomDocument* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gchar* (*write_string_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	void (*read_from_file) (GXmlDomDocument* self, GFile* file, GCancellable* cancellable, GError** error);
	void (*read_from_file_async) (GXmlDomDocument* self, GFile* file, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_file_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	void (*read_from_string) (GXmlDomDocument* self, const gchar* str, GCancellable* cancellable, GError** error);
	void (*read_from_string_async) (GXmlDomDocument* self, const gchar* str, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_string_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	void (*read_from_stream) (GXmlDomDocument* self, GInputStream* stream, GCancellable* cancellable, GError** error);
	void (*read_from_stream_async) (GXmlDomDocument* self, GInputStream* stream, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_stream_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	GXmlParser* (*get_xml_parser) (GXmlDomDocument* self);
	void (*set_xml_parser) (GXmlDomDocument* self, GXmlParser* parser);
	GXmlDomImplementation* (*get_implementation) (GXmlDomDocument* self);
	const gchar* (*get_url) (GXmlDomDocument* self);
	const gchar* (*get_document_uri) (GXmlDomDocument* self);
	const gchar* (*get_origin) (GXmlDomDocument* self);
	const gchar* (*get_compat_mode) (GXmlDomDocument* self);
	const gchar* (*get_character_set) (GXmlDomDocument* self);
	const gchar* (*get_content_type) (GXmlDomDocument* self);
	GXmlDomDocumentType* (*get_doctype) (GXmlDomDocument* self);
	GXmlDomElement* (*get_document_element) (GXmlDomDocument* self);
};

struct _GXmlDomNodeIface {
	GTypeInterface parent_iface;
	gboolean (*has_child_nodes) (GXmlDomNode* self);
	void (*normalize) (GXmlDomNode* self);
	gboolean (*is_equal_node) (GXmlDomNode* self, GXmlDomNode* node);
	GXmlDomNodeDocumentPosition (*compare_document_position) (GXmlDomNode* self, GXmlDomNode* other);
	gboolean (*contains) (GXmlDomNode* self, GXmlDomNode* other);
	gchar* (*lookup_prefix) (GXmlDomNode* self, const gchar* nspace);
	gchar* (*lookup_namespace_uri) (GXmlDomNode* self, const gchar* prefix);
	gboolean (*is_default_namespace) (GXmlDomNode* self, const gchar* nspace);
	GXmlDomNode* (*insert_before) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*append_child) (GXmlDomNode* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*replace_child) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*remove_child) (GXmlDomNode* self, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*clone_node) (GXmlDomNode* self, gboolean deep, GError** error);
	GXmlDomNodeNodeType (*get_node_type) (GXmlDomNode* self);
	gchar* (*get_node_name) (GXmlDomNode* self);
	const gchar* (*get_base_uri) (GXmlDomNode* self);
	GXmlDomDocument* (*get_owner_document) (GXmlDomNode* self);
	void (*set_owner_document) (GXmlDomNode* self, GXmlDomDocument* value);
	GXmlDomNode* (*get_parent_node) (GXmlDomNode* self);
	GXmlDomElement* (*get_parent_element) (GXmlDomNode* self);
	GXmlDomNodeList* (*get_child_nodes) (GXmlDomNode* self);
	GXmlDomNode* (*get_first_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_last_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_previous_sibling) (GXmlDomNode* self);
	GXmlDomNode* (*get_next_sibling) (GXmlDomNode* self);
	gchar* (*get_node_value) (GXmlDomNode* self);
	void (*set_node_value) (GXmlDomNode* self, const gchar* value);
	gchar* (*get_text_content) (GXmlDomNode* self);
	void (*set_text_content) (GXmlDomNode* self, const gchar* value);
};

struct _GXmlGNode {
	GObject parent_instance;
	GXmlGNodePrivate * priv;
	GXmlGDocument* _doc;
	xmlNode* _node;
	gchar* _base_uri;
};

struct _GXmlGNodeClass {
	GObjectClass parent_class;
	gboolean (*set_namespace) (GXmlGNode* self, const gchar* uri, const gchar* prefix);
	gchar* (*to_string) (GXmlGNode* self);
	GeeMap* (*get_attrs) (GXmlGNode* self);
	GeeBidirList* (*get_children_nodes) (GXmlGNode* self);
	GeeList* (*get_namespaces) (GXmlGNode* self);
	GXmlDocument* (*get_document) (GXmlGNode* self);
	GXmlNode* (*get_parent) (GXmlGNode* self);
	GXmlNodeType (*get_type_node) (GXmlGNode* self);
	gchar* (*get_name) (GXmlGNode* self);
	gchar* (*get_value) (GXmlGNode* self);
	void (*set_value) (GXmlGNode* self, const gchar* value);
};

struct _GXmlXPathObjectIface {
	GTypeInterface parent_iface;
	GXmlXPathObjectType (*get_object_type) (GXmlXPathObject* self);
	gboolean (*get_boolean_value) (GXmlXPathObject* self);
	const gchar* (*get_string_value) (GXmlXPathObject* self);
	gdouble (*get_number_value) (GXmlXPathObject* self);
	GXmlDomHTMLCollection* (*get_nodeset) (GXmlXPathObject* self);
};

typedef enum  {
	GXML_XPATH_ERROR_EXPRESSION_OK,
	GXML_XPATH_ERROR_NUMBER_ERROR,
	GXML_XPATH_ERROR_UNFINISHED_LITERAL_ERROR,
	GXML_XPATH_ERROR_START_LITERAL_ERROR,
	GXML_XPATH_ERROR_VARIABLE_REF_ERROR,
	GXML_XPATH_ERROR_UNDEF_VARIABLE_ERROR,
	GXML_XPATH_ERROR_INVALID_PREDICATE_ERROR,
	GXML_XPATH_ERROR_EXPR_ERROR,
	GXML_XPATH_ERROR_UNCLOSED_ERROR,
	GXML_XPATH_ERROR_UNKNOWN_FUNC_ERROR,
	GXML_XPATH_ERROR_INVALID_OPERAND,
	GXML_XPATH_ERROR_INVALID_TYPE,
	GXML_XPATH_ERROR_INVALID_ARITY,
	GXML_XPATH_ERROR_INVALID_CTXT_SIZE,
	GXML_XPATH_ERROR_INVALID_CTXT_POSITION,
	GXML_XPATH_ERROR_MEMORY_ERROR,
	GXML_XPATH_ERROR_XPTR_SYNTAX_ERROR,
	GXML_XPATH_ERROR_XPTR_RESOURCE_ERROR,
	GXML_XPATH_ERROR_XPTR_SUB_RESOURCE_ERROR,
	GXML_XPATH_ERROR_UNDEF_PREFIX_ERROR,
	GXML_XPATH_ERROR_ENCODING_ERROR,
	GXML_XPATH_ERROR_INVALID_CHAR_ERROR,
	GXML_XPATH_ERROR_INVALID_CTXT
} GXmlXPathError;
#define GXML_XPATH_ERROR gxml_xpath_error_quark ()
struct _GXmlXPathContextIface {
	GTypeInterface parent_iface;
	GXmlXPathObject* (*evaluate) (GXmlXPathContext* self, const gchar* expression, GeeList* resolver, GError** error);
};

struct _GXmlGDocument {
	GXmlGNode parent_instance;
	GXmlGDocumentPrivate * priv;
	xmlDoc* doc;
	xmlBuffer* _buffer;
	GXmlParser* _parser;
	GXmlGImplementation* _implementation;
	gchar* _url;
	gchar* _origin;
	gchar* _compat_mode;
	gchar* _character_set;
	gchar* _content_type;
	GXmlDomEvent* _constructor;
};

struct _GXmlGDocumentClass {
	GXmlGNodeClass parent_class;
	gboolean (*save) (GXmlGDocument* self, GCancellable* cancellable, GError** error);
	gboolean (*save_as) (GXmlGDocument* self, GFile* f, GCancellable* cancellable, GError** error);
};

struct _GXmlGDocumentPrivate {
	gboolean _indent;
	gboolean _ns_top;
	gboolean _prefix_default_ns;
	gboolean _backup;
	GFile* _file;
};

typedef enum  {
	GXML_DOCUMENT_ERROR_INVALID_DOCUMENT_ERROR,
	GXML_DOCUMENT_ERROR_INVALID_FILE
} GXmlDocumentError;
#define GXML_DOCUMENT_ERROR gxml_document_error_quark ()
typedef enum  {
	GXML_ERROR_NOT_SUPPORTED,
	GXML_ERROR_PARSER,
	GXML_ERROR_WRITER
} GXmlError;
#define GXML_ERROR gxml_error_quark ()
typedef enum  {
	GXML_DOM_ERROR_INDEX_SIZE_ERROR = 1,
	GXML_DOM_ERROR_DOMSTRING_SIZE_ERROR,
	GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR,
	GXML_DOM_ERROR_WRONG_DOCUMENT_ERROR,
	GXML_DOM_ERROR_INVALID_CHARACTER_ERROR,
	GXML_DOM_ERROR_NO_DATA_ALLOWED_ERROR,
	GXML_DOM_ERROR_NO_MODIFICATION_ALLOWED_ERROR,
	GXML_DOM_ERROR_NOT_FOUND_ERROR,
	GXML_DOM_ERROR_NOT_SUPPORTED_ERROR,
	GXML_DOM_ERROR_INUSE_ATTRIBUTE_ERROR,
	GXML_DOM_ERROR_INVALID_STATE_ERROR,
	GXML_DOM_ERROR_SYNTAX_ERROR,
	GXML_DOM_ERROR_INVALID_MODIFICATION_ERROR,
	GXML_DOM_ERROR_NAMESPACE_ERROR,
	GXML_DOM_ERROR_INVALID_ACCESS_ERROR,
	GXML_DOM_ERROR_VALIDATION_ERROR,
	GXML_DOM_ERROR_TYPE_MISMATCH_ERROR,
	GXML_DOM_ERROR_SECURITY_ERROR,
	GXML_DOM_ERROR_NETWORK_ERROR,
	GXML_DOM_ERROR_ABORT_ERROR,
	GXML_DOM_ERROR_URL_MISMATCH_ERROR,
	GXML_DOM_ERROR_QUOTA_EXCEEDED_ERROR,
	GXML_DOM_ERROR_TIME_OUT_ERROR,
	GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR,
	GXML_DOM_ERROR_DATA_CLONE_ERROR
} GXmlDomError;
#define GXML_DOM_ERROR gxml_dom_error_quark ()
struct _GXmlElementIface {
	GTypeInterface parent_iface;
	void (*normalize) (GXmlElement* self);
	void (*set_attr) (GXmlElement* self, const gchar* name, const gchar* value);
	GXmlNode* (*get_attr) (GXmlElement* self, const gchar* name);
	void (*remove_attr) (GXmlElement* self, const gchar* name);
	void (*remove_ns_attr) (GXmlElement* self, const gchar* name, const gchar* uri);
	void (*set_ns_attr) (GXmlElement* self, const gchar* ns, const gchar* name, const gchar* value);
	GXmlNode* (*get_ns_attr) (GXmlElement* self, const gchar* name, const gchar* uri);
	gchar* (*get_tag_name) (GXmlElement* self);
	gchar* (*get_content) (GXmlElement* self);
	void (*set_content) (GXmlElement* self, const gchar* value);
};

struct _GXmlGImplementation {
	GObject parent_instance;
	GXmlGImplementationPrivate * priv;
};

struct _GXmlGImplementationClass {
	GObjectClass parent_class;
};

struct _GXmlGChildNode {
	GXmlGNode parent_instance;
	GXmlGChildNodePrivate * priv;
};

struct _GXmlGChildNodeClass {
	GXmlGNodeClass parent_class;
};

struct _GXmlGDocumentType {
	GXmlGChildNode parent_instance;
	GXmlGDocumentTypePrivate * priv;
	gchar* _name;
	gchar* _public_id;
	gchar* _system_id;
};

struct _GXmlGDocumentTypeClass {
	GXmlGChildNodeClass parent_class;
};

struct _GXmlGDocumentFragment {
	GXmlGDocument parent_instance;
	GXmlGDocumentFragmentPrivate * priv;
};

struct _GXmlGDocumentFragmentClass {
	GXmlGDocumentClass parent_class;
};

struct _GXmlGDomNodeIterator {
	GObject parent_instance;
	GXmlGDomNodeIteratorPrivate * priv;
	GXmlDomNode* _root;
	GXmlDomNode* _reference_node;
	gboolean _pointer_before_reference_node;
	gint _what_to_show;
	GXmlDomNodeFilter* _filter;
};

struct _GXmlGDomNodeIteratorClass {
	GObjectClass parent_class;
};

struct _GXmlGDomTreeWalker {
	GObject parent_instance;
	GXmlGDomTreeWalkerPrivate * priv;
	GXmlDomNode* _root;
	gint _what_to_show;
	GXmlDomNodeFilter* _filter;
	GXmlDomNode* _current_node;
};

struct _GXmlGDomTreeWalkerClass {
	GObjectClass parent_class;
};

static gint GXmlGDocument_private_offset;
static gpointer gxml_gdocument_parent_class = NULL;
static GXmlDocumentIface * gxml_gdocument_gxml_document_parent_iface = NULL;
static GXmlDomParentNodeIface * gxml_gdocument_gxml_dom_parent_node_parent_iface = NULL;
static GXmlDomNonElementParentNodeIface * gxml_gdocument_gxml_dom_non_element_parent_node_parent_iface = NULL;
static GXmlDomDocumentIface * gxml_gdocument_gxml_dom_document_parent_iface = NULL;
static GXmlDomXMLDocumentIface * gxml_gdocument_gxml_dom_xml_document_parent_iface = NULL;
static GXmlXPathContextIface * gxml_gdocument_gxml_xpath_context_parent_iface = NULL;
static gpointer gxml_gimplementation_parent_class = NULL;
static GXmlDomImplementationIface * gxml_gimplementation_gxml_dom_implementation_parent_iface = NULL;
static gpointer gxml_gdocument_type_parent_class = NULL;
static GXmlDomNodeIface * gxml_gdocument_type_gxml_dom_node_parent_iface = NULL;
static GXmlDomChildNodeIface * gxml_gdocument_type_gxml_dom_child_node_parent_iface = NULL;
static GXmlDomDocumentTypeIface * gxml_gdocument_type_gxml_dom_document_type_parent_iface = NULL;
static gpointer gxml_gdocument_fragment_parent_class = NULL;
static GXmlDomDocumentFragmentIface * gxml_gdocument_fragment_gxml_dom_document_fragment_parent_iface = NULL;
static gpointer gxml_gdom_node_iterator_parent_class = NULL;
static GXmlDomNodeIteratorIface * gxml_gdom_node_iterator_gxml_dom_node_iterator_parent_iface = NULL;
static gpointer gxml_gdom_tree_walker_parent_class = NULL;
static GXmlDomTreeWalkerIface * gxml_gdom_tree_walker_gxml_dom_tree_walker_parent_iface = NULL;

GType gxml_dom_time_stamp_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_phase_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_listener_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_target_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_document_position_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_node_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_document_type_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_html_collection_get_type (void) G_GNUC_CONST;
GType gxml_dom_token_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_named_node_map_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_element_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_fragment_get_type (void) G_GNUC_CONST;
GType gxml_dom_character_data_get_type (void) G_GNUC_CONST;
GType gxml_dom_text_get_type (void) G_GNUC_CONST;
GType gxml_dom_comment_get_type (void) G_GNUC_CONST;
GType gxml_dom_processing_instruction_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_boundary_points_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_filter_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_iterator_get_type (void) G_GNUC_CONST;
GType gxml_dom_tree_walker_get_type (void) G_GNUC_CONST;
GType gxml_parser_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_xml_document_get_type (void) G_GNUC_CONST;
GType gxml_element_list_get_type (void) G_GNUC_CONST;
GType gxml_namespace_get_type (void) G_GNUC_CONST;
GType gxml_node_type_get_type (void) G_GNUC_CONST;
GType gxml_node_get_type (void) G_GNUC_CONST;
GType gxml_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_implementation_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_get_type (void) G_GNUC_CONST;
GType gxml_gnode_get_type (void) G_GNUC_CONST;
GType gxml_gdocument_get_type (void) G_GNUC_CONST;
GType gxml_xpath_object_type_get_type (void) G_GNUC_CONST;
GType gxml_xpath_object_get_type (void) G_GNUC_CONST;
GQuark gxml_xpath_error_quark (void);
GType gxml_xpath_context_get_type (void) G_GNUC_CONST;
GType gxml_gimplementation_get_type (void) G_GNUC_CONST;
GXmlGImplementation* gxml_gimplementation_new (void);
GXmlGImplementation* gxml_gimplementation_construct (GType object_type);
GXmlGDocument* gxml_gdocument_new (void);
GXmlGDocument* gxml_gdocument_construct (GType object_type);
GXmlGNode* gxml_gnode_construct (GType object_type);
GXmlGDocument* gxml_gdocument_new_from_path (const gchar* path,
                                             gint options,
                                             GError** error);
GXmlGDocument* gxml_gdocument_construct_from_path (GType object_type,
                                                   const gchar* path,
                                                   gint options,
                                                   GError** error);
GXmlGDocument* gxml_gdocument_new_from_file (GFile* file,
                                             gint options,
                                             GCancellable* cancel,
                                             GError** error);
GXmlGDocument* gxml_gdocument_construct_from_file (GType object_type,
                                                   GFile* file,
                                                   gint options,
                                                   GCancellable* cancel,
                                                   GError** error);
GXmlGDocument* gxml_gdocument_new_from_uri (const gchar* uri,
                                            gint options,
                                            GError** error);
GXmlGDocument* gxml_gdocument_construct_from_uri (GType object_type,
                                                  const gchar* uri,
                                                  gint options,
                                                  GError** error);
GQuark gxml_document_error_quark (void);
GType gxml_gparser_get_type (void) G_GNUC_CONST;
GXmlGParser* gxml_gparser_new (GXmlGDocument* doc);
GXmlGParser* gxml_gparser_construct (GType object_type,
                                     GXmlGDocument* doc);
void gxml_parser_set_cancellable (GXmlParser* self,
                                  GCancellable* value);
void gxml_parser_read_stream (GXmlParser* self,
                              GInputStream* stream,
                              GError** error);
GXmlGDocument* gxml_gdocument_new_from_string (const gchar* str,
                                               gint options,
                                               GError** error);
GXmlGDocument* gxml_gdocument_construct_from_string (GType object_type,
                                                     const gchar* str,
                                                     gint options,
                                                     GError** error);
void gxml_parser_read_string (GXmlParser* self,
                              const gchar* str,
                              GError** error);
GXmlGDocument* gxml_gdocument_new_from_stream (GInputStream* istream,
                                               GError** error);
GXmlGDocument* gxml_gdocument_construct_from_stream (GType object_type,
                                                     GInputStream* istream,
                                                     GError** error);
GXmlGDocument* gxml_gdocument_new_from_doc (xmlDoc* doc);
GXmlGDocument* gxml_gdocument_construct_from_doc (GType object_type,
                                                  xmlDoc* doc);
static GXmlParser* gxml_gdocument_real_gxml_dom_document_get_xml_parser (GXmlDomDocument* base);
static void gxml_gdocument_real_set_xml_parser (GXmlDomDocument* base,
                                         GXmlParser* parser);
static gboolean gxml_gdocument_real_set_namespace (GXmlGNode* base,
                                            const gchar* uri,
                                            const gchar* prefix);
static GXmlNode* gxml_gdocument_real_gxml_document_create_comment (GXmlDocument* base,
                                                            const gchar* text);
GXmlGComment* gxml_gcomment_new (GXmlGDocument* doc,
                                 xmlNode* node);
GXmlGComment* gxml_gcomment_construct (GType object_type,
                                       GXmlGDocument* doc,
                                       xmlNode* node);
GType gxml_gchild_node_get_type (void) G_GNUC_CONST;
GType gxml_gnon_document_child_node_get_type (void) G_GNUC_CONST;
GType gxml_gcharacter_data_get_type (void) G_GNUC_CONST;
GType gxml_gcomment_get_type (void) G_GNUC_CONST;
static GXmlNode* gxml_gdocument_real_create_pi (GXmlDocument* base,
                                         const gchar* target,
                                         const gchar* data);
GXmlGProcessingInstruction* gxml_gprocessing_instruction_new (GXmlGDocument* doc,
                                                              xmlNode* node);
GXmlGProcessingInstruction* gxml_gprocessing_instruction_construct (GType object_type,
                                                                    GXmlGDocument* doc,
                                                                    xmlNode* node);
GType gxml_gprocessing_instruction_get_type (void) G_GNUC_CONST;
static GXmlNode* gxml_gdocument_real_gxml_document_create_element (GXmlDocument* base,
                                                            const gchar* name,
                                                            GError** error);
gchar* gxml_gnode_libxml2_error_to_string (xmlError* e);
GQuark gxml_error_quark (void);
GXmlGElement* gxml_gelement_new (GXmlGDocument* doc,
                                 xmlNode* node);
GXmlGElement* gxml_gelement_construct (GType object_type,
                                       GXmlGDocument* doc,
                                       xmlNode* node);
GType gxml_gelement_get_type (void) G_GNUC_CONST;
static GXmlNode* gxml_gdocument_real_create_text (GXmlDocument* base,
                                           const gchar* text);
GXmlGText* gxml_gtext_new (GXmlGDocument* doc,
                           xmlNode* node);
GXmlGText* gxml_gtext_construct (GType object_type,
                                 GXmlGDocument* doc,
                                 xmlNode* node);
GType gxml_gtext_get_type (void) G_GNUC_CONST;
static GXmlNode* gxml_gdocument_real_create_cdata (GXmlDocument* base,
                                            const gchar* text);
GXmlGCDATA* gxml_gcdata_new (GXmlGDocument* doc,
                             xmlNode* node);
GXmlGCDATA* gxml_gcdata_construct (GType object_type,
                                   GXmlGDocument* doc,
                                   xmlNode* node);
GType gxml_gcdata_get_type (void) G_GNUC_CONST;
static gchar* gxml_gdocument_real_to_string (GXmlGNode* base);
void gxml_tdocument_write_document (GXmlDocument* doc,
                                    xmlTextWriter* tw,
                                    GError** error);
gchar* gxml_gdocument_libxml_to_string (GXmlGDocument* self);
gboolean gxml_gdocument_save (GXmlGDocument* self,
                              GCancellable* cancellable,
                              GError** error);
static gboolean gxml_gdocument_real_save (GXmlGDocument* self,
                                   GCancellable* cancellable,
                                   GError** error);
gboolean gxml_gdocument_save_as (GXmlGDocument* self,
                                 GFile* f,
                                 GCancellable* cancellable,
                                 GError** error);
GFile* gxml_document_get_file (GXmlDocument* self);
static gboolean gxml_gdocument_real_save_as (GXmlGDocument* self,
                                      GFile* f,
                                      GCancellable* cancellable,
                                      GError** error);
gboolean gxml_tdocument_tw_save_as (GXmlDocument* doc,
                                    GFile* f,
                                    GCancellable* cancellable,
                                    GError** error);
static GXmlDomElement* gxml_gdocument_real_gxml_dom_document_create_element (GXmlDomDocument* base,
                                                                      const gchar* local_name,
                                                                      GError** error);
GXmlNode* gxml_document_create_element (GXmlDocument* self,
                                        const gchar* name,
                                        GError** error);
static GXmlDomElement* gxml_gdocument_real_gxml_dom_document_create_element_ns (GXmlDomDocument* base,
                                                                         const gchar* ns,
                                                                         const gchar* qualified_name,
                                                                         GError** error);
GQuark gxml_dom_error_quark (void);
gboolean gxml_node_set_namespace (GXmlNode* self,
                                  const gchar* uri,
                                  const gchar* prefix);
static GXmlDomHTMLCollection* gxml_gdocument_real_get_elements_by_tag_name (GXmlDomDocument* base,
                                                                     const gchar* local_name);
GType gxml_gdom_html_collection_get_type (void) G_GNUC_CONST;
GXmlGDomHTMLCollection* gxml_gdom_html_collection_new (void);
GXmlGDomHTMLCollection* gxml_gdom_html_collection_construct (GType object_type);
GXmlDomElement* gxml_dom_document_get_document_element (GXmlDomDocument* self);
GXmlDomHTMLCollection* gxml_dom_element_get_elements_by_tag_name (GXmlDomElement* self,
                                                                  const gchar* local_name);
static GXmlDomHTMLCollection* gxml_gdocument_real_get_elements_by_tag_name_ns (GXmlDomDocument* base,
                                                                        const gchar* ns,
                                                                        const gchar* local_name);
GXmlDomHTMLCollection* gxml_dom_element_get_elements_by_tag_name_ns (GXmlDomElement* self,
                                                                     const gchar* namespace,
                                                                     const gchar* local_name);
static GXmlDomHTMLCollection* gxml_gdocument_real_get_elements_by_class_name (GXmlDomDocument* base,
                                                                       const gchar* class_names);
GXmlDomHTMLCollection* gxml_dom_element_get_elements_by_class_name (GXmlDomElement* self,
                                                                    const gchar* class_names);
static GXmlDomDocumentFragment* gxml_gdocument_real_create_document_fragment (GXmlDomDocument* base);
GXmlGDocumentFragment* gxml_gdocument_fragment_new (GXmlGDocument* d);
GXmlGDocumentFragment* gxml_gdocument_fragment_construct (GType object_type,
                                                          GXmlGDocument* d);
GType gxml_gdocument_fragment_get_type (void) G_GNUC_CONST;
static GXmlDomText* gxml_gdocument_real_create_text_node (GXmlDomDocument* base,
                                                   const gchar* data,
                                                   GError** error);
GXmlNode* gxml_document_create_text (GXmlDocument* self,
                                     const gchar* text);
static GXmlDomComment* gxml_gdocument_real_gxml_dom_document_create_comment (GXmlDomDocument* base,
                                                                      const gchar* data,
                                                                      GError** error);
GXmlNode* gxml_document_create_comment (GXmlDocument* self,
                                        const gchar* text);
static GXmlDomProcessingInstruction* gxml_gdocument_real_create_processing_instruction (GXmlDomDocument* base,
                                                                                 const gchar* target,
                                                                                 const gchar* data,
                                                                                 GError** error);
GXmlNode* gxml_document_create_pi (GXmlDocument* self,
                                   const gchar* target,
                                   const gchar* data);
static GXmlDomNode* gxml_gdocument_real_import_node (GXmlDomDocument* base,
                                              GXmlDomNode* node,
                                              gboolean deep,
                                              GError** error);
GXmlDomElement* gxml_dom_document_create_element (GXmlDomDocument* self,
                                                  const gchar* local_name,
                                                  GError** error);
gchar* gxml_dom_node_get_node_name (GXmlDomNode* self);
gboolean gxml_node_copy (GXmlDocument* doc,
                         GXmlNode* node,
                         GXmlNode* source,
                         gboolean deep);
GXmlDomNode* gxml_dom_node_append_child (GXmlDomNode* self,
                                         GXmlDomNode* node,
                                         GError** error);
GXmlDomText* gxml_dom_document_create_text_node (GXmlDomDocument* self,
                                                 const gchar* data,
                                                 GError** error);
gchar* gxml_dom_character_data_get_data (GXmlDomCharacterData* self);
GXmlDomComment* gxml_dom_document_create_comment (GXmlDomDocument* self,
                                                  const gchar* data,
                                                  GError** error);
GXmlDomProcessingInstruction* gxml_dom_document_create_processing_instruction (GXmlDomDocument* self,
                                                                               const gchar* target,
                                                                               const gchar* data,
                                                                               GError** error);
gchar* gxml_dom_processing_instruction_get_target (GXmlDomProcessingInstruction* self);
static GXmlDomNode* gxml_gdocument_real_adopt_node (GXmlDomDocument* base,
                                             GXmlDomNode* node,
                                             GError** error);
GXmlDomDocument* gxml_dom_node_get_owner_document (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_parent_node (GXmlDomNode* self);
GXmlDomNodeList* gxml_dom_node_get_child_nodes (GXmlDomNode* self);
static GXmlDomEvent* gxml_gdocument_real_create_event (GXmlDomDocument* base,
                                                const gchar* iface,
                                                GError** error);
GXmlGDomCustomEvent* gxml_gdom_custom_event_new (void);
GXmlGDomCustomEvent* gxml_gdom_custom_event_construct (GType object_type);
GType gxml_gdom_event_get_type (void) G_GNUC_CONST;
GType gxml_gdom_custom_event_get_type (void) G_GNUC_CONST;
static GXmlDomRange* gxml_gdocument_real_create_range (GXmlDomDocument* base);
GXmlGDomRange* gxml_gdom_range_new (GXmlDomDocument* doc);
GXmlGDomRange* gxml_gdom_range_construct (GType object_type,
                                          GXmlDomDocument* doc);
GType gxml_gdom_range_get_type (void) G_GNUC_CONST;
static GXmlDomNodeIterator* gxml_gdocument_real_create_node_iterator (GXmlDomDocument* base,
                                                               GXmlDomNode* root,
                                                               gint what_to_show,
                                                               GXmlDomNodeFilter* filter);
GXmlGDomNodeIterator* gxml_gdom_node_iterator_new (GXmlDomNode* n,
                                                   gint what_to_show,
                                                   GXmlDomNodeFilter* filter);
GXmlGDomNodeIterator* gxml_gdom_node_iterator_construct (GType object_type,
                                                         GXmlDomNode* n,
                                                         gint what_to_show,
                                                         GXmlDomNodeFilter* filter);
GType gxml_gdom_node_iterator_get_type (void) G_GNUC_CONST;
static GXmlDomTreeWalker* gxml_gdocument_real_create_tree_walker (GXmlDomDocument* base,
                                                           GXmlDomNode* root,
                                                           gint what_to_show,
                                                           GXmlDomNodeFilter* filter);
GXmlGDomTreeWalker* gxml_gdom_tree_walker_new (GXmlDomNode* r,
                                               gint w,
                                               GXmlDomNodeFilter* f);
GXmlGDomTreeWalker* gxml_gdom_tree_walker_construct (GType object_type,
                                                     GXmlDomNode* r,
                                                     gint w,
                                                     GXmlDomNodeFilter* f);
GType gxml_gdom_tree_walker_get_type (void) G_GNUC_CONST;
static GXmlDomNodeList* gxml_gdocument_real_query_selector_all (GXmlDomParentNode* base,
                                                         const gchar* selectors,
                                                         GError** error);
GType gxml_css_selector_parser_get_type (void) G_GNUC_CONST;
GXmlCssSelectorParser* gxml_css_selector_parser_new (void);
GXmlCssSelectorParser* gxml_css_selector_parser_construct (GType object_type);
void gxml_css_selector_parser_parse (GXmlCssSelectorParser* self,
                                     const gchar* selectors,
                                     GError** error);
GType gxml_gom_node_list_get_type (void) G_GNUC_CONST;
GXmlGomNodeList* gxml_gom_node_list_new (void);
GXmlGomNodeList* gxml_gom_node_list_construct (GType object_type);
GeeBidirList* gxml_gnode_get_children_nodes (GXmlGNode* self);
gboolean gxml_css_selector_parser_match (GXmlCssSelectorParser* self,
                                         GXmlDomElement* element,
                                         GError** error);
GXmlDomNodeList* gxml_css_selector_parser_query_selector_all (GXmlCssSelectorParser* self,
                                                              GXmlDomElement* element,
                                                              GError** error);
static GXmlDomElement* gxml_gdocument_real_get_element_by_id (GXmlDomNonElementParentNode* base,
                                                       const gchar* element_id,
                                                       GError** error);
GXmlDomElementList* gxml_dom_parent_node_get_elements_by_property_value (GXmlDomParentNode* self,
                                                                         const gchar* property,
                                                                         const gchar* value);
static GXmlXPathObject* gxml_gdocument_real_evaluate (GXmlXPathContext* base,
                                               const gchar* expression,
                                               GeeList* resolver,
                                               GError** error);
GXmlXPathObject* gxml_xpath_context_evaluate (GXmlXPathContext* self,
                                              const gchar* expression,
                                              GeeList* resolver,
                                              GError** error);
GXmlGHashMapAttr* gxml_ghash_map_attr_new (GXmlGDocument* doc,
                                           xmlNode* node);
GXmlGHashMapAttr* gxml_ghash_map_attr_construct (GType object_type,
                                                 GXmlGDocument* doc,
                                                 xmlNode* node);
GType gxml_ghash_map_attr_get_type (void) G_GNUC_CONST;
GXmlGListChildren* gxml_glist_children_new (GXmlGDocument* doc,
                                            xmlNode* node);
GXmlGListChildren* gxml_glist_children_construct (GType object_type,
                                                  GXmlGDocument* doc,
                                                  xmlNode* node);
GType gxml_glist_children_get_type (void) G_GNUC_CONST;
GXmlGListNamespaces* gxml_glist_namespaces_new (GXmlGDocument* doc,
                                                xmlNode* node);
GXmlGListNamespaces* gxml_glist_namespaces_construct (GType object_type,
                                                      GXmlGDocument* doc,
                                                      xmlNode* node);
GType gxml_glist_namespaces_get_type (void) G_GNUC_CONST;
GType gxml_element_get_type (void) G_GNUC_CONST;
GXmlNode* gxml_document_get_root (GXmlDocument* self);
GXmlDomElementList* gxml_dom_element_list_new (void);
GXmlDomElementList* gxml_dom_element_list_construct (GType object_type);
GeeBidirList* gxml_node_get_children_nodes (GXmlNode* self);
static void gxml_gdocument_finalize (GObject * obj);
GeeMap* gxml_gnode_get_attrs (GXmlGNode* self);
GeeList* gxml_gnode_get_namespaces (GXmlGNode* self);
GXmlDocument* gxml_gnode_get_document (GXmlGNode* self);
gboolean gxml_document_get_indent (GXmlDocument* self);
gboolean gxml_document_get_ns_top (GXmlDocument* self);
gboolean gxml_document_get_prefix_default_ns (GXmlDocument* self);
gboolean gxml_document_get_backup (GXmlDocument* self);
GXmlDomImplementation* gxml_dom_document_get_implementation (GXmlDomDocument* self);
const gchar* gxml_dom_document_get_url (GXmlDomDocument* self);
const gchar* gxml_dom_document_get_document_uri (GXmlDomDocument* self);
const gchar* gxml_dom_document_get_origin (GXmlDomDocument* self);
const gchar* gxml_dom_document_get_compat_mode (GXmlDomDocument* self);
const gchar* gxml_dom_document_get_character_set (GXmlDomDocument* self);
const gchar* gxml_dom_document_get_content_type (GXmlDomDocument* self);
GXmlDomDocumentType* gxml_dom_document_get_doctype (GXmlDomDocument* self);
GXmlDomHTMLCollection* gxml_dom_parent_node_get_children (GXmlDomParentNode* self);
GXmlDomElement* gxml_dom_parent_node_get_first_element_child (GXmlDomParentNode* self);
GXmlDomElement* gxml_dom_parent_node_get_last_element_child (GXmlDomParentNode* self);
gint gxml_dom_parent_node_get_child_element_count (GXmlDomParentNode* self);
static void _vala_gxml_gdocument_get_property (GObject * object,
                                        guint property_id,
                                        GValue * value,
                                        GParamSpec * pspec);
void gxml_document_set_indent (GXmlDocument* self,
                               gboolean value);
void gxml_document_set_ns_top (GXmlDocument* self,
                               gboolean value);
void gxml_document_set_prefix_default_ns (GXmlDocument* self,
                                          gboolean value);
void gxml_document_set_backup (GXmlDocument* self,
                               gboolean value);
void gxml_document_set_file (GXmlDocument* self,
                             GFile* value);
static void _vala_gxml_gdocument_set_property (GObject * object,
                                        guint property_id,
                                        const GValue * value,
                                        GParamSpec * pspec);
static GXmlDomDocumentType* gxml_gimplementation_real_create_document_type (GXmlDomImplementation* base,
                                                                     const gchar* qualified_name,
                                                                     const gchar* public_id,
                                                                     const gchar* system_id,
                                                                     GError** error);
GXmlGDocumentType* gxml_gdocument_type_new_with_ids (const gchar* name,
                                                     const gchar* public_id,
                                                     const gchar* system_id);
GXmlGDocumentType* gxml_gdocument_type_construct_with_ids (GType object_type,
                                                           const gchar* name,
                                                           const gchar* public_id,
                                                           const gchar* system_id);
GType gxml_gdocument_type_get_type (void) G_GNUC_CONST;
static GXmlDomXMLDocument* gxml_gimplementation_real_create_document (GXmlDomImplementation* base,
                                                               const gchar* namespace,
                                                               const gchar* qualified_name,
                                                               GXmlDomDocumentType* doctype,
                                                               GError** error);
static GXmlDocument* gxml_gimplementation_real_create_html_document (GXmlDomImplementation* base,
                                                              const gchar* title);
GXmlGHtmlDocument* gxml_ghtml_document_new (void);
GXmlGHtmlDocument* gxml_ghtml_document_construct (GType object_type);
GType gxml_ghtml_document_get_type (void) G_GNUC_CONST;
GXmlGDocumentType* gxml_gdocument_type_new_with_name (const gchar* name);
GXmlGDocumentType* gxml_gdocument_type_construct_with_name (GType object_type,
                                                            const gchar* name);
GXmlGChildNode* gxml_gchild_node_new (void);
GXmlGChildNode* gxml_gchild_node_construct (GType object_type);
static void gxml_gdocument_type_real_remove (GXmlDomChildNode* base);
xmlNode* gxml_gnode_get_internal_node (GXmlGNode* self);
GXmlGDocumentType* gxml_gdocument_type_new (void);
GXmlGDocumentType* gxml_gdocument_type_construct (GType object_type);
GXmlDomNodeNodeType gxml_dom_node_get_node_type (GXmlDomNode* self);
const gchar* gxml_dom_node_get_base_uri (GXmlDomNode* self);
void gxml_dom_node_set_owner_document (GXmlDomNode* self,
                                       GXmlDomDocument* value);
GXmlDomElement* gxml_dom_node_get_parent_element (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_first_child (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_last_child (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_previous_sibling (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_next_sibling (GXmlDomNode* self);
gchar* gxml_dom_node_get_node_value (GXmlDomNode* self);
void gxml_dom_node_set_node_value (GXmlDomNode* self,
                                   const gchar* value);
gchar* gxml_dom_node_get_text_content (GXmlDomNode* self);
void gxml_dom_node_set_text_content (GXmlDomNode* self,
                                     const gchar* value);
static void gxml_gdocument_type_finalize (GObject * obj);
const gchar* gxml_dom_document_type_get_name (GXmlDomDocumentType* self);
const gchar* gxml_dom_document_type_get_public_id (GXmlDomDocumentType* self);
const gchar* gxml_dom_document_type_get_system_id (GXmlDomDocumentType* self);
static void _vala_gxml_gdocument_type_get_property (GObject * object,
                                             guint property_id,
                                             GValue * value,
                                             GParamSpec * pspec);
static GXmlDomNode* gxml_gdom_node_iterator_real_next_node (GXmlDomNodeIterator* base);
static GXmlDomNode* gxml_gdom_node_iterator_real_previous_node (GXmlDomNodeIterator* base);
static void gxml_gdom_node_iterator_real_detach (GXmlDomNodeIterator* base);
static void gxml_gdom_node_iterator_finalize (GObject * obj);
static void _vala_gxml_gdom_node_iterator_get_property (GObject * object,
                                                 guint property_id,
                                                 GValue * value,
                                                 GParamSpec * pspec);
static GXmlDomNode* gxml_gdom_tree_walker_real_parent_node (GXmlDomTreeWalker* base);
static GXmlDomNode* gxml_gdom_tree_walker_real_first_child (GXmlDomTreeWalker* base);
static GXmlDomNode* gxml_gdom_tree_walker_real_last_child (GXmlDomTreeWalker* base);
static GXmlDomNode* gxml_gdom_tree_walker_real_previous_sibling (GXmlDomTreeWalker* base);
static GXmlDomNode* gxml_gdom_tree_walker_real_next_sibling (GXmlDomTreeWalker* base);
static GXmlDomNode* gxml_gdom_tree_walker_real_previous_node (GXmlDomTreeWalker* base);
static GXmlDomNode* gxml_gdom_tree_walker_real_next_node (GXmlDomTreeWalker* base);
GXmlDomNode* gxml_dom_tree_walker_get_root (GXmlDomTreeWalker* self);
static void gxml_gdom_tree_walker_finalize (GObject * obj);
gint gxml_dom_tree_walker_get_what_to_show (GXmlDomTreeWalker* self);
GXmlDomNodeFilter* gxml_dom_tree_walker_get_filter (GXmlDomTreeWalker* self);
GXmlDomNode* gxml_dom_tree_walker_get_current_node (GXmlDomTreeWalker* self);
static void _vala_gxml_gdom_tree_walker_get_property (GObject * object,
                                               guint property_id,
                                               GValue * value,
                                               GParamSpec * pspec);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);

static inline gpointer
gxml_gdocument_get_instance_private (GXmlGDocument* self)
{
	return G_STRUCT_MEMBER_P (self, GXmlGDocument_private_offset);
}

GXmlGDocument*
gxml_gdocument_construct (GType object_type)
{
	GXmlGDocument * self = NULL;
	xmlDoc* _tmp0_;
	self = (GXmlGDocument*) gxml_gnode_construct (object_type);
	_tmp0_ = xmlNewDoc ((xmlChar*) NULL);
	self->doc = _tmp0_;
	return self;
}

GXmlGDocument*
gxml_gdocument_new (void)
{
	return gxml_gdocument_construct (GXML_TYPE_GDOCUMENT);
}

GXmlGDocument*
gxml_gdocument_construct_from_path (GType object_type,
                                    const gchar* path,
                                    gint options,
                                    GError** error)
{
	GXmlGDocument * self = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
	GError* _inner_error0_ = NULL;
	g_return_val_if_fail (path != NULL, NULL);
	_tmp0_ = g_file_new_for_path (path);
	_tmp1_ = _tmp0_;
	self = (GXmlGDocument*) gxml_gdocument_construct_from_file (object_type, _tmp1_, options, NULL, &_inner_error0_);
	_g_object_unref0 (_tmp1_);
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (self);
		return NULL;
	}
	return self;
}

GXmlGDocument*
gxml_gdocument_new_from_path (const gchar* path,
                              gint options,
                              GError** error)
{
	return gxml_gdocument_construct_from_path (GXML_TYPE_GDOCUMENT, path, options, error);
}

GXmlGDocument*
gxml_gdocument_construct_from_uri (GType object_type,
                                   const gchar* uri,
                                   gint options,
                                   GError** error)
{
	GXmlGDocument * self = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
	GError* _inner_error0_ = NULL;
	g_return_val_if_fail (uri != NULL, NULL);
	_tmp0_ = g_file_new_for_uri (uri);
	_tmp1_ = _tmp0_;
	self = (GXmlGDocument*) gxml_gdocument_construct_from_file (object_type, _tmp1_, options, NULL, &_inner_error0_);
	_g_object_unref0 (_tmp1_);
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (self);
		return NULL;
	}
	return self;
}

GXmlGDocument*
gxml_gdocument_new_from_uri (const gchar* uri,
                             gint options,
                             GError** error)
{
	return gxml_gdocument_construct_from_uri (GXML_TYPE_GDOCUMENT, uri, options, error);
}

GXmlGDocument*
gxml_gdocument_construct_from_file (GType object_type,
                                    GFile* file,
                                    gint options,
                                    GCancellable* cancel,
                                    GError** error)
{
	GXmlGDocument * self = NULL;
	GXmlGParser* parser = NULL;
	GXmlGParser* _tmp1_;
	GXmlGParser* _tmp2_;
	GFileInputStream* _tmp3_ = NULL;
	GFileInputStream* _tmp4_;
	GXmlGParser* _tmp5_;
	GError* _inner_error0_ = NULL;
	g_return_val_if_fail (file != NULL, NULL);
	self = (GXmlGDocument*) gxml_gnode_construct (object_type);
	if (!g_file_query_exists (file, NULL)) {
		GError* _tmp0_;
		_tmp0_ = g_error_new_literal (GXML_DOCUMENT_ERROR, GXML_DOCUMENT_ERROR_INVALID_DOCUMENT_ERROR, _ ("File doesn't exist"));
		_inner_error0_ = _tmp0_;
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (self);
		return NULL;
	}
	_tmp1_ = gxml_gparser_new (self);
	parser = _tmp1_;
	_tmp2_ = parser;
	gxml_parser_set_cancellable ((GXmlParser*) _tmp2_, cancel);
	_tmp4_ = g_file_read (file, NULL, &_inner_error0_);
	_tmp3_ = _tmp4_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (parser);
		_g_object_unref0 (self);
		return NULL;
	}
	_tmp5_ = parser;
	gxml_parser_read_stream ((GXmlParser*) _tmp5_, (GInputStream*) _tmp3_, &_inner_error0_);
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (_tmp3_);
		_g_object_unref0 (parser);
		_g_object_unref0 (self);
		return NULL;
	}
	_g_object_unref0 (_tmp3_);
	_g_object_unref0 (parser);
	return self;
}

GXmlGDocument*
gxml_gdocument_new_from_file (GFile* file,
                              gint options,
                              GCancellable* cancel,
                              GError** error)
{
	return gxml_gdocument_construct_from_file (GXML_TYPE_GDOCUMENT, file, options, cancel, error);
}

GXmlGDocument*
gxml_gdocument_construct_from_string (GType object_type,
                                      const gchar* str,
                                      gint options,
                                      GError** error)
{
	GXmlGDocument * self = NULL;
	GXmlGParser* parser = NULL;
	GXmlGParser* _tmp0_;
	GError* _inner_error0_ = NULL;
	g_return_val_if_fail (str != NULL, NULL);
	self = (GXmlGDocument*) gxml_gnode_construct (object_type);
	_tmp0_ = gxml_gparser_new (self);
	parser = _tmp0_;
	gxml_parser_read_string ((GXmlParser*) parser, str, &_inner_error0_);
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (parser);
		_g_object_unref0 (self);
		return NULL;
	}
	_g_object_unref0 (parser);
	return self;
}

GXmlGDocument*
gxml_gdocument_new_from_string (const gchar* str,
                                gint options,
                                GError** error)
{
	return gxml_gdocument_construct_from_string (GXML_TYPE_GDOCUMENT, str, options, error);
}

GXmlGDocument*
gxml_gdocument_construct_from_stream (GType object_type,
                                      GInputStream* istream,
                                      GError** error)
{
	GXmlGDocument * self = NULL;
	GXmlGParser* parser = NULL;
	GXmlGParser* _tmp0_;
	GError* _inner_error0_ = NULL;
	g_return_val_if_fail (istream != NULL, NULL);
	self = (GXmlGDocument*) gxml_gnode_construct (object_type);
	_tmp0_ = gxml_gparser_new (self);
	parser = _tmp0_;
	gxml_parser_read_stream ((GXmlParser*) parser, istream, &_inner_error0_);
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (parser);
		_g_object_unref0 (self);
		return NULL;
	}
	_g_object_unref0 (parser);
	return self;
}

GXmlGDocument*
gxml_gdocument_new_from_stream (GInputStream* istream,
                                GError** error)
{
	return gxml_gdocument_construct_from_stream (GXML_TYPE_GDOCUMENT, istream, error);
}

GXmlGDocument*
gxml_gdocument_construct_from_doc (GType object_type,
                                   xmlDoc* doc)
{
	GXmlGDocument * self = NULL;
	g_return_val_if_fail (doc != NULL, NULL);
	self = (GXmlGDocument*) gxml_gnode_construct (object_type);
	self->doc = doc;
	return self;
}

GXmlGDocument*
gxml_gdocument_new_from_doc (xmlDoc* doc)
{
	return gxml_gdocument_construct_from_doc (GXML_TYPE_GDOCUMENT, doc);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static GXmlParser*
gxml_gdocument_real_gxml_dom_document_get_xml_parser (GXmlDomDocument* base)
{
	GXmlGDocument * self;
	GXmlParser* result = NULL;
	GXmlParser* _tmp0_;
	GXmlGParser* _tmp3_;
	self = (GXmlGDocument*) base;
	_tmp0_ = self->_parser;
	if (_tmp0_ != NULL) {
		GXmlParser* _tmp1_;
		GXmlParser* _tmp2_;
		_tmp1_ = self->_parser;
		_tmp2_ = _g_object_ref0 (_tmp1_);
		result = _tmp2_;
		return result;
	}
	_tmp3_ = gxml_gparser_new (self);
	result = (GXmlParser*) _tmp3_;
	return result;
}

static void
gxml_gdocument_real_set_xml_parser (GXmlDomDocument* base,
                                    GXmlParser* parser)
{
	GXmlGDocument * self;
	GXmlParser* _tmp0_;
	self = (GXmlGDocument*) base;
	g_return_if_fail (parser != NULL);
	_tmp0_ = _g_object_ref0 (parser);
	_g_object_unref0 (self->_parser);
	self->_parser = _tmp0_;
}

static gboolean
gxml_gdocument_real_set_namespace (GXmlGNode* base,
                                   const gchar* uri,
                                   const gchar* prefix)
{
	GXmlGDocument * self;
	gboolean result = FALSE;
	xmlNode* root = NULL;
	xmlDoc* _tmp0_;
	xmlNode* _tmp1_;
	xmlNode* _tmp2_;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (uri != NULL, FALSE);
	_tmp0_ = self->doc;
	_tmp1_ = xmlDocGetRootElement (_tmp0_);
	root = _tmp1_;
	_tmp2_ = root;
	if (_tmp2_ != NULL) {
		xmlNs* ns = NULL;
		xmlNode* _tmp3_;
		xmlNs* _tmp4_;
		xmlNs* _tmp5_;
		_tmp3_ = root;
		_tmp4_ = xmlNewNs (_tmp3_, (xmlChar*) uri, (xmlChar*) prefix);
		ns = _tmp4_;
		_tmp5_ = ns;
		result = _tmp5_ != NULL;
		return result;
	}
	result = FALSE;
	return result;
}

static GXmlNode*
gxml_gdocument_real_gxml_document_create_comment (GXmlDocument* base,
                                                  const gchar* text)
{
	GXmlGDocument * self;
	GXmlNode* result = NULL;
	xmlNode* c = NULL;
	xmlDoc* _tmp0_;
	xmlNode* _tmp1_;
	GXmlGComment* _tmp2_;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (text != NULL, NULL);
	_tmp0_ = self->doc;
	_tmp1_ = xmlNewDocComment (_tmp0_, (xmlChar*) text);
	c = _tmp1_;
	_tmp2_ = gxml_gcomment_new (self, c);
	result = (GXmlNode*) _tmp2_;
	return result;
}

static GXmlNode*
gxml_gdocument_real_create_pi (GXmlDocument* base,
                               const gchar* target,
                               const gchar* data)
{
	GXmlGDocument * self;
	GXmlNode* result = NULL;
	xmlNode* pi = NULL;
	xmlDoc* _tmp0_;
	xmlNode* _tmp1_;
	GXmlGProcessingInstruction* _tmp2_;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (target != NULL, NULL);
	g_return_val_if_fail (data != NULL, NULL);
	_tmp0_ = self->doc;
	_tmp1_ = xmlNewDocPI (_tmp0_, (xmlChar*) target, (xmlChar*) data);
	pi = _tmp1_;
	_tmp2_ = gxml_gprocessing_instruction_new (self, pi);
	result = (GXmlNode*) _tmp2_;
	return result;
}

static GXmlNode*
gxml_gdocument_real_gxml_document_create_element (GXmlDocument* base,
                                                  const gchar* name,
                                                  GError** error)
{
	GXmlGDocument * self;
	GXmlNode* result = NULL;
	xmlNode* el = NULL;
	xmlDoc* _tmp0_;
	xmlNode* _tmp1_;
	xmlError* e = NULL;
	xmlError* _tmp2_;
	xmlError* _tmp3_;
	xmlNode* _tmp11_;
	GXmlGElement* _tmp12_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (name != NULL, NULL);
	xmlResetLastError ();
	_tmp0_ = self->doc;
	_tmp1_ = xmlNewDocRawNode (_tmp0_, NULL, (xmlChar*) name, (xmlChar*) NULL);
	el = _tmp1_;
	_tmp2_ = xmlGetLastError ();
	e = _tmp2_;
	_tmp3_ = e;
	if (_tmp3_ != NULL) {
		gchar* errmsg = NULL;
		gchar* _tmp4_;
		gchar* s = NULL;
		xmlError* _tmp5_;
		gchar* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp9_;
		GError* _tmp10_;
		_tmp4_ = g_strdup ("Parser Error for string");
		errmsg = _tmp4_;
		_tmp5_ = e;
		_tmp6_ = gxml_gnode_libxml2_error_to_string (_tmp5_);
		s = _tmp6_;
		_tmp7_ = s;
		if (_tmp7_ != NULL) {
			gchar* _tmp8_;
			_tmp8_ = g_strdup (".  ");
			_g_free0 (errmsg);
			errmsg = _tmp8_;
		}
		_tmp9_ = errmsg;
		_tmp10_ = g_error_new_literal (GXML_ERROR, GXML_ERROR_PARSER, _tmp9_);
		_inner_error0_ = _tmp10_;
		g_propagate_error (error, _inner_error0_);
		_g_free0 (s);
		_g_free0 (errmsg);
		return NULL;
	}
	_tmp11_ = el;
	_tmp12_ = gxml_gelement_new (self, _tmp11_);
	result = (GXmlNode*) _tmp12_;
	return result;
}

static GXmlNode*
gxml_gdocument_real_create_text (GXmlDocument* base,
                                 const gchar* text)
{
	GXmlGDocument * self;
	GXmlNode* result = NULL;
	xmlNode* t = NULL;
	xmlDoc* _tmp0_;
	xmlNode* _tmp1_;
	GXmlGText* _tmp2_;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (text != NULL, NULL);
	_tmp0_ = self->doc;
	_tmp1_ = xmlNewDocText (_tmp0_, (xmlChar*) text);
	t = _tmp1_;
	_tmp2_ = gxml_gtext_new (self, t);
	result = (GXmlNode*) _tmp2_;
	return result;
}

static GXmlNode*
gxml_gdocument_real_create_cdata (GXmlDocument* base,
                                  const gchar* text)
{
	GXmlGDocument * self;
	GXmlNode* result = NULL;
	xmlNode* cd = NULL;
	xmlDoc* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	xmlNode* _tmp3_;
	GXmlGCDATA* _tmp4_;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (text != NULL, NULL);
	_tmp0_ = self->doc;
	_tmp1_ = strlen (text);
	_tmp2_ = _tmp1_;
	_tmp3_ = xmlNewCDataBlock (_tmp0_, (xmlChar*) text, _tmp2_);
	cd = _tmp3_;
	_tmp4_ = gxml_gcdata_new (self, cd);
	result = (GXmlNode*) _tmp4_;
	return result;
}

static gchar*
gxml_gdocument_real_to_string (GXmlGNode* base)
{
	GXmlGDocument * self;
	gchar* result = NULL;
	xmlDoc* doc = NULL;
	xmlTextWriter* tw = NULL;
	xmlTextWriter* _tmp0_;
	gchar* str = NULL;
	gint size = 0;
	xmlDoc* _tmp3_;
	gchar* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	GError* _inner_error0_ = NULL;
	self = (GXmlGDocument*) base;
	doc = NULL;
	_tmp0_ = xmlNewTextWriterDoc (&doc, FALSE);
	tw = _tmp0_;
	{
		xmlTextWriter* _tmp1_;
		_tmp1_ = tw;
		gxml_tdocument_write_document ((GXmlDocument*) self, _tmp1_, &_inner_error0_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch10_g_error;
		}
	}
	goto __finally10;
	__catch10_g_error:
	{
		gchar* _tmp2_;
		g_clear_error (&_inner_error0_);
		_inner_error0_ = NULL;
		_tmp2_ = g_strdup ("<?xml version=\"0\"?>");
		result = _tmp2_;
		_xmlFreeTextWriter0 (tw);
		_xmlFreeDoc0 (doc);
		return result;
	}
	__finally10:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		_xmlFreeTextWriter0 (tw);
		_xmlFreeDoc0 (doc);
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return NULL;
	}
	_tmp3_ = doc;
	xmlDocDumpMemory (_tmp3_, (xmlChar**) (&_tmp4_), &_tmp5_);
	_g_free0 (str);
	str = _tmp4_;
	size = _tmp5_;
	result = str;
	_xmlFreeTextWriter0 (tw);
	_xmlFreeDoc0 (doc);
	return result;
}

/**
   * Uses libxml2 internal dump to memory function over owned 
   */
gchar*
gxml_gdocument_libxml_to_string (GXmlGDocument* self)
{
	gchar* result = NULL;
	gchar* buffer = NULL;
	xmlDoc* _tmp0_;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->doc;
	xmlDocDumpMemory (_tmp0_, (xmlChar**) (&_tmp1_), NULL);
	_g_free0 (buffer);
	buffer = _tmp1_;
	_tmp2_ = g_strdup (buffer);
	result = _tmp2_;
	_g_free0 (buffer);
	return result;
}

static gboolean
gxml_gdocument_real_save (GXmlGDocument* self,
                          GCancellable* cancellable,
                          GError** error)
{
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	GFile* _tmp1_;
	GFile* _tmp2_;
	GError* _inner_error0_ = NULL;
	_tmp1_ = gxml_document_get_file ((GXmlDocument*) self);
	_tmp2_ = _tmp1_;
	_tmp0_ = gxml_gdocument_save_as (self, _tmp2_, cancellable, &_inner_error0_);
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		gboolean _tmp3_ = FALSE;
		g_propagate_error (error, _inner_error0_);
		return _tmp3_;
	}
	result = _tmp0_;
	return result;
}

gboolean
gxml_gdocument_save (GXmlGDocument* self,
                     GCancellable* cancellable,
                     GError** error)
{
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_GDOCUMENT_GET_CLASS (self)->save (self, cancellable, error);
}

static gboolean
gxml_gdocument_real_save_as (GXmlGDocument* self,
                             GFile* f,
                             GCancellable* cancellable,
                             GError** error)
{
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	GError* _inner_error0_ = NULL;
	g_return_val_if_fail (f != NULL, FALSE);
	_tmp0_ = gxml_tdocument_tw_save_as ((GXmlDocument*) self, f, cancellable, &_inner_error0_);
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		gboolean _tmp1_ = FALSE;
		g_propagate_error (error, _inner_error0_);
		return _tmp1_;
	}
	result = _tmp0_;
	return result;
}

gboolean
gxml_gdocument_save_as (GXmlGDocument* self,
                        GFile* f,
                        GCancellable* cancellable,
                        GError** error)
{
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_GDOCUMENT_GET_CLASS (self)->save_as (self, f, cancellable, error);
}

static GXmlDomElement*
gxml_gdocument_real_gxml_dom_document_create_element (GXmlDomDocument* base,
                                                      const gchar* local_name,
                                                      GError** error)
{
	GXmlGDocument * self;
	GXmlDomElement* result = NULL;
	GXmlNode* _tmp0_ = NULL;
	GXmlNode* _tmp1_;
	GXmlDomElement* _tmp2_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (local_name != NULL, NULL);
	_tmp1_ = gxml_document_create_element (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOCUMENT) ? ((GXmlDocument*) self) : NULL, local_name, &_inner_error0_);
	_tmp0_ = _tmp1_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement));
	result = _tmp2_;
	_g_object_unref0 (_tmp0_);
	return result;
}

static gboolean
string_contains (const gchar* self,
                 const gchar* needle)
{
	gboolean result = FALSE;
	gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, FALSE);
	g_return_val_if_fail (needle != NULL, FALSE);
	_tmp0_ = strstr ((gchar*) self, (gchar*) needle);
	result = _tmp0_ != NULL;
	return result;
}

static GXmlDomElement*
gxml_gdocument_real_gxml_dom_document_create_element_ns (GXmlDomDocument* base,
                                                         const gchar* ns,
                                                         const gchar* qualified_name,
                                                         GError** error)
{
	GXmlGDocument * self;
	GXmlDomElement* result = NULL;
	gchar* prefix = NULL;
	gchar* qname = NULL;
	gchar* _tmp0_;
	GXmlNode* e = NULL;
	const gchar* _tmp11_;
	GXmlNode* _tmp12_;
	const gchar* _tmp13_;
	GXmlDomElement* _tmp14_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (qualified_name != NULL, NULL);
	prefix = NULL;
	_tmp0_ = g_strdup (qualified_name);
	qname = _tmp0_;
	if (string_contains (qualified_name, ":")) {
		gchar** s = NULL;
		gchar** _tmp1_;
		gchar** _tmp2_;
		gint s_length1;
		gint _s_size_;
		gchar** _tmp3_;
		gint _tmp3__length1;
		gchar** _tmp5_;
		gint _tmp5__length1;
		const gchar* _tmp6_;
		gchar* _tmp7_;
		gchar** _tmp8_;
		gint _tmp8__length1;
		const gchar* _tmp9_;
		gchar* _tmp10_;
		_tmp2_ = _tmp1_ = g_strsplit (qualified_name, ":", 0);
		s = _tmp2_;
		s_length1 = _vala_array_length (_tmp1_);
		_s_size_ = s_length1;
		_tmp3_ = s;
		_tmp3__length1 = s_length1;
		if (_tmp3__length1 != 2) {
			GError* _tmp4_;
			_tmp4_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INVALID_CHARACTER_ERROR, _ ("Invalid element qualified name: multiple namespace prefixes"));
			_inner_error0_ = _tmp4_;
			g_propagate_error (error, _inner_error0_);
			s = (_vala_array_free (s, s_length1, (GDestroyNotify) g_free), NULL);
			_g_free0 (qname);
			_g_free0 (prefix);
			return NULL;
		}
		_tmp5_ = s;
		_tmp5__length1 = s_length1;
		_tmp6_ = _tmp5_[0];
		_tmp7_ = g_strdup (_tmp6_);
		_g_free0 (prefix);
		prefix = _tmp7_;
		_tmp8_ = s;
		_tmp8__length1 = s_length1;
		_tmp9_ = _tmp8_[1];
		_tmp10_ = g_strdup (_tmp9_);
		_g_free0 (qname);
		qname = _tmp10_;
		s = (_vala_array_free (s, s_length1, (GDestroyNotify) g_free), NULL);
	}
	_tmp11_ = qname;
	_tmp12_ = gxml_document_create_element (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOCUMENT) ? ((GXmlDocument*) self) : NULL, _tmp11_, &_inner_error0_);
	e = _tmp12_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		_g_free0 (qname);
		_g_free0 (prefix);
		return NULL;
	}
	_tmp13_ = prefix;
	gxml_node_set_namespace (e, ns, _tmp13_);
	_tmp14_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (e, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) e) : NULL);
	result = _tmp14_;
	_g_object_unref0 (e);
	_g_free0 (qname);
	_g_free0 (prefix);
	return result;
}

static GXmlDomHTMLCollection*
gxml_gdocument_real_get_elements_by_tag_name (GXmlDomDocument* base,
                                              const gchar* local_name)
{
	GXmlGDocument * self;
	GXmlDomHTMLCollection* result = NULL;
	GXmlGDomHTMLCollection* l = NULL;
	GXmlGDomHTMLCollection* _tmp0_;
	GXmlDomElement* _tmp1_;
	GXmlDomElement* _tmp2_;
	GXmlDomElement* _tmp3_;
	gboolean _tmp4_;
	GXmlGDomHTMLCollection* _tmp5_;
	GXmlDomElement* _tmp6_;
	GXmlDomElement* _tmp7_;
	GXmlDomElement* _tmp8_;
	GXmlDomHTMLCollection* _tmp9_;
	GXmlDomHTMLCollection* _tmp10_;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (local_name != NULL, NULL);
	_tmp0_ = gxml_gdom_html_collection_new ();
	l = _tmp0_;
	_tmp1_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_ == NULL;
	_g_object_unref0 (_tmp3_);
	if (_tmp4_) {
		result = (GXmlDomHTMLCollection*) l;
		return result;
	}
	_tmp5_ = l;
	_tmp6_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
	_tmp7_ = _tmp6_;
	_tmp8_ = _tmp7_;
	_tmp9_ = gxml_dom_element_get_elements_by_tag_name (_tmp8_, local_name);
	_tmp10_ = _tmp9_;
	gee_array_list_add_all ((GeeArrayList*) _tmp5_, (GeeCollection*) _tmp10_);
	_g_object_unref0 (_tmp10_);
	_g_object_unref0 (_tmp8_);
	result = (GXmlDomHTMLCollection*) l;
	return result;
}

static GXmlDomHTMLCollection*
gxml_gdocument_real_get_elements_by_tag_name_ns (GXmlDomDocument* base,
                                                 const gchar* ns,
                                                 const gchar* local_name)
{
	GXmlGDocument * self;
	GXmlDomHTMLCollection* result = NULL;
	GXmlGDomHTMLCollection* l = NULL;
	GXmlGDomHTMLCollection* _tmp0_;
	GXmlDomElement* _tmp1_;
	GXmlDomElement* _tmp2_;
	GXmlDomElement* _tmp3_;
	gboolean _tmp4_;
	GXmlGDomHTMLCollection* _tmp5_;
	GXmlDomElement* _tmp6_;
	GXmlDomElement* _tmp7_;
	GXmlDomElement* _tmp8_;
	GXmlDomHTMLCollection* _tmp9_;
	GXmlDomHTMLCollection* _tmp10_;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (local_name != NULL, NULL);
	_tmp0_ = gxml_gdom_html_collection_new ();
	l = _tmp0_;
	_tmp1_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_ == NULL;
	_g_object_unref0 (_tmp3_);
	if (_tmp4_) {
		result = (GXmlDomHTMLCollection*) l;
		return result;
	}
	_tmp5_ = l;
	_tmp6_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
	_tmp7_ = _tmp6_;
	_tmp8_ = _tmp7_;
	_tmp9_ = gxml_dom_element_get_elements_by_tag_name_ns (_tmp8_, ns, local_name);
	_tmp10_ = _tmp9_;
	gee_array_list_add_all ((GeeArrayList*) _tmp5_, (GeeCollection*) _tmp10_);
	_g_object_unref0 (_tmp10_);
	_g_object_unref0 (_tmp8_);
	result = (GXmlDomHTMLCollection*) l;
	return result;
}

static GXmlDomHTMLCollection*
gxml_gdocument_real_get_elements_by_class_name (GXmlDomDocument* base,
                                                const gchar* class_names)
{
	GXmlGDocument * self;
	GXmlDomHTMLCollection* result = NULL;
	GXmlGDomHTMLCollection* l = NULL;
	GXmlGDomHTMLCollection* _tmp0_;
	GXmlDomElement* _tmp1_;
	GXmlDomElement* _tmp2_;
	GXmlDomElement* _tmp3_;
	gboolean _tmp4_;
	GXmlGDomHTMLCollection* _tmp5_;
	GXmlDomElement* _tmp6_;
	GXmlDomElement* _tmp7_;
	GXmlDomElement* _tmp8_;
	GXmlDomHTMLCollection* _tmp9_;
	GXmlDomHTMLCollection* _tmp10_;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (class_names != NULL, NULL);
	_tmp0_ = gxml_gdom_html_collection_new ();
	l = _tmp0_;
	_tmp1_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_ == NULL;
	_g_object_unref0 (_tmp3_);
	if (_tmp4_) {
		result = (GXmlDomHTMLCollection*) l;
		return result;
	}
	_tmp5_ = l;
	_tmp6_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
	_tmp7_ = _tmp6_;
	_tmp8_ = _tmp7_;
	_tmp9_ = gxml_dom_element_get_elements_by_class_name (_tmp8_, class_names);
	_tmp10_ = _tmp9_;
	gee_array_list_add_all ((GeeArrayList*) _tmp5_, (GeeCollection*) _tmp10_);
	_g_object_unref0 (_tmp10_);
	_g_object_unref0 (_tmp8_);
	result = (GXmlDomHTMLCollection*) l;
	return result;
}

static GXmlDomDocumentFragment*
gxml_gdocument_real_create_document_fragment (GXmlDomDocument* base)
{
	GXmlGDocument * self;
	GXmlDomDocumentFragment* result = NULL;
	GXmlGDocumentFragment* _tmp0_;
	self = (GXmlGDocument*) base;
	_tmp0_ = gxml_gdocument_fragment_new (self);
	result = (GXmlDomDocumentFragment*) _tmp0_;
	return result;
}

static GXmlDomText*
gxml_gdocument_real_create_text_node (GXmlDomDocument* base,
                                      const gchar* data,
                                      GError** error)
{
	GXmlGDocument * self;
	GXmlDomText* result = NULL;
	GXmlNode* _tmp0_;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (data != NULL, NULL);
	_tmp0_ = gxml_document_create_text ((GXmlDocument*) self, data);
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GXML_TYPE_DOM_TEXT, GXmlDomText);
	return result;
}

static GXmlDomComment*
gxml_gdocument_real_gxml_dom_document_create_comment (GXmlDomDocument* base,
                                                      const gchar* data,
                                                      GError** error)
{
	GXmlGDocument * self;
	GXmlDomComment* result = NULL;
	GXmlNode* _tmp0_;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (data != NULL, NULL);
	_tmp0_ = gxml_document_create_comment ((GXmlDocument*) self, data);
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GXML_TYPE_DOM_COMMENT, GXmlDomComment);
	return result;
}

static GXmlDomProcessingInstruction*
gxml_gdocument_real_create_processing_instruction (GXmlDomDocument* base,
                                                   const gchar* target,
                                                   const gchar* data,
                                                   GError** error)
{
	GXmlGDocument * self;
	GXmlDomProcessingInstruction* result = NULL;
	GXmlNode* _tmp0_;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (target != NULL, NULL);
	g_return_val_if_fail (data != NULL, NULL);
	_tmp0_ = gxml_document_create_pi ((GXmlDocument*) self, target, data);
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstruction);
	return result;
}

static GXmlDomNode*
gxml_gdocument_real_import_node (GXmlDomDocument* base,
                                 GXmlDomNode* node,
                                 gboolean deep,
                                 GError** error)
{
	GXmlGDocument * self;
	GXmlDomNode* result = NULL;
	gboolean _tmp1_ = FALSE;
	GXmlDomNode* dst = NULL;
	GXmlDomNode* _tmp45_;
	GXmlDomNode* _tmp52_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (node != NULL, NULL);
	if (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_DOCUMENT)) {
		GError* _tmp0_;
		_tmp0_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NOT_SUPPORTED_ERROR, _ ("Can't import a Document"));
		_inner_error0_ = _tmp0_;
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	if (!G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ELEMENT)) {
		GXmlDomElement* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlDomElement* _tmp4_;
		_tmp2_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
		_tmp3_ = _tmp2_;
		_tmp4_ = _tmp3_;
		_tmp1_ = _tmp4_ == NULL;
		_g_object_unref0 (_tmp4_);
	} else {
		_tmp1_ = FALSE;
	}
	if (_tmp1_) {
		GError* _tmp5_;
		_tmp5_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _ ("Can't import a non Element type node to a Document"));
		_inner_error0_ = _tmp5_;
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	dst = NULL;
	if (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ELEMENT)) {
		GXmlDomElement* _tmp6_ = NULL;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		GXmlDomElement* _tmp10_;
		GXmlDomElement* _tmp11_;
		GXmlDomElement* _tmp12_;
		GXmlDomNode* _tmp13_;
		GXmlDomElement* _tmp14_;
		GXmlDomElement* _tmp15_;
		GXmlDomElement* _tmp16_;
		gboolean _tmp17_;
		_tmp7_ = gxml_dom_node_get_node_name (node);
		_tmp8_ = _tmp7_;
		_tmp9_ = _tmp8_;
		_tmp10_ = gxml_dom_document_create_element (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) self) : NULL, _tmp9_, &_inner_error0_);
		_tmp11_ = _tmp10_;
		_g_free0 (_tmp9_);
		_tmp6_ = _tmp11_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			g_propagate_error (error, _inner_error0_);
			_g_object_unref0 (dst);
			return NULL;
		}
		_tmp12_ = _tmp6_;
		_tmp6_ = NULL;
		_g_object_unref0 (dst);
		dst = (GXmlDomNode*) _tmp12_;
		_tmp13_ = dst;
		gxml_node_copy ((GXmlDocument*) self, G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GXML_TYPE_NODE, GXmlNode), G_TYPE_CHECK_INSTANCE_CAST (node, GXML_TYPE_NODE, GXmlNode), deep);
		_tmp14_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
		_tmp15_ = _tmp14_;
		_tmp16_ = _tmp15_;
		_tmp17_ = _tmp16_ == NULL;
		_g_object_unref0 (_tmp16_);
		if (_tmp17_) {
			GXmlDomNode* _tmp18_;
			GXmlDomNode* _tmp19_;
			GXmlDomNode* _tmp20_;
			_tmp18_ = dst;
			_tmp19_ = gxml_dom_node_append_child ((GXmlDomNode*) self, _tmp18_, &_inner_error0_);
			_tmp20_ = _tmp19_;
			_g_object_unref0 (_tmp20_);
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
				g_propagate_error (error, _inner_error0_);
				_g_object_unref0 (_tmp6_);
				_g_object_unref0 (dst);
				return NULL;
			}
			result = dst;
			_g_object_unref0 (_tmp6_);
			return result;
		}
		_g_object_unref0 (_tmp6_);
	}
	if (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_TEXT)) {
		GXmlDomText* _tmp21_ = NULL;
		gchar* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
		GXmlDomText* _tmp25_;
		GXmlDomText* _tmp26_;
		GXmlDomText* _tmp27_;
		_tmp22_ = gxml_dom_character_data_get_data ((GXmlDomCharacterData*) (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_TEXT) ? ((GXmlDomText*) node) : NULL));
		_tmp23_ = _tmp22_;
		_tmp24_ = _tmp23_;
		_tmp25_ = gxml_dom_document_create_text_node ((GXmlDomDocument*) self, _tmp24_, &_inner_error0_);
		_tmp26_ = _tmp25_;
		_g_free0 (_tmp24_);
		_tmp21_ = _tmp26_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			g_propagate_error (error, _inner_error0_);
			_g_object_unref0 (dst);
			return NULL;
		}
		_tmp27_ = _tmp21_;
		_tmp21_ = NULL;
		_g_object_unref0 (dst);
		dst = (GXmlDomNode*) _tmp27_;
		_g_object_unref0 (_tmp21_);
	}
	if (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_COMMENT)) {
		GXmlDomComment* _tmp28_ = NULL;
		gchar* _tmp29_;
		gchar* _tmp30_;
		gchar* _tmp31_;
		GXmlDomComment* _tmp32_;
		GXmlDomComment* _tmp33_;
		GXmlDomComment* _tmp34_;
		_tmp29_ = gxml_dom_character_data_get_data ((GXmlDomCharacterData*) (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_COMMENT) ? ((GXmlDomComment*) node) : NULL));
		_tmp30_ = _tmp29_;
		_tmp31_ = _tmp30_;
		_tmp32_ = gxml_dom_document_create_comment (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) self) : NULL, _tmp31_, &_inner_error0_);
		_tmp33_ = _tmp32_;
		_g_free0 (_tmp31_);
		_tmp28_ = _tmp33_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			g_propagate_error (error, _inner_error0_);
			_g_object_unref0 (dst);
			return NULL;
		}
		_tmp34_ = _tmp28_;
		_tmp28_ = NULL;
		_g_object_unref0 (dst);
		dst = (GXmlDomNode*) _tmp34_;
		_g_object_unref0 (_tmp28_);
	}
	if (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_PROCESSING_INSTRUCTION)) {
		GXmlDomProcessingInstruction* _tmp35_ = NULL;
		gchar* _tmp36_;
		gchar* _tmp37_;
		gchar* _tmp38_;
		gchar* _tmp39_;
		gchar* _tmp40_;
		gchar* _tmp41_;
		GXmlDomProcessingInstruction* _tmp42_;
		GXmlDomProcessingInstruction* _tmp43_;
		GXmlDomProcessingInstruction* _tmp44_;
		_tmp36_ = gxml_dom_processing_instruction_get_target (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_PROCESSING_INSTRUCTION) ? ((GXmlDomProcessingInstruction*) node) : NULL);
		_tmp37_ = _tmp36_;
		_tmp38_ = _tmp37_;
		_tmp39_ = gxml_dom_character_data_get_data ((GXmlDomCharacterData*) (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_PROCESSING_INSTRUCTION) ? ((GXmlDomProcessingInstruction*) node) : NULL));
		_tmp40_ = _tmp39_;
		_tmp41_ = _tmp40_;
		_tmp42_ = gxml_dom_document_create_processing_instruction ((GXmlDomDocument*) self, _tmp38_, _tmp41_, &_inner_error0_);
		_tmp43_ = _tmp42_;
		_g_free0 (_tmp41_);
		_g_free0 (_tmp38_);
		_tmp35_ = _tmp43_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			g_propagate_error (error, _inner_error0_);
			_g_object_unref0 (dst);
			return NULL;
		}
		_tmp44_ = _tmp35_;
		_tmp35_ = NULL;
		_g_object_unref0 (dst);
		dst = (GXmlDomNode*) _tmp44_;
		_g_object_unref0 (_tmp35_);
	}
	_tmp45_ = dst;
	if (_tmp45_ != NULL) {
		GXmlDomElement* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomNode* _tmp49_;
		GXmlDomNode* _tmp50_;
		GXmlDomNode* _tmp51_;
		_tmp46_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
		_tmp47_ = _tmp46_;
		_tmp48_ = _tmp47_;
		_tmp49_ = dst;
		_tmp50_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp48_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp49_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp49_) : NULL, &_inner_error0_);
		_tmp51_ = _tmp50_;
		_g_object_unref0 (_tmp51_);
		_g_object_unref0 (_tmp48_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			g_propagate_error (error, _inner_error0_);
			_g_object_unref0 (dst);
			return NULL;
		}
		result = dst;
		return result;
	}
	_tmp52_ = _g_object_ref0 (node);
	result = _tmp52_;
	_g_object_unref0 (dst);
	return result;
}

static GXmlDomNode*
gxml_gdocument_real_adopt_node (GXmlDomDocument* base,
                                GXmlDomNode* node,
                                GError** error)
{
	GXmlGDocument * self;
	GXmlDomNode* result = NULL;
	GXmlDomDocument* _tmp1_;
	GXmlDomDocument* _tmp2_;
	GXmlNode* dst = NULL;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	GXmlNode* _tmp7_;
	GXmlNode* _tmp8_;
	GXmlNode* _tmp9_;
	GXmlDomNode* _tmp10_;
	GXmlDomNode* _tmp11_;
	GXmlDomNode* _tmp12_;
	gboolean _tmp13_;
	GXmlDomElement* _tmp28_;
	GXmlDomElement* _tmp29_;
	GXmlDomElement* _tmp30_;
	gboolean _tmp31_;
	GXmlNode* _tmp41_;
	GXmlDomNode* _tmp42_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (node != NULL, NULL);
	if (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_DOCUMENT)) {
		GError* _tmp0_;
		_tmp0_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NOT_SUPPORTED_ERROR, _ ("Can't adopt a Document"));
		_inner_error0_ = _tmp0_;
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	_tmp1_ = gxml_dom_node_get_owner_document (node);
	_tmp2_ = _tmp1_;
	if (self == _tmp2_) {
		GXmlDomNode* _tmp3_;
		_tmp3_ = _g_object_ref0 (node);
		result = _tmp3_;
		return result;
	}
	_tmp4_ = gxml_dom_node_get_node_name (node);
	_tmp5_ = _tmp4_;
	_tmp6_ = _tmp5_;
	_tmp7_ = gxml_document_create_element ((GXmlDocument*) self, _tmp6_, &_inner_error0_);
	_tmp8_ = _tmp7_;
	_g_free0 (_tmp6_);
	dst = _tmp8_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	_tmp9_ = dst;
	gxml_node_copy ((GXmlDocument*) self, _tmp9_, G_TYPE_CHECK_INSTANCE_CAST (node, GXML_TYPE_NODE, GXmlNode), TRUE);
	_tmp10_ = gxml_dom_node_get_parent_node (node);
	_tmp11_ = _tmp10_;
	_tmp12_ = _tmp11_;
	_tmp13_ = _tmp12_ != NULL;
	_g_object_unref0 (_tmp12_);
	if (_tmp13_) {
		GXmlDomNode* _tmp14_;
		GXmlDomNode* _tmp15_;
		GXmlDomNode* _tmp16_;
		GXmlDomNodeList* _tmp17_;
		GXmlDomNodeList* _tmp18_;
		GXmlDomNodeList* _tmp19_;
		GXmlDomNode* _tmp20_;
		GXmlDomNode* _tmp21_;
		GXmlDomNode* _tmp22_;
		GXmlDomNodeList* _tmp23_;
		GXmlDomNodeList* _tmp24_;
		GXmlDomNodeList* _tmp25_;
		gpointer _tmp26_;
		GXmlDomNode* _tmp27_;
		_tmp14_ = gxml_dom_node_get_parent_node (node);
		_tmp15_ = _tmp14_;
		_tmp16_ = _tmp15_;
		_tmp17_ = gxml_dom_node_get_child_nodes (_tmp16_);
		_tmp18_ = _tmp17_;
		_tmp19_ = _tmp18_;
		_tmp20_ = gxml_dom_node_get_parent_node (node);
		_tmp21_ = _tmp20_;
		_tmp22_ = _tmp21_;
		_tmp23_ = gxml_dom_node_get_child_nodes (_tmp22_);
		_tmp24_ = _tmp23_;
		_tmp25_ = _tmp24_;
		_tmp26_ = gee_list_remove_at ((GeeList*) _tmp19_, gee_list_index_of ((GeeList*) _tmp25_, node));
		_tmp27_ = (GXmlDomNode*) _tmp26_;
		_g_object_unref0 (_tmp27_);
		_g_object_unref0 (_tmp25_);
		_g_object_unref0 (_tmp22_);
		_g_object_unref0 (_tmp19_);
		_g_object_unref0 (_tmp16_);
	}
	_tmp28_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
	_tmp29_ = _tmp28_;
	_tmp30_ = _tmp29_;
	_tmp31_ = _tmp30_ == NULL;
	_g_object_unref0 (_tmp30_);
	if (_tmp31_) {
		GXmlNode* _tmp32_;
		GXmlDomNode* _tmp33_;
		GXmlDomNode* _tmp34_;
		_tmp32_ = dst;
		_tmp33_ = gxml_dom_node_append_child ((GXmlDomNode*) self, G_TYPE_CHECK_INSTANCE_TYPE (_tmp32_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp32_) : NULL, &_inner_error0_);
		_tmp34_ = _tmp33_;
		_g_object_unref0 (_tmp34_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			g_propagate_error (error, _inner_error0_);
			_g_object_unref0 (dst);
			return NULL;
		}
	} else {
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomElement* _tmp37_;
		GXmlNode* _tmp38_;
		GXmlDomNode* _tmp39_;
		GXmlDomNode* _tmp40_;
		_tmp35_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
		_tmp36_ = _tmp35_;
		_tmp37_ = _tmp36_;
		_tmp38_ = dst;
		_tmp39_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp37_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp38_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp38_) : NULL, &_inner_error0_);
		_tmp40_ = _tmp39_;
		_g_object_unref0 (_tmp40_);
		_g_object_unref0 (_tmp37_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			g_propagate_error (error, _inner_error0_);
			_g_object_unref0 (dst);
			return NULL;
		}
	}
	_tmp41_ = dst;
	_tmp42_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, GXML_TYPE_DOM_NODE, GXmlDomNode));
	result = _tmp42_;
	_g_object_unref0 (dst);
	return result;
}

static GXmlDomEvent*
gxml_gdocument_real_create_event (GXmlDomDocument* base,
                                  const gchar* iface,
                                  GError** error)
{
	GXmlGDocument * self;
	GXmlDomEvent* result = NULL;
	gchar* s = NULL;
	gchar* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp3_;
	const gchar* _tmp5_;
	const gchar* _tmp7_;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	const gchar* _tmp14_;
	const gchar* _tmp15_;
	const gchar* _tmp16_;
	GXmlDomEvent* _tmp17_;
	GXmlDomEvent* _tmp18_;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (iface != NULL, NULL);
	_tmp0_ = g_utf8_strdown (iface, (gssize) -1);
	s = _tmp0_;
	_tmp1_ = s;
	if (g_strcmp0 (_tmp1_, "customevent") == 0) {
		GXmlGDomCustomEvent* _tmp2_;
		_tmp2_ = gxml_gdom_custom_event_new ();
		_g_object_unref0 (self->_constructor);
		self->_constructor = (GXmlDomEvent*) _tmp2_;
	}
	_tmp3_ = s;
	if (g_strcmp0 (_tmp3_, "event") == 0) {
		GXmlGDomCustomEvent* _tmp4_;
		_tmp4_ = gxml_gdom_custom_event_new ();
		_g_object_unref0 (self->_constructor);
		self->_constructor = (GXmlDomEvent*) _tmp4_;
	}
	_tmp5_ = s;
	if (g_strcmp0 (_tmp5_, "events") == 0) {
		GXmlGDomCustomEvent* _tmp6_;
		_tmp6_ = gxml_gdom_custom_event_new ();
		_g_object_unref0 (self->_constructor);
		self->_constructor = (GXmlDomEvent*) _tmp6_;
	}
	_tmp7_ = s;
	if (g_strcmp0 (_tmp7_, "htmlevents") == 0) {
		GXmlGDomCustomEvent* _tmp8_;
		_tmp8_ = gxml_gdom_custom_event_new ();
		_g_object_unref0 (self->_constructor);
		self->_constructor = (GXmlDomEvent*) _tmp8_;
	}
	_tmp9_ = s;
	if (g_strcmp0 (_tmp9_, "keyboardevent") == 0) {
		_g_object_unref0 (self->_constructor);
		self->_constructor = NULL;
	}
	_tmp10_ = s;
	if (g_strcmp0 (_tmp10_, "keyevents") == 0) {
		_g_object_unref0 (self->_constructor);
		self->_constructor = NULL;
	}
	_tmp11_ = s;
	if (g_strcmp0 (_tmp11_, "messageevent") == 0) {
		_g_object_unref0 (self->_constructor);
		self->_constructor = NULL;
	}
	_tmp12_ = s;
	if (g_strcmp0 (_tmp12_, "mouseevent") == 0) {
		_g_object_unref0 (self->_constructor);
		self->_constructor = NULL;
	}
	_tmp13_ = s;
	if (g_strcmp0 (_tmp13_, "mouseevents") == 0) {
		_g_object_unref0 (self->_constructor);
		self->_constructor = NULL;
	}
	_tmp14_ = s;
	if (g_strcmp0 (_tmp14_, "touchevent") == 0) {
		_g_object_unref0 (self->_constructor);
		self->_constructor = NULL;
	}
	_tmp15_ = s;
	if (g_strcmp0 (_tmp15_, "uievent") == 0) {
		_g_object_unref0 (self->_constructor);
		self->_constructor = NULL;
	}
	_tmp16_ = s;
	if (g_strcmp0 (_tmp16_, "uievents") == 0) {
		_g_object_unref0 (self->_constructor);
		self->_constructor = NULL;
	}
	_tmp17_ = self->_constructor;
	_tmp18_ = _g_object_ref0 (_tmp17_);
	result = _tmp18_;
	_g_free0 (s);
	return result;
}

static GXmlDomRange*
gxml_gdocument_real_create_range (GXmlDomDocument* base)
{
	GXmlGDocument * self;
	GXmlDomRange* result = NULL;
	GXmlGDomRange* _tmp0_;
	self = (GXmlGDocument*) base;
	_tmp0_ = gxml_gdom_range_new ((GXmlDomDocument*) self);
	result = (GXmlDomRange*) _tmp0_;
	return result;
}

static GXmlDomNodeIterator*
gxml_gdocument_real_create_node_iterator (GXmlDomDocument* base,
                                          GXmlDomNode* root,
                                          gint what_to_show,
                                          GXmlDomNodeFilter* filter)
{
	GXmlGDocument * self;
	GXmlDomNodeIterator* result = NULL;
	GXmlGDomNodeIterator* _tmp0_;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (root != NULL, NULL);
	_tmp0_ = gxml_gdom_node_iterator_new (root, what_to_show, filter);
	result = (GXmlDomNodeIterator*) _tmp0_;
	return result;
}

static GXmlDomTreeWalker*
gxml_gdocument_real_create_tree_walker (GXmlDomDocument* base,
                                        GXmlDomNode* root,
                                        gint what_to_show,
                                        GXmlDomNodeFilter* filter)
{
	GXmlGDocument * self;
	GXmlDomTreeWalker* result = NULL;
	GXmlGDomTreeWalker* _tmp0_;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (root != NULL, NULL);
	_tmp0_ = gxml_gdom_tree_walker_new (root, what_to_show, filter);
	result = (GXmlDomTreeWalker*) _tmp0_;
	return result;
}

static GXmlDomNodeList*
gxml_gdocument_real_query_selector_all (GXmlDomParentNode* base,
                                        const gchar* selectors,
                                        GError** error)
{
	GXmlGDocument * self;
	GXmlDomNodeList* result = NULL;
	GXmlCssSelectorParser* cs = NULL;
	GXmlCssSelectorParser* _tmp0_;
	GXmlCssSelectorParser* _tmp1_;
	GXmlGomNodeList* l = NULL;
	GXmlGomNodeList* _tmp2_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (selectors != NULL, NULL);
	_tmp0_ = gxml_css_selector_parser_new ();
	cs = _tmp0_;
	_tmp1_ = cs;
	gxml_css_selector_parser_parse (_tmp1_, selectors, &_inner_error0_);
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (cs);
		return NULL;
	}
	_tmp2_ = gxml_gom_node_list_new ();
	l = _tmp2_;
	{
		GeeBidirList* _e_list = NULL;
		GeeBidirList* _tmp3_;
		GeeBidirList* _tmp4_;
		gint _e_size = 0;
		GeeBidirList* _tmp5_;
		gint _tmp6_;
		gint _tmp7_;
		gint _e_index = 0;
		_tmp3_ = gxml_gnode_get_children_nodes ((GXmlGNode*) self);
		_tmp4_ = _tmp3_;
		_e_list = _tmp4_;
		_tmp5_ = _e_list;
		_tmp6_ = gee_collection_get_size ((GeeCollection*) _tmp5_);
		_tmp7_ = _tmp6_;
		_e_size = _tmp7_;
		_e_index = -1;
		while (TRUE) {
			GXmlNode* e = NULL;
			GeeBidirList* _tmp8_;
			gpointer _tmp9_;
			GXmlNode* _tmp10_;
			gboolean _tmp11_ = FALSE;
			GXmlCssSelectorParser* _tmp12_;
			GXmlNode* _tmp13_;
			GXmlDomNodeList* _tmp16_ = NULL;
			GXmlCssSelectorParser* _tmp17_;
			GXmlNode* _tmp18_;
			GXmlDomNodeList* _tmp19_;
			GXmlGomNodeList* _tmp20_;
			_e_index = _e_index + 1;
			if (!(_e_index < _e_size)) {
				break;
			}
			_tmp8_ = _e_list;
			_tmp9_ = gee_list_get ((GeeList*) _tmp8_, _e_index);
			e = (GXmlNode*) _tmp9_;
			_tmp10_ = e;
			if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, GXML_TYPE_DOM_ELEMENT)) {
				_g_object_unref0 (e);
				continue;
			}
			_tmp12_ = cs;
			_tmp13_ = e;
			_tmp11_ = gxml_css_selector_parser_match (_tmp12_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp13_) : NULL, &_inner_error0_);
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
				g_propagate_error (error, _inner_error0_);
				_g_object_unref0 (e);
				_g_object_unref0 (_e_list);
				_g_object_unref0 (l);
				_g_object_unref0 (cs);
				return NULL;
			}
			if (_tmp11_) {
				GXmlGomNodeList* _tmp14_;
				GXmlNode* _tmp15_;
				_tmp14_ = l;
				_tmp15_ = e;
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp14_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp15_) : NULL);
			}
			_tmp17_ = cs;
			_tmp18_ = e;
			_tmp19_ = gxml_css_selector_parser_query_selector_all (_tmp17_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp18_) : NULL, &_inner_error0_);
			_tmp16_ = _tmp19_;
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
				g_propagate_error (error, _inner_error0_);
				_g_object_unref0 (e);
				_g_object_unref0 (_e_list);
				_g_object_unref0 (l);
				_g_object_unref0 (cs);
				return NULL;
			}
			_tmp20_ = l;
			gee_array_list_add_all ((GeeArrayList*) _tmp20_, (GeeCollection*) _tmp16_);
			_g_object_unref0 (_tmp16_);
			_g_object_unref0 (e);
		}
		_g_object_unref0 (_e_list);
	}
	result = (GXmlDomNodeList*) l;
	_g_object_unref0 (cs);
	return result;
}

static GXmlDomElement*
gxml_gdocument_real_get_element_by_id (GXmlDomNonElementParentNode* base,
                                       const gchar* element_id,
                                       GError** error)
{
	GXmlGDocument * self;
	GXmlDomElement* result = NULL;
	GXmlDomElementList* l = NULL;
	GXmlDomElementList* _tmp0_;
	GXmlDomElementList* _tmp1_;
	gint _tmp2_;
	gint _tmp3_;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (element_id != NULL, NULL);
	_tmp0_ = gxml_dom_parent_node_get_elements_by_property_value ((GXmlDomParentNode*) self, "id", element_id);
	l = _tmp0_;
	_tmp1_ = l;
	_tmp2_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp1_);
	_tmp3_ = _tmp2_;
	if (_tmp3_ > 0) {
		GXmlDomElementList* _tmp4_;
		gpointer _tmp5_;
		_tmp4_ = l;
		_tmp5_ = gee_abstract_list_get ((GeeAbstractList*) _tmp4_, 0);
		result = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomElement*) _tmp5_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
		_g_object_unref0 (l);
		return result;
	}
	result = NULL;
	_g_object_unref0 (l);
	return result;
}

/**
   * {@link XPathContext} implementation.
   */
static GXmlXPathObject*
gxml_gdocument_real_evaluate (GXmlXPathContext* base,
                              const gchar* expression,
                              GeeList* resolver,
                              GError** error)
{
	GXmlGDocument * self;
	GXmlXPathObject* result = NULL;
	GXmlXPathObject* nullobj = NULL;
	GXmlDomElement* _tmp0_;
	GXmlDomElement* _tmp1_;
	GXmlDomElement* _tmp2_;
	gboolean _tmp3_;
	GXmlXPathObject* _tmp4_ = NULL;
	GXmlDomElement* _tmp5_;
	GXmlDomElement* _tmp6_;
	GXmlXPathContext* _tmp7_;
	GXmlXPathContext* _tmp8_;
	GXmlXPathObject* _tmp9_;
	GXmlXPathObject* _tmp10_;
	GXmlXPathObject* _tmp11_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGDocument*) base;
	g_return_val_if_fail (expression != NULL, NULL);
	nullobj = NULL;
	_tmp0_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_ == NULL;
	_g_object_unref0 (_tmp2_);
	if (_tmp3_) {
		result = nullobj;
		return result;
	}
	_tmp5_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
	_tmp6_ = _tmp5_;
	_tmp7_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, GXML_TYPE_XPATH_CONTEXT) ? ((GXmlXPathContext*) _tmp6_) : NULL;
	if (_tmp7_ == NULL) {
		_g_object_unref0 (_tmp6_);
	}
	_tmp8_ = _tmp7_;
	_tmp9_ = gxml_xpath_context_evaluate (_tmp8_, expression, resolver, &_inner_error0_);
	_tmp10_ = _tmp9_;
	_g_object_unref0 (_tmp8_);
	_tmp4_ = _tmp10_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		if (_inner_error0_->domain == GXML_XPATH_ERROR) {
			g_propagate_error (error, _inner_error0_);
			_g_object_unref0 (nullobj);
			return NULL;
		} else {
			_g_object_unref0 (nullobj);
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
			g_clear_error (&_inner_error0_);
			return NULL;
		}
	}
	_tmp11_ = _tmp4_;
	_tmp4_ = NULL;
	result = _tmp11_;
	_g_object_unref0 (_tmp4_);
	_g_object_unref0 (nullobj);
	return result;
}

static GeeMap*
gxml_gdocument_real_get_attrs (GXmlGNode* base)
{
	GeeMap* result;
	GXmlGDocument* self;
	xmlDoc* _tmp0_;
	GXmlGHashMapAttr* _tmp1_;
	GeeMap* _tmp2_;
	self = (GXmlGDocument*) base;
	_tmp0_ = self->doc;
	_tmp1_ = gxml_ghash_map_attr_new (self, (xmlNode*) _tmp0_);
	_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GEE_TYPE_MAP) ? ((GeeMap*) _tmp1_) : NULL;
	if (_tmp2_ == NULL) {
		_g_object_unref0 (_tmp1_);
	}
	result = _tmp2_;
	return result;
}

static GeeBidirList*
gxml_gdocument_real_get_children_nodes (GXmlGNode* base)
{
	GeeBidirList* result;
	GXmlGDocument* self;
	xmlDoc* _tmp0_;
	GXmlGListChildren* _tmp1_;
	GeeBidirList* _tmp2_;
	self = (GXmlGDocument*) base;
	_tmp0_ = self->doc;
	_tmp1_ = gxml_glist_children_new (self, (xmlNode*) _tmp0_);
	_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GEE_TYPE_BIDIR_LIST) ? ((GeeBidirList*) _tmp1_) : NULL;
	if (_tmp2_ == NULL) {
		_g_object_unref0 (_tmp1_);
	}
	result = _tmp2_;
	return result;
}

static GeeList*
gxml_gdocument_real_get_namespaces (GXmlGNode* base)
{
	GeeList* result;
	GXmlGDocument* self;
	xmlDoc* _tmp0_;
	xmlNode* _tmp1_;
	GXmlGListNamespaces* _tmp2_;
	GeeList* _tmp3_;
	self = (GXmlGDocument*) base;
	_tmp0_ = self->doc;
	_tmp1_ = xmlDocGetRootElement (_tmp0_);
	_tmp2_ = gxml_glist_namespaces_new (self, _tmp1_);
	_tmp3_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, GEE_TYPE_LIST) ? ((GeeList*) _tmp2_) : NULL;
	if (_tmp3_ == NULL) {
		_g_object_unref0 (_tmp2_);
	}
	result = _tmp3_;
	return result;
}

static GXmlDocument*
gxml_gdocument_real_get_document (GXmlGNode* base)
{
	GXmlDocument* result;
	GXmlGDocument* self;
	self = (GXmlGDocument*) base;
	result = (GXmlDocument*) self;
	return result;
}

static gboolean
gxml_gdocument_real_get_indent (GXmlDocument* base)
{
	gboolean result;
	GXmlGDocument* self;
	self = (GXmlGDocument*) base;
	result = self->priv->_indent;
	return result;
}

static void
gxml_gdocument_real_set_indent (GXmlDocument* base,
                                gboolean value)
{
	GXmlGDocument* self;
	self = (GXmlGDocument*) base;
	if (gxml_gdocument_real_get_indent (base) != value) {
		self->priv->_indent = value;
		g_object_notify_by_pspec ((GObject *) self, gxml_gdocument_properties[GXML_GDOCUMENT_INDENT_PROPERTY]);
	}
}

static gboolean
gxml_gdocument_real_get_ns_top (GXmlDocument* base)
{
	gboolean result;
	GXmlGDocument* self;
	self = (GXmlGDocument*) base;
	result = self->priv->_ns_top;
	return result;
}

static void
gxml_gdocument_real_set_ns_top (GXmlDocument* base,
                                gboolean value)
{
	GXmlGDocument* self;
	self = (GXmlGDocument*) base;
	if (gxml_gdocument_real_get_ns_top (base) != value) {
		self->priv->_ns_top = value;
		g_object_notify_by_pspec ((GObject *) self, gxml_gdocument_properties[GXML_GDOCUMENT_NS_TOP_PROPERTY]);
	}
}

static gboolean
gxml_gdocument_real_get_prefix_default_ns (GXmlDocument* base)
{
	gboolean result;
	GXmlGDocument* self;
	self = (GXmlGDocument*) base;
	result = self->priv->_prefix_default_ns;
	return result;
}

static void
gxml_gdocument_real_set_prefix_default_ns (GXmlDocument* base,
                                           gboolean value)
{
	GXmlGDocument* self;
	self = (GXmlGDocument*) base;
	if (gxml_gdocument_real_get_prefix_default_ns (base) != value) {
		self->priv->_prefix_default_ns = value;
		g_object_notify_by_pspec ((GObject *) self, gxml_gdocument_properties[GXML_GDOCUMENT_PREFIX_DEFAULT_NS_PROPERTY]);
	}
}

static gboolean
gxml_gdocument_real_get_backup (GXmlDocument* base)
{
	gboolean result;
	GXmlGDocument* self;
	self = (GXmlGDocument*) base;
	result = self->priv->_backup;
	return result;
}

static void
gxml_gdocument_real_set_backup (GXmlDocument* base,
                                gboolean value)
{
	GXmlGDocument* self;
	self = (GXmlGDocument*) base;
	if (gxml_gdocument_real_get_backup (base) != value) {
		self->priv->_backup = value;
		g_object_notify_by_pspec ((GObject *) self, gxml_gdocument_properties[GXML_GDOCUMENT_BACKUP_PROPERTY]);
	}
}

static GFile*
gxml_gdocument_real_get_file (GXmlDocument* base)
{
	GFile* result;
	GXmlGDocument* self;
	GFile* _tmp0_;
	self = (GXmlGDocument*) base;
	_tmp0_ = self->priv->_file;
	result = _tmp0_;
	return result;
}

static void
gxml_gdocument_real_set_file (GXmlDocument* base,
                              GFile* value)
{
	GXmlGDocument* self;
	self = (GXmlGDocument*) base;
	if (gxml_gdocument_real_get_file (base) != value) {
		GFile* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_file);
		self->priv->_file = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gxml_gdocument_properties[GXML_GDOCUMENT_FILE_PROPERTY]);
	}
}

static GXmlNode*
gxml_gdocument_real_get_root (GXmlDocument* base)
{
	GXmlNode* result;
	GXmlGDocument* self;
	xmlNode* r = NULL;
	xmlDoc* _tmp0_;
	xmlNode* _tmp1_;
	xmlNode* _tmp2_;
	xmlNode* _tmp18_;
	GXmlGElement* _tmp19_;
	self = (GXmlGDocument*) base;
	_tmp0_ = self->doc;
	_tmp1_ = xmlDocGetRootElement (_tmp0_);
	r = _tmp1_;
	_tmp2_ = r;
	if (_tmp2_ == NULL) {
		gint found = 0;
		found = 0;
		{
			gint i = 0;
			i = 0;
			{
				gboolean _tmp3_ = FALSE;
				_tmp3_ = TRUE;
				while (TRUE) {
					GeeBidirList* _tmp5_;
					GeeBidirList* _tmp6_;
					GeeBidirList* _tmp7_;
					gint _tmp8_;
					gint _tmp9_;
					gboolean _tmp10_;
					GXmlNode* n = NULL;
					GeeBidirList* _tmp11_;
					GeeBidirList* _tmp12_;
					GeeBidirList* _tmp13_;
					gpointer _tmp14_;
					GXmlNode* _tmp15_;
					GXmlNode* _tmp16_;
					if (!_tmp3_) {
						gint _tmp4_;
						_tmp4_ = i;
						i = _tmp4_ + 1;
					}
					_tmp3_ = FALSE;
					_tmp5_ = gxml_gnode_get_children_nodes ((GXmlGNode*) self);
					_tmp6_ = _tmp5_;
					_tmp7_ = _tmp6_;
					_tmp8_ = gee_collection_get_size ((GeeCollection*) _tmp7_);
					_tmp9_ = _tmp8_;
					_tmp10_ = !(i < _tmp9_);
					_g_object_unref0 (_tmp7_);
					if (_tmp10_) {
						break;
					}
					_tmp11_ = gxml_gnode_get_children_nodes ((GXmlGNode*) self);
					_tmp12_ = _tmp11_;
					_tmp13_ = _tmp12_;
					_tmp14_ = gee_list_get ((GeeList*) _tmp13_, i);
					_tmp15_ = (GXmlNode*) _tmp14_;
					_g_object_unref0 (_tmp13_);
					n = _tmp15_;
					_tmp16_ = n;
					if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp16_, GXML_TYPE_ELEMENT)) {
						gint _tmp17_;
						_tmp17_ = found;
						found = _tmp17_ + 1;
						if (found == 1) {
							result = n;
							return result;
						}
					}
					_g_object_unref0 (n);
				}
			}
		}
		if (found > 1) {
			g_warning ("GXmlDocument.vala:119: Document have more than one root GXmlElement. U" \
"sing first found");
		}
	}
	_tmp18_ = r;
	_tmp19_ = gxml_gelement_new (self, _tmp18_);
	result = (GXmlNode*) _tmp19_;
	return result;
}

static GXmlDomImplementation*
gxml_gdocument_real_get_implementation (GXmlDomDocument* base)
{
	GXmlDomImplementation* result;
	GXmlGDocument* self;
	GXmlGImplementation* _tmp0_;
	self = (GXmlGDocument*) base;
	_tmp0_ = self->_implementation;
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementation);
	return result;
}

static const gchar*
gxml_gdocument_real_get_url (GXmlDomDocument* base)
{
	const gchar* result;
	GXmlGDocument* self;
	const gchar* _tmp0_;
	self = (GXmlGDocument*) base;
	_tmp0_ = self->_url;
	result = _tmp0_;
	return result;
}

static const gchar*
gxml_gdocument_real_get_document_uri (GXmlDomDocument* base)
{
	const gchar* result;
	GXmlGDocument* self;
	const gchar* _tmp0_;
	self = (GXmlGDocument*) base;
	_tmp0_ = self->_url;
	result = _tmp0_;
	return result;
}

static const gchar*
gxml_gdocument_real_get_origin (GXmlDomDocument* base)
{
	const gchar* result;
	GXmlGDocument* self;
	const gchar* _tmp0_;
	self = (GXmlGDocument*) base;
	_tmp0_ = self->_origin;
	result = _tmp0_;
	return result;
}

static const gchar*
gxml_gdocument_real_get_compat_mode (GXmlDomDocument* base)
{
	const gchar* result;
	GXmlGDocument* self;
	const gchar* _tmp0_;
	self = (GXmlGDocument*) base;
	_tmp0_ = self->_compat_mode;
	result = _tmp0_;
	return result;
}

static const gchar*
gxml_gdocument_real_get_character_set (GXmlDomDocument* base)
{
	const gchar* result;
	GXmlGDocument* self;
	const gchar* _tmp0_;
	self = (GXmlGDocument*) base;
	_tmp0_ = self->_character_set;
	result = _tmp0_;
	return result;
}

static const gchar*
gxml_gdocument_real_get_content_type (GXmlDomDocument* base)
{
	const gchar* result;
	GXmlGDocument* self;
	const gchar* _tmp0_;
	self = (GXmlGDocument*) base;
	_tmp0_ = self->_content_type;
	result = _tmp0_;
	return result;
}

static GXmlDomDocumentType*
gxml_gdocument_real_get_doctype (GXmlDomDocument* base)
{
	GXmlDomDocumentType* result;
	GXmlGDocument* self;
	self = (GXmlGDocument*) base;
	{
		GXmlDomNodeList* _n_list = NULL;
		GXmlDomNodeList* _tmp0_;
		GXmlDomNodeList* _tmp1_;
		gint _n_size = 0;
		GXmlDomNodeList* _tmp2_;
		gint _tmp3_;
		gint _tmp4_;
		gint _n_index = 0;
		_tmp0_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
		_tmp1_ = _tmp0_;
		_n_list = _tmp1_;
		_tmp2_ = _n_list;
		_tmp3_ = gee_collection_get_size ((GeeCollection*) _tmp2_);
		_tmp4_ = _tmp3_;
		_n_size = _tmp4_;
		_n_index = -1;
		while (TRUE) {
			GXmlDomNode* n = NULL;
			GXmlDomNodeList* _tmp5_;
			gpointer _tmp6_;
			GXmlDomNode* _tmp7_;
			_n_index = _n_index + 1;
			if (!(_n_index < _n_size)) {
				break;
			}
			_tmp5_ = _n_list;
			_tmp6_ = gee_list_get ((GeeList*) _tmp5_, _n_index);
			n = (GXmlDomNode*) _tmp6_;
			_tmp7_ = n;
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, GXML_TYPE_DOM_DOCUMENT_TYPE)) {
				GXmlDomNode* _tmp8_;
				GXmlDomDocumentType* _tmp9_;
				_tmp8_ = n;
				_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentType));
				result = _tmp9_;
				_g_object_unref0 (n);
				_g_object_unref0 (_n_list);
				return result;
			}
			_g_object_unref0 (n);
		}
		_g_object_unref0 (_n_list);
	}
	result = NULL;
	return result;
}

static GXmlDomElement*
gxml_gdocument_real_get_document_element (GXmlDomDocument* base)
{
	GXmlDomElement* result;
	GXmlGDocument* self;
	GXmlNode* _tmp0_;
	GXmlNode* _tmp1_;
	self = (GXmlGDocument*) base;
	_tmp0_ = gxml_document_get_root ((GXmlDocument*) self);
	_tmp1_ = _tmp0_;
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
	return result;
}

static GXmlDomHTMLCollection*
gxml_gdocument_real_get_children (GXmlDomParentNode* base)
{
	GXmlDomHTMLCollection* result;
	GXmlGDocument* self;
	GXmlDomElementList* l = NULL;
	GXmlDomElementList* _tmp0_;
	self = (GXmlGDocument*) base;
	_tmp0_ = gxml_dom_element_list_new ();
	l = _tmp0_;
	{
		GXmlDomNodeList* _n_list = NULL;
		GXmlDomNodeList* _tmp1_;
		GXmlDomNodeList* _tmp2_;
		gint _n_size = 0;
		GXmlDomNodeList* _tmp3_;
		gint _tmp4_;
		gint _tmp5_;
		gint _n_index = 0;
		_tmp1_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
		_tmp2_ = _tmp1_;
		_n_list = _tmp2_;
		_tmp3_ = _n_list;
		_tmp4_ = gee_collection_get_size ((GeeCollection*) _tmp3_);
		_tmp5_ = _tmp4_;
		_n_size = _tmp5_;
		_n_index = -1;
		while (TRUE) {
			GXmlDomNode* n = NULL;
			GXmlDomNodeList* _tmp6_;
			gpointer _tmp7_;
			GXmlDomNode* _tmp8_;
			_n_index = _n_index + 1;
			if (!(_n_index < _n_size)) {
				break;
			}
			_tmp6_ = _n_list;
			_tmp7_ = gee_list_get ((GeeList*) _tmp6_, _n_index);
			n = (GXmlDomNode*) _tmp7_;
			_tmp8_ = n;
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, GXML_TYPE_DOM_ELEMENT)) {
				GXmlDomElementList* _tmp9_;
				GXmlDomNode* _tmp10_;
				_tmp9_ = l;
				_tmp10_ = n;
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp9_, G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement));
			}
			_g_object_unref0 (n);
		}
		_g_object_unref0 (_n_list);
	}
	result = (GXmlDomHTMLCollection*) l;
	return result;
}

static GXmlDomElement*
gxml_gdocument_real_get_first_element_child (GXmlDomParentNode* base)
{
	GXmlDomElement* result;
	GXmlGDocument* self;
	GeeBidirList* _tmp0_;
	GeeBidirList* _tmp1_;
	GeeBidirList* _tmp2_;
	gpointer _tmp3_;
	GXmlDomElement* _tmp4_;
	self = (GXmlGDocument*) base;
	_tmp0_ = gxml_node_get_children_nodes ((GXmlNode*) (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOCUMENT) ? ((GXmlDocument*) self) : NULL));
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_list_first ((GeeList*) _tmp2_);
	_tmp4_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlNode*) _tmp3_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
	_g_object_unref0 (_tmp2_);
	result = _tmp4_;
	return result;
}

static GXmlDomElement*
gxml_gdocument_real_get_last_element_child (GXmlDomParentNode* base)
{
	GXmlDomElement* result;
	GXmlGDocument* self;
	GeeBidirList* _tmp0_;
	GeeBidirList* _tmp1_;
	GeeBidirList* _tmp2_;
	gpointer _tmp3_;
	GXmlDomElement* _tmp4_;
	self = (GXmlGDocument*) base;
	_tmp0_ = gxml_node_get_children_nodes ((GXmlNode*) (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOCUMENT) ? ((GXmlDocument*) self) : NULL));
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_list_last ((GeeList*) _tmp2_);
	_tmp4_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlNode*) _tmp3_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
	_g_object_unref0 (_tmp2_);
	result = _tmp4_;
	return result;
}

static gint
gxml_gdocument_real_get_child_element_count (GXmlDomParentNode* base)
{
	gint result;
	GXmlGDocument* self;
	GeeBidirList* _tmp0_;
	GeeBidirList* _tmp1_;
	GeeBidirList* _tmp2_;
	gint _tmp3_;
	gint _tmp4_;
	gint _tmp5_;
	self = (GXmlGDocument*) base;
	_tmp0_ = gxml_gnode_get_children_nodes ((GXmlGNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_collection_get_size ((GeeCollection*) _tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_;
	_g_object_unref0 (_tmp2_);
	result = _tmp5_;
	return result;
}

static void
gxml_gdocument_class_init (GXmlGDocumentClass * klass,
                           gpointer klass_data)
{
	gxml_gdocument_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GXmlGDocument_private_offset);
	((GXmlGNodeClass *) klass)->set_namespace = (gboolean (*) (GXmlGNode*, const gchar*, const gchar*)) gxml_gdocument_real_set_namespace;
	((GXmlGNodeClass *) klass)->to_string = (gchar* (*) (GXmlGNode*)) gxml_gdocument_real_to_string;
	((GXmlGDocumentClass *) klass)->save = (gboolean (*) (GXmlGDocument*, GCancellable*, GError**)) gxml_gdocument_real_save;
	((GXmlGDocumentClass *) klass)->save_as = (gboolean (*) (GXmlGDocument*, GFile*, GCancellable*, GError**)) gxml_gdocument_real_save_as;
	GXML_GNODE_CLASS (klass)->get_attrs = gxml_gdocument_real_get_attrs;
	GXML_GNODE_CLASS (klass)->get_children_nodes = gxml_gdocument_real_get_children_nodes;
	GXML_GNODE_CLASS (klass)->get_namespaces = gxml_gdocument_real_get_namespaces;
	GXML_GNODE_CLASS (klass)->get_document = gxml_gdocument_real_get_document;
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gdocument_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gxml_gdocument_set_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_gdocument_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_ATTRS_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_ATTRS_PROPERTY] = g_param_spec_object ("attrs", "attrs", "attrs", GEE_TYPE_MAP, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_CHILDREN_NODES_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_CHILDREN_NODES_PROPERTY] = g_param_spec_object ("children-nodes", "children-nodes", "children-nodes", GEE_TYPE_BIDIR_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_NAMESPACES_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_NAMESPACES_PROPERTY] = g_param_spec_object ("namespaces", "namespaces", "namespaces", GEE_TYPE_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_DOCUMENT_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_DOCUMENT_PROPERTY] = g_param_spec_object ("document", "document", "document", GXML_TYPE_DOCUMENT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_INDENT_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_INDENT_PROPERTY] = g_param_spec_boolean ("indent", "indent", "indent", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_NS_TOP_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_NS_TOP_PROPERTY] = g_param_spec_boolean ("ns-top", "ns-top", "ns-top", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_PREFIX_DEFAULT_NS_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_PREFIX_DEFAULT_NS_PROPERTY] = g_param_spec_boolean ("prefix-default-ns", "prefix-default-ns", "prefix-default-ns", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_BACKUP_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_BACKUP_PROPERTY] = g_param_spec_boolean ("backup", "backup", "backup", TRUE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_FILE_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_FILE_PROPERTY] = g_param_spec_object ("file", "file", "file", g_file_get_type (), G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_ROOT_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_ROOT_PROPERTY] = g_param_spec_object ("root", "root", "root", GXML_TYPE_NODE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_IMPLEMENTATION_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_IMPLEMENTATION_PROPERTY] = g_param_spec_object ("implementation", "implementation", "implementation", GXML_TYPE_DOM_IMPLEMENTATION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_URL_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_URL_PROPERTY] = g_param_spec_string ("url", "url", "url", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_DOCUMENT_URI_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_DOCUMENT_URI_PROPERTY] = g_param_spec_string ("document-uri", "document-uri", "document-uri", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_ORIGIN_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_ORIGIN_PROPERTY] = g_param_spec_string ("origin", "origin", "origin", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_COMPAT_MODE_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_COMPAT_MODE_PROPERTY] = g_param_spec_string ("compat-mode", "compat-mode", "compat-mode", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_CHARACTER_SET_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_CHARACTER_SET_PROPERTY] = g_param_spec_string ("character-set", "character-set", "character-set", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_CONTENT_TYPE_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_CONTENT_TYPE_PROPERTY] = g_param_spec_string ("content-type", "content-type", "content-type", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_DOCTYPE_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_DOCTYPE_PROPERTY] = g_param_spec_object ("doctype", "doctype", "doctype", GXML_TYPE_DOM_DOCUMENT_TYPE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_DOCUMENT_ELEMENT_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_DOCUMENT_ELEMENT_PROPERTY] = g_param_spec_object ("document-element", "document-element", "document-element", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_CHILDREN_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_CHILDREN_PROPERTY] = g_param_spec_object ("children", "children", "children", GXML_TYPE_DOM_HTML_COLLECTION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_FIRST_ELEMENT_CHILD_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_FIRST_ELEMENT_CHILD_PROPERTY] = g_param_spec_object ("first-element-child", "first-element-child", "first-element-child", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_LAST_ELEMENT_CHILD_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_LAST_ELEMENT_CHILD_PROPERTY] = g_param_spec_object ("last-element-child", "last-element-child", "last-element-child", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_CHILD_ELEMENT_COUNT_PROPERTY, gxml_gdocument_properties[GXML_GDOCUMENT_CHILD_ELEMENT_COUNT_PROPERTY] = g_param_spec_int ("child-element-count", "child-element-count", "child-element-count", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
gxml_gdocument_gxml_document_interface_init (GXmlDocumentIface * iface,
                                             gpointer iface_data)
{
	gxml_gdocument_gxml_document_parent_iface = g_type_interface_peek_parent (iface);
	iface->create_comment = (GXmlNode* (*) (GXmlDocument*, const gchar*)) gxml_gdocument_real_gxml_document_create_comment;
	iface->create_pi = (GXmlNode* (*) (GXmlDocument*, const gchar*, const gchar*)) gxml_gdocument_real_create_pi;
	iface->create_element = (GXmlNode* (*) (GXmlDocument*, const gchar*, GError**)) gxml_gdocument_real_gxml_document_create_element;
	iface->create_text = (GXmlNode* (*) (GXmlDocument*, const gchar*)) gxml_gdocument_real_create_text;
	iface->create_cdata = (GXmlNode* (*) (GXmlDocument*, const gchar*)) gxml_gdocument_real_create_cdata;
	iface->save = (gboolean (*) (GXmlDocument*, GCancellable*, GError**)) gxml_gdocument_save;
	iface->save_as = (gboolean (*) (GXmlDocument*, GFile*, GCancellable*, GError**)) gxml_gdocument_save_as;
	iface->get_indent = gxml_gdocument_real_get_indent;
	iface->set_indent = gxml_gdocument_real_set_indent;
	iface->get_ns_top = gxml_gdocument_real_get_ns_top;
	iface->set_ns_top = gxml_gdocument_real_set_ns_top;
	iface->get_prefix_default_ns = gxml_gdocument_real_get_prefix_default_ns;
	iface->set_prefix_default_ns = gxml_gdocument_real_set_prefix_default_ns;
	iface->get_backup = gxml_gdocument_real_get_backup;
	iface->set_backup = gxml_gdocument_real_set_backup;
	iface->get_file = gxml_gdocument_real_get_file;
	iface->set_file = gxml_gdocument_real_set_file;
	iface->get_root = gxml_gdocument_real_get_root;
}

static void
gxml_gdocument_gxml_dom_parent_node_interface_init (GXmlDomParentNodeIface * iface,
                                                    gpointer iface_data)
{
	gxml_gdocument_gxml_dom_parent_node_parent_iface = g_type_interface_peek_parent (iface);
	iface->query_selector_all = (GXmlDomNodeList* (*) (GXmlDomParentNode*, const gchar*, GError**)) gxml_gdocument_real_query_selector_all;
	iface->get_children = gxml_gdocument_real_get_children;
	iface->get_first_element_child = gxml_gdocument_real_get_first_element_child;
	iface->get_last_element_child = gxml_gdocument_real_get_last_element_child;
	iface->get_child_element_count = gxml_gdocument_real_get_child_element_count;
}

static void
gxml_gdocument_gxml_dom_non_element_parent_node_interface_init (GXmlDomNonElementParentNodeIface * iface,
                                                                gpointer iface_data)
{
	gxml_gdocument_gxml_dom_non_element_parent_node_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_element_by_id = (GXmlDomElement* (*) (GXmlDomNonElementParentNode*, const gchar*, GError**)) gxml_gdocument_real_get_element_by_id;
}

static void
gxml_gdocument_gxml_dom_document_interface_init (GXmlDomDocumentIface * iface,
                                                 gpointer iface_data)
{
	gxml_gdocument_gxml_dom_document_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_xml_parser = (GXmlParser* (*) (GXmlDomDocument*)) gxml_gdocument_real_gxml_dom_document_get_xml_parser;
	iface->set_xml_parser = (void (*) (GXmlDomDocument*, GXmlParser*)) gxml_gdocument_real_set_xml_parser;
	iface->create_element = (GXmlDomElement* (*) (GXmlDomDocument*, const gchar*, GError**)) gxml_gdocument_real_gxml_dom_document_create_element;
	iface->create_element_ns = (GXmlDomElement* (*) (GXmlDomDocument*, const gchar*, const gchar*, GError**)) gxml_gdocument_real_gxml_dom_document_create_element_ns;
	iface->get_elements_by_tag_name = (GXmlDomHTMLCollection* (*) (GXmlDomDocument*, const gchar*)) gxml_gdocument_real_get_elements_by_tag_name;
	iface->get_elements_by_tag_name_ns = (GXmlDomHTMLCollection* (*) (GXmlDomDocument*, const gchar*, const gchar*)) gxml_gdocument_real_get_elements_by_tag_name_ns;
	iface->get_elements_by_class_name = (GXmlDomHTMLCollection* (*) (GXmlDomDocument*, const gchar*)) gxml_gdocument_real_get_elements_by_class_name;
	iface->create_document_fragment = (GXmlDomDocumentFragment* (*) (GXmlDomDocument*)) gxml_gdocument_real_create_document_fragment;
	iface->create_text_node = (GXmlDomText* (*) (GXmlDomDocument*, const gchar*, GError**)) gxml_gdocument_real_create_text_node;
	iface->create_comment = (GXmlDomComment* (*) (GXmlDomDocument*, const gchar*, GError**)) gxml_gdocument_real_gxml_dom_document_create_comment;
	iface->create_processing_instruction = (GXmlDomProcessingInstruction* (*) (GXmlDomDocument*, const gchar*, const gchar*, GError**)) gxml_gdocument_real_create_processing_instruction;
	iface->import_node = (GXmlDomNode* (*) (GXmlDomDocument*, GXmlDomNode*, gboolean, GError**)) gxml_gdocument_real_import_node;
	iface->adopt_node = (GXmlDomNode* (*) (GXmlDomDocument*, GXmlDomNode*, GError**)) gxml_gdocument_real_adopt_node;
	iface->create_event = (GXmlDomEvent* (*) (GXmlDomDocument*, const gchar*, GError**)) gxml_gdocument_real_create_event;
	iface->create_range = (GXmlDomRange* (*) (GXmlDomDocument*)) gxml_gdocument_real_create_range;
	iface->create_node_iterator = (GXmlDomNodeIterator* (*) (GXmlDomDocument*, GXmlDomNode*, gint, GXmlDomNodeFilter*)) gxml_gdocument_real_create_node_iterator;
	iface->create_tree_walker = (GXmlDomTreeWalker* (*) (GXmlDomDocument*, GXmlDomNode*, gint, GXmlDomNodeFilter*)) gxml_gdocument_real_create_tree_walker;
	iface->get_implementation = gxml_gdocument_real_get_implementation;
	iface->get_url = gxml_gdocument_real_get_url;
	iface->get_document_uri = gxml_gdocument_real_get_document_uri;
	iface->get_origin = gxml_gdocument_real_get_origin;
	iface->get_compat_mode = gxml_gdocument_real_get_compat_mode;
	iface->get_character_set = gxml_gdocument_real_get_character_set;
	iface->get_content_type = gxml_gdocument_real_get_content_type;
	iface->get_doctype = gxml_gdocument_real_get_doctype;
	iface->get_document_element = gxml_gdocument_real_get_document_element;
}

static void
gxml_gdocument_gxml_dom_xml_document_interface_init (GXmlDomXMLDocumentIface * iface,
                                                     gpointer iface_data)
{
	gxml_gdocument_gxml_dom_xml_document_parent_iface = g_type_interface_peek_parent (iface);
}

static void
gxml_gdocument_gxml_xpath_context_interface_init (GXmlXPathContextIface * iface,
                                                  gpointer iface_data)
{
	gxml_gdocument_gxml_xpath_context_parent_iface = g_type_interface_peek_parent (iface);
	iface->evaluate = (GXmlXPathObject* (*) (GXmlXPathContext*, const gchar*, GeeList*, GError**)) gxml_gdocument_real_evaluate;
}

static void
gxml_gdocument_instance_init (GXmlGDocument * self,
                              gpointer klass)
{
	GXmlGImplementation* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	self->priv = gxml_gdocument_get_instance_private (self);
	self->_parser = NULL;
	self->priv->_indent = FALSE;
	self->priv->_ns_top = FALSE;
	self->priv->_prefix_default_ns = FALSE;
	self->priv->_backup = TRUE;
	_tmp0_ = gxml_gimplementation_new ();
	self->_implementation = _tmp0_;
	_tmp1_ = g_strdup ("about:blank");
	self->_url = _tmp1_;
	_tmp2_ = g_strdup ("");
	self->_origin = _tmp2_;
	_tmp3_ = g_strdup ("");
	self->_compat_mode = _tmp3_;
	_tmp4_ = g_strdup ("utf-8");
	self->_character_set = _tmp4_;
	_tmp5_ = g_strdup ("application/xml");
	self->_content_type = _tmp5_;
}

static void
gxml_gdocument_finalize (GObject * obj)
{
	GXmlGDocument * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GDOCUMENT, GXmlGDocument);
	_xmlBufferFree0 (self->_buffer);
	_g_object_unref0 (self->_parser);
	_g_object_unref0 (self->priv->_file);
	_g_object_unref0 (self->_implementation);
	_g_free0 (self->_url);
	_g_free0 (self->_origin);
	_g_free0 (self->_compat_mode);
	_g_free0 (self->_character_set);
	_g_free0 (self->_content_type);
	_g_object_unref0 (self->_constructor);
	G_OBJECT_CLASS (gxml_gdocument_parent_class)->finalize (obj);
}

/**
 * DOM4 class implemeting {@link GXml.Document} and {GXml.DomDocument} interface,
 * powered by libxml-2.0 library.
 *
 * This class use {@link Xml.TextWriter} to write down XML documents using
 * its contained {@link GXml.Node} children or other XML structures.
 */
GType
gxml_gdocument_get_type (void)
{
	static volatile gsize gxml_gdocument_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gdocument_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGDocumentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gdocument_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGDocument), 0, (GInstanceInitFunc) gxml_gdocument_instance_init, NULL };
		static const GInterfaceInfo gxml_document_info = { (GInterfaceInitFunc) gxml_gdocument_gxml_document_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_parent_node_info = { (GInterfaceInitFunc) gxml_gdocument_gxml_dom_parent_node_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_non_element_parent_node_info = { (GInterfaceInitFunc) gxml_gdocument_gxml_dom_non_element_parent_node_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_document_info = { (GInterfaceInitFunc) gxml_gdocument_gxml_dom_document_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_xml_document_info = { (GInterfaceInitFunc) gxml_gdocument_gxml_dom_xml_document_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_xpath_context_info = { (GInterfaceInitFunc) gxml_gdocument_gxml_xpath_context_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_gdocument_type_id;
		gxml_gdocument_type_id = g_type_register_static (GXML_TYPE_GNODE, "GXmlGDocument", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_gdocument_type_id, GXML_TYPE_DOCUMENT, &gxml_document_info);
		g_type_add_interface_static (gxml_gdocument_type_id, GXML_TYPE_DOM_PARENT_NODE, &gxml_dom_parent_node_info);
		g_type_add_interface_static (gxml_gdocument_type_id, GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, &gxml_dom_non_element_parent_node_info);
		g_type_add_interface_static (gxml_gdocument_type_id, GXML_TYPE_DOM_DOCUMENT, &gxml_dom_document_info);
		g_type_add_interface_static (gxml_gdocument_type_id, GXML_TYPE_DOM_XML_DOCUMENT, &gxml_dom_xml_document_info);
		g_type_add_interface_static (gxml_gdocument_type_id, GXML_TYPE_XPATH_CONTEXT, &gxml_xpath_context_info);
		GXmlGDocument_private_offset = g_type_add_instance_private (gxml_gdocument_type_id, sizeof (GXmlGDocumentPrivate));
		g_once_init_leave (&gxml_gdocument_type_id__volatile, gxml_gdocument_type_id);
	}
	return gxml_gdocument_type_id__volatile;
}

static void
_vala_gxml_gdocument_get_property (GObject * object,
                                   guint property_id,
                                   GValue * value,
                                   GParamSpec * pspec)
{
	GXmlGDocument * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GDOCUMENT, GXmlGDocument);
	switch (property_id) {
		case GXML_GDOCUMENT_ATTRS_PROPERTY:
		g_value_take_object (value, gxml_gnode_get_attrs ((GXmlGNode*) self));
		break;
		case GXML_GDOCUMENT_CHILDREN_NODES_PROPERTY:
		g_value_take_object (value, gxml_gnode_get_children_nodes ((GXmlGNode*) self));
		break;
		case GXML_GDOCUMENT_NAMESPACES_PROPERTY:
		g_value_take_object (value, gxml_gnode_get_namespaces ((GXmlGNode*) self));
		break;
		case GXML_GDOCUMENT_DOCUMENT_PROPERTY:
		g_value_set_object (value, gxml_gnode_get_document ((GXmlGNode*) self));
		break;
		case GXML_GDOCUMENT_INDENT_PROPERTY:
		g_value_set_boolean (value, gxml_document_get_indent ((GXmlDocument*) self));
		break;
		case GXML_GDOCUMENT_NS_TOP_PROPERTY:
		g_value_set_boolean (value, gxml_document_get_ns_top ((GXmlDocument*) self));
		break;
		case GXML_GDOCUMENT_PREFIX_DEFAULT_NS_PROPERTY:
		g_value_set_boolean (value, gxml_document_get_prefix_default_ns ((GXmlDocument*) self));
		break;
		case GXML_GDOCUMENT_BACKUP_PROPERTY:
		g_value_set_boolean (value, gxml_document_get_backup ((GXmlDocument*) self));
		break;
		case GXML_GDOCUMENT_FILE_PROPERTY:
		g_value_set_object (value, gxml_document_get_file ((GXmlDocument*) self));
		break;
		case GXML_GDOCUMENT_ROOT_PROPERTY:
		g_value_take_object (value, gxml_document_get_root ((GXmlDocument*) self));
		break;
		case GXML_GDOCUMENT_IMPLEMENTATION_PROPERTY:
		g_value_set_object (value, gxml_dom_document_get_implementation ((GXmlDomDocument*) self));
		break;
		case GXML_GDOCUMENT_URL_PROPERTY:
		g_value_set_string (value, gxml_dom_document_get_url ((GXmlDomDocument*) self));
		break;
		case GXML_GDOCUMENT_DOCUMENT_URI_PROPERTY:
		g_value_set_string (value, gxml_dom_document_get_document_uri ((GXmlDomDocument*) self));
		break;
		case GXML_GDOCUMENT_ORIGIN_PROPERTY:
		g_value_set_string (value, gxml_dom_document_get_origin ((GXmlDomDocument*) self));
		break;
		case GXML_GDOCUMENT_COMPAT_MODE_PROPERTY:
		g_value_set_string (value, gxml_dom_document_get_compat_mode ((GXmlDomDocument*) self));
		break;
		case GXML_GDOCUMENT_CHARACTER_SET_PROPERTY:
		g_value_set_string (value, gxml_dom_document_get_character_set ((GXmlDomDocument*) self));
		break;
		case GXML_GDOCUMENT_CONTENT_TYPE_PROPERTY:
		g_value_set_string (value, gxml_dom_document_get_content_type ((GXmlDomDocument*) self));
		break;
		case GXML_GDOCUMENT_DOCTYPE_PROPERTY:
		g_value_take_object (value, gxml_dom_document_get_doctype ((GXmlDomDocument*) self));
		break;
		case GXML_GDOCUMENT_DOCUMENT_ELEMENT_PROPERTY:
		g_value_take_object (value, gxml_dom_document_get_document_element ((GXmlDomDocument*) self));
		break;
		case GXML_GDOCUMENT_CHILDREN_PROPERTY:
		g_value_take_object (value, gxml_dom_parent_node_get_children ((GXmlDomParentNode*) self));
		break;
		case GXML_GDOCUMENT_FIRST_ELEMENT_CHILD_PROPERTY:
		g_value_take_object (value, gxml_dom_parent_node_get_first_element_child ((GXmlDomParentNode*) self));
		break;
		case GXML_GDOCUMENT_LAST_ELEMENT_CHILD_PROPERTY:
		g_value_take_object (value, gxml_dom_parent_node_get_last_element_child ((GXmlDomParentNode*) self));
		break;
		case GXML_GDOCUMENT_CHILD_ELEMENT_COUNT_PROPERTY:
		g_value_set_int (value, gxml_dom_parent_node_get_child_element_count ((GXmlDomParentNode*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_gxml_gdocument_set_property (GObject * object,
                                   guint property_id,
                                   const GValue * value,
                                   GParamSpec * pspec)
{
	GXmlGDocument * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GDOCUMENT, GXmlGDocument);
	switch (property_id) {
		case GXML_GDOCUMENT_INDENT_PROPERTY:
		gxml_document_set_indent ((GXmlDocument*) self, g_value_get_boolean (value));
		break;
		case GXML_GDOCUMENT_NS_TOP_PROPERTY:
		gxml_document_set_ns_top ((GXmlDocument*) self, g_value_get_boolean (value));
		break;
		case GXML_GDOCUMENT_PREFIX_DEFAULT_NS_PROPERTY:
		gxml_document_set_prefix_default_ns ((GXmlDocument*) self, g_value_get_boolean (value));
		break;
		case GXML_GDOCUMENT_BACKUP_PROPERTY:
		gxml_document_set_backup ((GXmlDocument*) self, g_value_get_boolean (value));
		break;
		case GXML_GDOCUMENT_FILE_PROPERTY:
		gxml_document_set_file ((GXmlDocument*) self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static GXmlDomDocumentType*
gxml_gimplementation_real_create_document_type (GXmlDomImplementation* base,
                                                const gchar* qualified_name,
                                                const gchar* public_id,
                                                const gchar* system_id,
                                                GError** error)
{
	GXmlGImplementation * self;
	GXmlDomDocumentType* result = NULL;
	GXmlGDocumentType* _tmp0_;
	self = (GXmlGImplementation*) base;
	g_return_val_if_fail (qualified_name != NULL, NULL);
	g_return_val_if_fail (public_id != NULL, NULL);
	g_return_val_if_fail (system_id != NULL, NULL);
	_tmp0_ = gxml_gdocument_type_new_with_ids (qualified_name, public_id, system_id);
	result = (GXmlDomDocumentType*) _tmp0_;
	return result;
}

static GXmlDomXMLDocument*
gxml_gimplementation_real_create_document (GXmlDomImplementation* base,
                                           const gchar* namespace,
                                           const gchar* qualified_name,
                                           GXmlDomDocumentType* doctype,
                                           GError** error)
{
	GXmlGImplementation * self;
	GXmlDomXMLDocument* result = NULL;
	GXmlGDocument* _tmp0_;
	self = (GXmlGImplementation*) base;
	_tmp0_ = gxml_gdocument_new ();
	result = (GXmlDomXMLDocument*) _tmp0_;
	return result;
}

static GXmlDocument*
gxml_gimplementation_real_create_html_document (GXmlDomImplementation* base,
                                                const gchar* title)
{
	GXmlGImplementation * self;
	GXmlDocument* result = NULL;
	GXmlGHtmlDocument* _tmp0_;
	self = (GXmlGImplementation*) base;
	g_return_val_if_fail (title != NULL, NULL);
	_tmp0_ = gxml_ghtml_document_new ();
	result = (GXmlDocument*) _tmp0_;
	return result;
}

GXmlGImplementation*
gxml_gimplementation_construct (GType object_type)
{
	GXmlGImplementation * self = NULL;
	self = (GXmlGImplementation*) g_object_new (object_type, NULL);
	return self;
}

GXmlGImplementation*
gxml_gimplementation_new (void)
{
	return gxml_gimplementation_construct (GXML_TYPE_GIMPLEMENTATION);
}

static void
gxml_gimplementation_class_init (GXmlGImplementationClass * klass,
                                 gpointer klass_data)
{
	gxml_gimplementation_parent_class = g_type_class_peek_parent (klass);
}

static void
gxml_gimplementation_gxml_dom_implementation_interface_init (GXmlDomImplementationIface * iface,
                                                             gpointer iface_data)
{
	gxml_gimplementation_gxml_dom_implementation_parent_iface = g_type_interface_peek_parent (iface);
	iface->create_document_type = (GXmlDomDocumentType* (*) (GXmlDomImplementation*, const gchar*, const gchar*, const gchar*, GError**)) gxml_gimplementation_real_create_document_type;
	iface->create_document = (GXmlDomXMLDocument* (*) (GXmlDomImplementation*, const gchar*, const gchar*, GXmlDomDocumentType*, GError**)) gxml_gimplementation_real_create_document;
	iface->create_html_document = (GXmlDocument* (*) (GXmlDomImplementation*, const gchar*)) gxml_gimplementation_real_create_html_document;
}

static void
gxml_gimplementation_instance_init (GXmlGImplementation * self,
                                    gpointer klass)
{
}

GType
gxml_gimplementation_get_type (void)
{
	static volatile gsize gxml_gimplementation_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gimplementation_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGImplementationClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gimplementation_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGImplementation), 0, (GInstanceInitFunc) gxml_gimplementation_instance_init, NULL };
		static const GInterfaceInfo gxml_dom_implementation_info = { (GInterfaceInitFunc) gxml_gimplementation_gxml_dom_implementation_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_gimplementation_type_id;
		gxml_gimplementation_type_id = g_type_register_static (G_TYPE_OBJECT, "GXmlGImplementation", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_gimplementation_type_id, GXML_TYPE_DOM_IMPLEMENTATION, &gxml_dom_implementation_info);
		g_once_init_leave (&gxml_gimplementation_type_id__volatile, gxml_gimplementation_type_id);
	}
	return gxml_gimplementation_type_id__volatile;
}

GXmlGDocumentType*
gxml_gdocument_type_construct_with_name (GType object_type,
                                         const gchar* name)
{
	GXmlGDocumentType * self = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	g_return_val_if_fail (name != NULL, NULL);
	self = (GXmlGDocumentType*) gxml_gchild_node_construct (object_type);
	_tmp0_ = g_strdup (name);
	_g_free0 (self->_name);
	self->_name = _tmp0_;
	_tmp1_ = g_strdup ("");
	_g_free0 (self->_public_id);
	self->_public_id = _tmp1_;
	_tmp2_ = g_strdup ("");
	_g_free0 (self->_system_id);
	self->_system_id = _tmp2_;
	return self;
}

GXmlGDocumentType*
gxml_gdocument_type_new_with_name (const gchar* name)
{
	return gxml_gdocument_type_construct_with_name (GXML_TYPE_GDOCUMENT_TYPE, name);
}

GXmlGDocumentType*
gxml_gdocument_type_construct_with_ids (GType object_type,
                                        const gchar* name,
                                        const gchar* public_id,
                                        const gchar* system_id)
{
	GXmlGDocumentType * self = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	g_return_val_if_fail (name != NULL, NULL);
	g_return_val_if_fail (public_id != NULL, NULL);
	g_return_val_if_fail (system_id != NULL, NULL);
	self = (GXmlGDocumentType*) gxml_gchild_node_construct (object_type);
	_tmp0_ = g_strdup (name);
	_g_free0 (self->_name);
	self->_name = _tmp0_;
	_tmp1_ = g_strdup (public_id);
	_g_free0 (self->_public_id);
	self->_public_id = _tmp1_;
	_tmp2_ = g_strdup (system_id);
	_g_free0 (self->_system_id);
	self->_system_id = _tmp2_;
	return self;
}

GXmlGDocumentType*
gxml_gdocument_type_new_with_ids (const gchar* name,
                                  const gchar* public_id,
                                  const gchar* system_id)
{
	return gxml_gdocument_type_construct_with_ids (GXML_TYPE_GDOCUMENT_TYPE, name, public_id, system_id);
}

static void
gxml_gdocument_type_real_remove (GXmlDomChildNode* base)
{
	GXmlGDocumentType * self;
	xmlNode* _tmp0_;
	self = (GXmlGDocumentType*) base;
	_tmp0_ = gxml_gnode_get_internal_node ((GXmlGNode*) self);
	xmlUnlinkNode (_tmp0_);
}

GXmlGDocumentType*
gxml_gdocument_type_construct (GType object_type)
{
	GXmlGDocumentType * self = NULL;
	self = (GXmlGDocumentType*) gxml_gchild_node_construct (object_type);
	return self;
}

GXmlGDocumentType*
gxml_gdocument_type_new (void)
{
	return gxml_gdocument_type_construct (GXML_TYPE_GDOCUMENT_TYPE);
}

static const gchar*
gxml_gdocument_type_real_get_name (GXmlDomDocumentType* base)
{
	const gchar* result;
	GXmlGDocumentType* self;
	const gchar* _tmp0_;
	self = (GXmlGDocumentType*) base;
	_tmp0_ = self->_name;
	result = _tmp0_;
	return result;
}

static const gchar*
gxml_gdocument_type_real_get_public_id (GXmlDomDocumentType* base)
{
	const gchar* result;
	GXmlGDocumentType* self;
	const gchar* _tmp0_;
	self = (GXmlGDocumentType*) base;
	_tmp0_ = self->_public_id;
	result = _tmp0_;
	return result;
}

static const gchar*
gxml_gdocument_type_real_get_system_id (GXmlDomDocumentType* base)
{
	const gchar* result;
	GXmlGDocumentType* self;
	const gchar* _tmp0_;
	self = (GXmlGDocumentType*) base;
	_tmp0_ = self->_system_id;
	result = _tmp0_;
	return result;
}

static void
gxml_gdocument_type_class_init (GXmlGDocumentTypeClass * klass,
                                gpointer klass_data)
{
	gxml_gdocument_type_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gdocument_type_get_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_gdocument_type_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_TYPE_NAME_PROPERTY, gxml_gdocument_type_properties[GXML_GDOCUMENT_TYPE_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_TYPE_PUBLIC_ID_PROPERTY, gxml_gdocument_type_properties[GXML_GDOCUMENT_TYPE_PUBLIC_ID_PROPERTY] = g_param_spec_string ("public-id", "public-id", "public-id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOCUMENT_TYPE_SYSTEM_ID_PROPERTY, gxml_gdocument_type_properties[GXML_GDOCUMENT_TYPE_SYSTEM_ID_PROPERTY] = g_param_spec_string ("system-id", "system-id", "system-id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
gxml_gdocument_type_gxml_dom_node_interface_init (GXmlDomNodeIface * iface,
                                                  gpointer iface_data)
{
	gxml_gdocument_type_gxml_dom_node_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_node_type = (GXmlDomNodeNodeType (*) (GXmlDomNode *)) gxml_dom_node_get_node_type;
	iface->get_node_name = (gchar* (*) (GXmlDomNode *)) gxml_dom_node_get_node_name;
	iface->get_base_uri = (const gchar* (*) (GXmlDomNode *)) gxml_dom_node_get_base_uri;
	iface->get_owner_document = (GXmlDomDocument* (*) (GXmlDomNode *)) gxml_dom_node_get_owner_document;
	iface->set_owner_document = (void (*) (GXmlDomNode *, GXmlDomDocument*)) gxml_dom_node_set_owner_document;
	iface->get_parent_node = (GXmlDomNode* (*) (GXmlDomNode *)) gxml_dom_node_get_parent_node;
	iface->get_parent_element = (GXmlDomElement* (*) (GXmlDomNode *)) gxml_dom_node_get_parent_element;
	iface->get_child_nodes = (GXmlDomNodeList* (*) (GXmlDomNode *)) gxml_dom_node_get_child_nodes;
	iface->get_first_child = (GXmlDomNode* (*) (GXmlDomNode *)) gxml_dom_node_get_first_child;
	iface->get_last_child = (GXmlDomNode* (*) (GXmlDomNode *)) gxml_dom_node_get_last_child;
	iface->get_previous_sibling = (GXmlDomNode* (*) (GXmlDomNode *)) gxml_dom_node_get_previous_sibling;
	iface->get_next_sibling = (GXmlDomNode* (*) (GXmlDomNode *)) gxml_dom_node_get_next_sibling;
	iface->get_node_value = (gchar* (*) (GXmlDomNode *)) gxml_dom_node_get_node_value;
	iface->set_node_value = (void (*) (GXmlDomNode *, const gchar*)) gxml_dom_node_set_node_value;
	iface->get_text_content = (gchar* (*) (GXmlDomNode *)) gxml_dom_node_get_text_content;
	iface->set_text_content = (void (*) (GXmlDomNode *, const gchar*)) gxml_dom_node_set_text_content;
}

static void
gxml_gdocument_type_gxml_dom_child_node_interface_init (GXmlDomChildNodeIface * iface,
                                                        gpointer iface_data)
{
	gxml_gdocument_type_gxml_dom_child_node_parent_iface = g_type_interface_peek_parent (iface);
	iface->remove = (void (*) (GXmlDomChildNode*)) gxml_gdocument_type_real_remove;
}

static void
gxml_gdocument_type_gxml_dom_document_type_interface_init (GXmlDomDocumentTypeIface * iface,
                                                           gpointer iface_data)
{
	gxml_gdocument_type_gxml_dom_document_type_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_name = gxml_gdocument_type_real_get_name;
	iface->get_public_id = gxml_gdocument_type_real_get_public_id;
	iface->get_system_id = gxml_gdocument_type_real_get_system_id;
}

static void
gxml_gdocument_type_instance_init (GXmlGDocumentType * self,
                                   gpointer klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	_tmp0_ = g_strdup ("");
	self->_name = _tmp0_;
	_tmp1_ = g_strdup ("");
	self->_public_id = _tmp1_;
	_tmp2_ = g_strdup ("");
	self->_system_id = _tmp2_;
}

static void
gxml_gdocument_type_finalize (GObject * obj)
{
	GXmlGDocumentType * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GDOCUMENT_TYPE, GXmlGDocumentType);
	_g_free0 (self->_name);
	_g_free0 (self->_public_id);
	_g_free0 (self->_system_id);
	G_OBJECT_CLASS (gxml_gdocument_type_parent_class)->finalize (obj);
}

GType
gxml_gdocument_type_get_type (void)
{
	static volatile gsize gxml_gdocument_type_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gdocument_type_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGDocumentTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gdocument_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGDocumentType), 0, (GInstanceInitFunc) gxml_gdocument_type_instance_init, NULL };
		static const GInterfaceInfo gxml_dom_node_info = { (GInterfaceInitFunc) gxml_gdocument_type_gxml_dom_node_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_child_node_info = { (GInterfaceInitFunc) gxml_gdocument_type_gxml_dom_child_node_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_document_type_info = { (GInterfaceInitFunc) gxml_gdocument_type_gxml_dom_document_type_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_gdocument_type_type_id;
		gxml_gdocument_type_type_id = g_type_register_static (GXML_TYPE_GCHILD_NODE, "GXmlGDocumentType", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_gdocument_type_type_id, GXML_TYPE_DOM_NODE, &gxml_dom_node_info);
		g_type_add_interface_static (gxml_gdocument_type_type_id, GXML_TYPE_DOM_CHILD_NODE, &gxml_dom_child_node_info);
		g_type_add_interface_static (gxml_gdocument_type_type_id, GXML_TYPE_DOM_DOCUMENT_TYPE, &gxml_dom_document_type_info);
		g_once_init_leave (&gxml_gdocument_type_type_id__volatile, gxml_gdocument_type_type_id);
	}
	return gxml_gdocument_type_type_id__volatile;
}

static void
_vala_gxml_gdocument_type_get_property (GObject * object,
                                        guint property_id,
                                        GValue * value,
                                        GParamSpec * pspec)
{
	GXmlGDocumentType * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GDOCUMENT_TYPE, GXmlGDocumentType);
	switch (property_id) {
		case GXML_GDOCUMENT_TYPE_NAME_PROPERTY:
		g_value_set_string (value, gxml_dom_document_type_get_name ((GXmlDomDocumentType*) self));
		break;
		case GXML_GDOCUMENT_TYPE_PUBLIC_ID_PROPERTY:
		g_value_set_string (value, gxml_dom_document_type_get_public_id ((GXmlDomDocumentType*) self));
		break;
		case GXML_GDOCUMENT_TYPE_SYSTEM_ID_PROPERTY:
		g_value_set_string (value, gxml_dom_document_type_get_system_id ((GXmlDomDocumentType*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

GXmlGDocumentFragment*
gxml_gdocument_fragment_construct (GType object_type,
                                   GXmlGDocument* d)
{
	GXmlGDocumentFragment * self = NULL;
	GXmlGDocument* _tmp0_;
	GXmlGDocument* _tmp1_;
	g_return_val_if_fail (d != NULL, NULL);
	self = (GXmlGDocumentFragment*) gxml_gdocument_construct (object_type);
	_tmp0_ = ((GXmlGNode*) d)->_doc;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	_g_object_unref0 (((GXmlGNode*) self)->_doc);
	((GXmlGNode*) self)->_doc = _tmp1_;
	return self;
}

GXmlGDocumentFragment*
gxml_gdocument_fragment_new (GXmlGDocument* d)
{
	return gxml_gdocument_fragment_construct (GXML_TYPE_GDOCUMENT_FRAGMENT, d);
}

static void
gxml_gdocument_fragment_class_init (GXmlGDocumentFragmentClass * klass,
                                    gpointer klass_data)
{
	gxml_gdocument_fragment_parent_class = g_type_class_peek_parent (klass);
}

static void
gxml_gdocument_fragment_gxml_dom_document_fragment_interface_init (GXmlDomDocumentFragmentIface * iface,
                                                                   gpointer iface_data)
{
	gxml_gdocument_fragment_gxml_dom_document_fragment_parent_iface = g_type_interface_peek_parent (iface);
}

static void
gxml_gdocument_fragment_instance_init (GXmlGDocumentFragment * self,
                                       gpointer klass)
{
}

GType
gxml_gdocument_fragment_get_type (void)
{
	static volatile gsize gxml_gdocument_fragment_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gdocument_fragment_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGDocumentFragmentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gdocument_fragment_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGDocumentFragment), 0, (GInstanceInitFunc) gxml_gdocument_fragment_instance_init, NULL };
		static const GInterfaceInfo gxml_dom_document_fragment_info = { (GInterfaceInitFunc) gxml_gdocument_fragment_gxml_dom_document_fragment_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_gdocument_fragment_type_id;
		gxml_gdocument_fragment_type_id = g_type_register_static (GXML_TYPE_GDOCUMENT, "GXmlGDocumentFragment", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_gdocument_fragment_type_id, GXML_TYPE_DOM_DOCUMENT_FRAGMENT, &gxml_dom_document_fragment_info);
		g_once_init_leave (&gxml_gdocument_fragment_type_id__volatile, gxml_gdocument_fragment_type_id);
	}
	return gxml_gdocument_fragment_type_id__volatile;
}

GXmlGDomNodeIterator*
gxml_gdom_node_iterator_construct (GType object_type,
                                   GXmlDomNode* n,
                                   gint what_to_show,
                                   GXmlDomNodeFilter* filter)
{
	GXmlGDomNodeIterator * self = NULL;
	GXmlDomNode* _tmp0_;
	GXmlDomNodeFilter* _tmp1_;
	g_return_val_if_fail (n != NULL, NULL);
	g_return_val_if_fail (filter != NULL, NULL);
	self = (GXmlGDomNodeIterator*) g_object_new (object_type, NULL);
	_tmp0_ = _g_object_ref0 (n);
	_g_object_unref0 (self->_root);
	self->_root = _tmp0_;
	self->_what_to_show = what_to_show;
	_tmp1_ = _g_object_ref0 (filter);
	_g_object_unref0 (self->_filter);
	self->_filter = _tmp1_;
	return self;
}

GXmlGDomNodeIterator*
gxml_gdom_node_iterator_new (GXmlDomNode* n,
                             gint what_to_show,
                             GXmlDomNodeFilter* filter)
{
	return gxml_gdom_node_iterator_construct (GXML_TYPE_GDOM_NODE_ITERATOR, n, what_to_show, filter);
}

static GXmlDomNode*
gxml_gdom_node_iterator_real_next_node (GXmlDomNodeIterator* base)
{
	GXmlGDomNodeIterator * self;
	GXmlDomNode* result = NULL;
	self = (GXmlGDomNodeIterator*) base;
	result = NULL;
	return result;
}

static GXmlDomNode*
gxml_gdom_node_iterator_real_previous_node (GXmlDomNodeIterator* base)
{
	GXmlGDomNodeIterator * self;
	GXmlDomNode* result = NULL;
	self = (GXmlGDomNodeIterator*) base;
	result = NULL;
	return result;
}

static void
gxml_gdom_node_iterator_real_detach (GXmlDomNodeIterator* base)
{
	GXmlGDomNodeIterator * self;
	self = (GXmlGDomNodeIterator*) base;
	return;
}

static GXmlDomNode*
gxml_gdom_node_iterator_real_get_root (GXmlDomNodeIterator* base)
{
	GXmlDomNode* result;
	GXmlGDomNodeIterator* self;
	GXmlDomNode* _tmp0_;
	self = (GXmlGDomNodeIterator*) base;
	_tmp0_ = self->_root;
	result = _tmp0_;
	return result;
}

static GXmlDomNode*
gxml_gdom_node_iterator_real_get_reference_node (GXmlDomNodeIterator* base)
{
	GXmlDomNode* result;
	GXmlGDomNodeIterator* self;
	GXmlDomNode* _tmp0_;
	self = (GXmlGDomNodeIterator*) base;
	_tmp0_ = self->_reference_node;
	result = _tmp0_;
	return result;
}

static gboolean
gxml_gdom_node_iterator_real_get_pointer_before_reference_node (GXmlDomNodeIterator* base)
{
	gboolean result;
	GXmlGDomNodeIterator* self;
	self = (GXmlGDomNodeIterator*) base;
	result = self->_pointer_before_reference_node;
	return result;
}

static gint
gxml_gdom_node_iterator_real_get_what_to_show (GXmlDomNodeIterator* base)
{
	gint result;
	GXmlGDomNodeIterator* self;
	self = (GXmlGDomNodeIterator*) base;
	result = self->_what_to_show;
	return result;
}

static GXmlDomNodeFilter*
gxml_gdom_node_iterator_real_get_filter (GXmlDomNodeIterator* base)
{
	GXmlDomNodeFilter* result;
	GXmlGDomNodeIterator* self;
	GXmlDomNodeFilter* _tmp0_;
	self = (GXmlGDomNodeIterator*) base;
	_tmp0_ = self->_filter;
	result = _tmp0_;
	return result;
}

static void
gxml_gdom_node_iterator_class_init (GXmlGDomNodeIteratorClass * klass,
                                    gpointer klass_data)
{
	gxml_gdom_node_iterator_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gdom_node_iterator_get_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_gdom_node_iterator_finalize;
}

static void
gxml_gdom_node_iterator_gxml_dom_node_iterator_interface_init (GXmlDomNodeIteratorIface * iface,
                                                               gpointer iface_data)
{
	gxml_gdom_node_iterator_gxml_dom_node_iterator_parent_iface = g_type_interface_peek_parent (iface);
	iface->next_node = (GXmlDomNode* (*) (GXmlDomNodeIterator*)) gxml_gdom_node_iterator_real_next_node;
	iface->previous_node = (GXmlDomNode* (*) (GXmlDomNodeIterator*)) gxml_gdom_node_iterator_real_previous_node;
	iface->detach = (void (*) (GXmlDomNodeIterator*)) gxml_gdom_node_iterator_real_detach;
	iface->get_root = gxml_gdom_node_iterator_real_get_root;
	iface->get_reference_node = gxml_gdom_node_iterator_real_get_reference_node;
	iface->get_pointer_before_reference_node = gxml_gdom_node_iterator_real_get_pointer_before_reference_node;
	iface->get_what_to_show = gxml_gdom_node_iterator_real_get_what_to_show;
	iface->get_filter = gxml_gdom_node_iterator_real_get_filter;
}

static void
gxml_gdom_node_iterator_instance_init (GXmlGDomNodeIterator * self,
                                       gpointer klass)
{
}

static void
gxml_gdom_node_iterator_finalize (GObject * obj)
{
	GXmlGDomNodeIterator * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GDOM_NODE_ITERATOR, GXmlGDomNodeIterator);
	_g_object_unref0 (self->_root);
	_g_object_unref0 (self->_reference_node);
	_g_object_unref0 (self->_filter);
	G_OBJECT_CLASS (gxml_gdom_node_iterator_parent_class)->finalize (obj);
}

GType
gxml_gdom_node_iterator_get_type (void)
{
	static volatile gsize gxml_gdom_node_iterator_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gdom_node_iterator_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGDomNodeIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gdom_node_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGDomNodeIterator), 0, (GInstanceInitFunc) gxml_gdom_node_iterator_instance_init, NULL };
		static const GInterfaceInfo gxml_dom_node_iterator_info = { (GInterfaceInitFunc) gxml_gdom_node_iterator_gxml_dom_node_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_gdom_node_iterator_type_id;
		gxml_gdom_node_iterator_type_id = g_type_register_static (G_TYPE_OBJECT, "GXmlGDomNodeIterator", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_gdom_node_iterator_type_id, GXML_TYPE_DOM_NODE_ITERATOR, &gxml_dom_node_iterator_info);
		g_once_init_leave (&gxml_gdom_node_iterator_type_id__volatile, gxml_gdom_node_iterator_type_id);
	}
	return gxml_gdom_node_iterator_type_id__volatile;
}

static void
_vala_gxml_gdom_node_iterator_get_property (GObject * object,
                                            guint property_id,
                                            GValue * value,
                                            GParamSpec * pspec)
{
	GXmlGDomNodeIterator * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GDOM_NODE_ITERATOR, GXmlGDomNodeIterator);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

GXmlGDomTreeWalker*
gxml_gdom_tree_walker_construct (GType object_type,
                                 GXmlDomNode* r,
                                 gint w,
                                 GXmlDomNodeFilter* f)
{
	GXmlGDomTreeWalker * self = NULL;
	GXmlDomNode* _tmp0_;
	GXmlDomNodeFilter* _tmp1_;
	g_return_val_if_fail (r != NULL, NULL);
	g_return_val_if_fail (f != NULL, NULL);
	self = (GXmlGDomTreeWalker*) g_object_new (object_type, NULL);
	_tmp0_ = _g_object_ref0 (r);
	_g_object_unref0 (self->_root);
	self->_root = _tmp0_;
	self->_what_to_show = w;
	_tmp1_ = _g_object_ref0 (f);
	_g_object_unref0 (self->_filter);
	self->_filter = _tmp1_;
	return self;
}

GXmlGDomTreeWalker*
gxml_gdom_tree_walker_new (GXmlDomNode* r,
                           gint w,
                           GXmlDomNodeFilter* f)
{
	return gxml_gdom_tree_walker_construct (GXML_TYPE_GDOM_TREE_WALKER, r, w, f);
}

static GXmlDomNode*
gxml_gdom_tree_walker_real_parent_node (GXmlDomTreeWalker* base)
{
	GXmlGDomTreeWalker * self;
	GXmlDomNode* result = NULL;
	self = (GXmlGDomTreeWalker*) base;
	result = NULL;
	return result;
}

static GXmlDomNode*
gxml_gdom_tree_walker_real_first_child (GXmlDomTreeWalker* base)
{
	GXmlGDomTreeWalker * self;
	GXmlDomNode* result = NULL;
	self = (GXmlGDomTreeWalker*) base;
	result = NULL;
	return result;
}

static GXmlDomNode*
gxml_gdom_tree_walker_real_last_child (GXmlDomTreeWalker* base)
{
	GXmlGDomTreeWalker * self;
	GXmlDomNode* result = NULL;
	self = (GXmlGDomTreeWalker*) base;
	result = NULL;
	return result;
}

static GXmlDomNode*
gxml_gdom_tree_walker_real_previous_sibling (GXmlDomTreeWalker* base)
{
	GXmlGDomTreeWalker * self;
	GXmlDomNode* result = NULL;
	self = (GXmlGDomTreeWalker*) base;
	result = NULL;
	return result;
}

static GXmlDomNode*
gxml_gdom_tree_walker_real_next_sibling (GXmlDomTreeWalker* base)
{
	GXmlGDomTreeWalker * self;
	GXmlDomNode* result = NULL;
	self = (GXmlGDomTreeWalker*) base;
	result = NULL;
	return result;
}

static GXmlDomNode*
gxml_gdom_tree_walker_real_previous_node (GXmlDomTreeWalker* base)
{
	GXmlGDomTreeWalker * self;
	GXmlDomNode* result = NULL;
	self = (GXmlGDomTreeWalker*) base;
	result = NULL;
	return result;
}

static GXmlDomNode*
gxml_gdom_tree_walker_real_next_node (GXmlDomTreeWalker* base)
{
	GXmlGDomTreeWalker * self;
	GXmlDomNode* result = NULL;
	self = (GXmlGDomTreeWalker*) base;
	result = NULL;
	return result;
}

static GXmlDomNode*
gxml_gdom_tree_walker_real_get_root (GXmlDomTreeWalker* base)
{
	GXmlDomNode* result;
	GXmlGDomTreeWalker* self;
	GXmlDomNode* _tmp0_;
	GXmlDomNode* _tmp1_;
	self = (GXmlGDomTreeWalker*) base;
	_tmp0_ = gxml_dom_tree_walker_get_root ((GXmlDomTreeWalker*) self);
	_tmp1_ = _tmp0_;
	result = _tmp1_;
	return result;
}

static gint
gxml_gdom_tree_walker_real_get_what_to_show (GXmlDomTreeWalker* base)
{
	gint result;
	GXmlGDomTreeWalker* self;
	self = (GXmlGDomTreeWalker*) base;
	result = self->_what_to_show;
	return result;
}

static GXmlDomNodeFilter*
gxml_gdom_tree_walker_real_get_filter (GXmlDomTreeWalker* base)
{
	GXmlDomNodeFilter* result;
	GXmlGDomTreeWalker* self;
	GXmlDomNodeFilter* _tmp0_;
	self = (GXmlGDomTreeWalker*) base;
	_tmp0_ = self->_filter;
	result = _tmp0_;
	return result;
}

static GXmlDomNode*
gxml_gdom_tree_walker_real_get_current_node (GXmlDomTreeWalker* base)
{
	GXmlDomNode* result;
	GXmlGDomTreeWalker* self;
	GXmlDomNode* _tmp0_;
	self = (GXmlGDomTreeWalker*) base;
	_tmp0_ = self->_current_node;
	result = _tmp0_;
	return result;
}

static void
gxml_gdom_tree_walker_class_init (GXmlGDomTreeWalkerClass * klass,
                                  gpointer klass_data)
{
	gxml_gdom_tree_walker_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gdom_tree_walker_get_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_gdom_tree_walker_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOM_TREE_WALKER_ROOT_PROPERTY, gxml_gdom_tree_walker_properties[GXML_GDOM_TREE_WALKER_ROOT_PROPERTY] = g_param_spec_object ("root", "root", "root", GXML_TYPE_DOM_NODE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOM_TREE_WALKER_WHAT_TO_SHOW_PROPERTY, gxml_gdom_tree_walker_properties[GXML_GDOM_TREE_WALKER_WHAT_TO_SHOW_PROPERTY] = g_param_spec_int ("what-to-show", "what-to-show", "what-to-show", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOM_TREE_WALKER_FILTER_PROPERTY, gxml_gdom_tree_walker_properties[GXML_GDOM_TREE_WALKER_FILTER_PROPERTY] = g_param_spec_object ("filter", "filter", "filter", GXML_TYPE_DOM_NODE_FILTER, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOM_TREE_WALKER_CURRENT_NODE_PROPERTY, gxml_gdom_tree_walker_properties[GXML_GDOM_TREE_WALKER_CURRENT_NODE_PROPERTY] = g_param_spec_object ("current-node", "current-node", "current-node", GXML_TYPE_DOM_NODE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
gxml_gdom_tree_walker_gxml_dom_tree_walker_interface_init (GXmlDomTreeWalkerIface * iface,
                                                           gpointer iface_data)
{
	gxml_gdom_tree_walker_gxml_dom_tree_walker_parent_iface = g_type_interface_peek_parent (iface);
	iface->parent_node = (GXmlDomNode* (*) (GXmlDomTreeWalker*)) gxml_gdom_tree_walker_real_parent_node;
	iface->first_child = (GXmlDomNode* (*) (GXmlDomTreeWalker*)) gxml_gdom_tree_walker_real_first_child;
	iface->last_child = (GXmlDomNode* (*) (GXmlDomTreeWalker*)) gxml_gdom_tree_walker_real_last_child;
	iface->previous_sibling = (GXmlDomNode* (*) (GXmlDomTreeWalker*)) gxml_gdom_tree_walker_real_previous_sibling;
	iface->next_sibling = (GXmlDomNode* (*) (GXmlDomTreeWalker*)) gxml_gdom_tree_walker_real_next_sibling;
	iface->previous_node = (GXmlDomNode* (*) (GXmlDomTreeWalker*)) gxml_gdom_tree_walker_real_previous_node;
	iface->next_node = (GXmlDomNode* (*) (GXmlDomTreeWalker*)) gxml_gdom_tree_walker_real_next_node;
	iface->get_root = gxml_gdom_tree_walker_real_get_root;
	iface->get_what_to_show = gxml_gdom_tree_walker_real_get_what_to_show;
	iface->get_filter = gxml_gdom_tree_walker_real_get_filter;
	iface->get_current_node = gxml_gdom_tree_walker_real_get_current_node;
}

static void
gxml_gdom_tree_walker_instance_init (GXmlGDomTreeWalker * self,
                                     gpointer klass)
{
}

static void
gxml_gdom_tree_walker_finalize (GObject * obj)
{
	GXmlGDomTreeWalker * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GDOM_TREE_WALKER, GXmlGDomTreeWalker);
	_g_object_unref0 (self->_root);
	_g_object_unref0 (self->_filter);
	_g_object_unref0 (self->_current_node);
	G_OBJECT_CLASS (gxml_gdom_tree_walker_parent_class)->finalize (obj);
}

GType
gxml_gdom_tree_walker_get_type (void)
{
	static volatile gsize gxml_gdom_tree_walker_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gdom_tree_walker_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGDomTreeWalkerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gdom_tree_walker_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGDomTreeWalker), 0, (GInstanceInitFunc) gxml_gdom_tree_walker_instance_init, NULL };
		static const GInterfaceInfo gxml_dom_tree_walker_info = { (GInterfaceInitFunc) gxml_gdom_tree_walker_gxml_dom_tree_walker_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_gdom_tree_walker_type_id;
		gxml_gdom_tree_walker_type_id = g_type_register_static (G_TYPE_OBJECT, "GXmlGDomTreeWalker", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_gdom_tree_walker_type_id, GXML_TYPE_DOM_TREE_WALKER, &gxml_dom_tree_walker_info);
		g_once_init_leave (&gxml_gdom_tree_walker_type_id__volatile, gxml_gdom_tree_walker_type_id);
	}
	return gxml_gdom_tree_walker_type_id__volatile;
}

static void
_vala_gxml_gdom_tree_walker_get_property (GObject * object,
                                          guint property_id,
                                          GValue * value,
                                          GParamSpec * pspec)
{
	GXmlGDomTreeWalker * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GDOM_TREE_WALKER, GXmlGDomTreeWalker);
	switch (property_id) {
		case GXML_GDOM_TREE_WALKER_ROOT_PROPERTY:
		g_value_set_object (value, gxml_dom_tree_walker_get_root ((GXmlDomTreeWalker*) self));
		break;
		case GXML_GDOM_TREE_WALKER_WHAT_TO_SHOW_PROPERTY:
		g_value_set_int (value, gxml_dom_tree_walker_get_what_to_show ((GXmlDomTreeWalker*) self));
		break;
		case GXML_GDOM_TREE_WALKER_FILTER_PROPERTY:
		g_value_set_object (value, gxml_dom_tree_walker_get_filter ((GXmlDomTreeWalker*) self));
		break;
		case GXML_GDOM_TREE_WALKER_CURRENT_NODE_PROPERTY:
		g_value_set_object (value, gxml_dom_tree_walker_get_current_node ((GXmlDomTreeWalker*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

static gint
_vala_array_length (gpointer array)
{
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}

